@@ -329,8 +329,7 @@ bool CreateScenario::create(const GameParameters &g)
 
     int number_of_armies_factor;
     getCityDifficulty(g.difficulty, &number_of_armies_factor);
-    if (!setupCities(g.quick_start, g.cities_can_produce_allies,
-		     number_of_armies_factor))
+    if (!setupCities(g.cities_can_produce_allies, number_of_armies_factor))
         return false;
 
     if (!setupTemples())
@@ -352,7 +351,7 @@ bool CreateScenario::create(const GameParameters &g)
 
     int base_gold;
     getBaseGold (g.difficulty, &base_gold);
-    if (!setupPlayers(g.diplomacy, g.random_turns, base_gold))
+    if (!setupPlayers(g.random_turns, base_gold))
         return false;
 
     if (!setupItems())
@@ -460,7 +459,7 @@ bool CreateScenario::distributePlayers()
 
 	    History_CityWon *item = new History_CityWon();
 	    item->fillData(&*cit);
-	    (*pit)->getHistorylist()->push_back(item);
+	    (*pit)->addHistory(item);
 
             pit++;
             if ((*pit) == pl->getNeutral())
@@ -474,15 +473,11 @@ bool CreateScenario::distributePlayers()
     return true;
 }
 
-bool CreateScenario::setupCities(bool quick_start, 
-				 bool cities_can_produce_allies,
+bool CreateScenario::setupCities(bool cities_can_produce_allies,
 				 int number_of_armies_factor)
 {
     debug("CreateScenario::setupCities")
 
-    if (quick_start)
-      quickStart();
-
     for (Citylist::iterator it = Citylist::getInstance()->begin();
         it != Citylist::getInstance()->end(); it++)
     {
@@ -494,34 +489,6 @@ bool CreateScenario::setupCities(bool quick_start,
         //3. set the city production
         (*it).setRandomArmytypes(cities_can_produce_allies, 
 				 number_of_armies_factor);
-        if ((*it).getOwner() == Playerlist::getInstance()->getNeutral())
-        {
-            switch (GameScenario::s_neutral_cities)
-              {
-              case GameParameters::AVERAGE:
-                (*it).produceScout();
-                break;
-              case GameParameters::STRONG:
-                (*it).produceStrongestProductionBase();
-                break;
-              case GameParameters::ACTIVE:
-                if (rand () % 100 >  20)
-                  (*it).produceStrongestProductionBase();
-                else
-                  (*it).produceWeakestProductionBase();
-                break;
-              }
-            (*it).setActiveProductionSlot(-1);
-        }
-        else
-        {
-          if ((*it).isCapital())
-            (*it).produceStrongestProductionBase();
-          else
-            (*it).produceWeakestProductionBase();
-
-            (*it).setActiveProductionSlot(0);
-        }
 
 	if (rand() % 2 == 0)
 	  (*it).raiseDefense();
@@ -637,7 +604,7 @@ bool CreateScenario::setupSignposts(int ratio)
     return true;
 }
 
-bool CreateScenario::setupPlayers(bool diplomacy, bool random_turns, 
+bool CreateScenario::setupPlayers(bool random_turns, 
 				  int base_gold)
 {
     debug("CreateScenario::setupPlayers")
@@ -648,31 +615,6 @@ bool CreateScenario::setupPlayers(bool diplomacy, bool random_turns,
     for (Playerlist::iterator pit = pl->begin(); pit != pl->end(); pit++)
       (*pit)->setGold(base_gold + ((rand() % 8) * 50));
 
-    // Set up diplomacy
-    for (Playerlist::iterator pit = pl->begin(); pit != pl->end(); pit++)
-      {
-	if (pl->getNeutral() == (*pit))
-	  continue;
-	for (Playerlist::iterator it = pl->begin(); it != pl->end(); it++)
-	  {
-	    if (pl->getNeutral() == (*it))
-	      continue;
-	    if (*pit == *it)
-	      continue;
-	    if (diplomacy == false)
-	      {
-		(*pit)->proposeDiplomacy(Player::PROPOSE_WAR, *it);
-		(*pit)->declareDiplomacy(Player::AT_WAR, *it);
-	      }
-	    else 
-	      {
-		(*pit)->proposeDiplomacy(Player::NO_PROPOSAL, *it);
-		(*pit)->declareDiplomacy(Player::AT_PEACE, *it);
-	      }
-	  }
-      }
-    if (diplomacy)
-      pl->calculateDiplomaticRankings();
 
     if (random_turns)
       pl->randomizeOrder();
@@ -695,44 +637,35 @@ bool CreateScenario::setupMapRewards()
     return true;
   //okay, let's make some maps
   //split the terrain into a 3x3 grid
-  Uint32 h_count = 0;
-  Uint32 w_count = 0;
-  for (int i = 0; i < GameMap::getHeight(); i += (GameMap::getHeight() / 3))
-    {
-      for (int j = 0; j < GameMap::getWidth(); j += (GameMap::getWidth() / 3))
-	{
-	  char *name = NULL;
-	  if (h_count == 0 && j == 0)
-	    name = _("northwestern map");
-	  else if (h_count == 0 && w_count == 1)
-	    name = _("northern map");
-	  else if (h_count == 0 && w_count == 2)
-	    name = _("northeastern map");
-	  else if (h_count == 1 && w_count == 0)
-	    name = _("western map");
-	  else if (h_count == 1 && w_count == 1)
-	    name = _("central map");
-	  else if (h_count == 1 && w_count == 2)
-	    name = _("eastern map");
-	  else if (h_count == 2 && w_count == 0)
-	    name = _("southwestern map");
-	  else if (h_count == 2 && w_count == 1)
-	    name = _("southern map");
-	  else if (h_count == 2 && w_count == 2)
-	    name = _("southeastern map");
-	  else
-	    continue;
-
-	  Reward_Map *reward = new Reward_Map(Vector<int>(i, j), name,
-					      GameMap::getHeight() / 3, 
-					      GameMap::getWidth() / 3);
-	    
-	  Rewardlist::getInstance()->push_back(reward); //add it
-	  w_count++;
-	}
-      w_count = 0;
-      h_count++;
-    }
+  Vector<int> step = Vector<int>(GameMap::getWidth() / 3, 
+				 GameMap::getHeight() / 3);
+  Reward_Map *reward = new Reward_Map(Vector<int>(step.x * 0, 0), 
+				      _("Northwestern map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 1, 0), 
+			  _("Northern map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 2, 0), 
+			  _("Northeastern map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 0, step.y * 1), 
+			  _("Western map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 1, step.y * 1), 
+			  _("Central map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 2, step.y * 1), 
+			  _("Eastern map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 0, step.y * 2), 
+			  _("Southwestern map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 1, step.y * 2), 
+			  _("Southern map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 2, step.y * 2), 
+			  _("Southeastern map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
   return true;
 }
 bool CreateScenario::setupRuinRewards()
@@ -748,8 +681,11 @@ bool CreateScenario::setupRuinRewards()
 	    newReward->setName(newReward->getDescription());
 	    Rewardlist::getInstance()->push_back(newReward); //add it
 	  }
-	if ((*it).hasSage() == false)
-	  (*it).populateWithRandomReward();
+	else
+	  {
+	    if ((*it).hasSage() == false && (*it).getReward() == NULL)
+	      (*it).populateWithRandomReward();
+	  }
       }
   return true;
 }
@@ -777,40 +713,6 @@ bool CreateScenario::setupItemRewards()
   return true;
 }
 
-void CreateScenario::quickStart()
-{
-  Playerlist *plist = Playerlist::getInstance();
-  Citylist *clist = Citylist::getInstance();
-  Vector <int> pos;
-  // no neutral cities
-  // divvy up the neutral cities among other non-neutral players
-  int cities_left = clist->size() - plist->size() + 1;
-  unsigned int citycount[MAX_PLAYERS];
-  memset (citycount, 0, sizeof (citycount));
-  Playerlist::iterator pit = plist->begin();
-  for (; pit != plist->end(); pit++)
-    {
-      if (*pit == plist->getNeutral())
-	pit = plist->begin();
-      citycount[(*pit)->getId()]++;
-      cities_left--;
-      if (cities_left == 0)
-	break;
-    }
-  for (unsigned int i = 0; i < MAX_PLAYERS; i++)
-    {
-      for (unsigned int j = 0; j < citycount[i]; j++)
-	{
-	  Player *p = plist->getPlayer(i);
-	  pos = clist->getFirstCity(p)->getPos();
-	  City *c = clist->getNearestNeutralCity(pos);
-	  c->conquer(p);
-	  History_CityWon *item = new History_CityWon();
-	  item->fillData(c);
-	  p->getHistorylist()->push_back(item);
-	}
-    }
-}
 void CreateScenario::getRuinDifficulty (int difficulty, int *sage_factor, 
 					int *no_guardian_factor, 
 					int *stronghold_factor)
