@@ -154,37 +154,49 @@ void MapGenerator::makeMap(int width, int height, bool roads)
    
     // create the terrain
     cout <<_("Flatening Plains  ... 10%") <<endl;
+    progress.emit(.090, _("flattening plains..."));
     makePlains();
     cout <<_("Raining Water     ... 30%") <<endl;
+    progress.emit(.180, _("raining water..."));
     makeTerrain(Tile::WATER, d_pwater, true);  
     makeStreamer(Tile::WATER, d_pwater/3, 3);
     cout <<_("Raising Hills     ... 20%") <<endl;
+    progress.emit(.270, _("raising hills..."));
     makeTerrain(Tile::HILLS, d_phills, false);
     cout <<_("Raising Mountains ... 30%") <<endl;
+    progress.emit(.360, _("raising mountains..."));
     makeTerrain(Tile::MOUNTAIN, d_pmountains, false);
     makeStreamer(Tile::MOUNTAIN, d_pmountains/3, 3);
     cout <<_("Planting Forest   ... 40%") <<endl;
+    progress.emit(.450, _("planting forests..."));
     makeTerrain(Tile::FOREST, d_pforest, false);
     cout <<_("Watering Swamps   ... 50%") <<endl;
+    progress.emit(.540, _("watering swamps..."));
     makeTerrain(Tile::SWAMP, d_pswamp, false);
     cout <<_("Normalizing       ... 60%") <<endl;
+    progress.emit(.630, _("normalizing terrain..."));
     normalize();
            
     // place buildings
     cout <<_("Building Cities   ... 70%") <<endl;
+    progress.emit(.720, _("building cities..."));
     makeCities(d_nocities);
 
     if (roads)
       {
 	cout <<_("Paving Roads      ... 75%") <<endl;
+	progress.emit(.810, _("paving roads..."));
 	makeRoads();
       }
 
     cout <<_("Ruining Ruins     ... 80%") <<endl;
+    progress.emit(.810, _("ruining ruins..."));
     makeBuildings(Maptile::RUIN,d_noruins);
     cout <<_("Raising Signs     ... 88%") <<endl;
+    progress.emit(.900, _("raising signs..."));
     makeBuildings(Maptile::SIGNPOST,d_nosignposts);
     cout <<_("Spawning temples  ... 90%") <<endl;
+    progress.emit(.990, _("spawning temples..."));
     makeBuildings(Maptile::TEMPLE,d_notemples);
     cout <<_("Done making map   ... 100%") <<endl;
 }
