@@ -145,22 +145,29 @@ void NextTurn::startTurn()
 
   p->initTurn();
 
+  //calculate upkeep and income
+  p->calculateUpkeep();
+  p->calculateIncome();
+
   //if turnmode is set, create/heal armies at player's turn
   if (d_turnmode)
     {
-      //pay upkeep for stacks, reset moves, and heal stacks
-      p->getStacklist()->nextTurn();
 
       //if (p->getType() != Player::NETWORKED)
       
+      //collect taxes
+      Citylist::getInstance()->collectTaxes(p);
+
+      //pay upkeep for existing stacks, reset moves, and heal stacks
+      p->getStacklist()->nextTurn();
+
       //vector armies (needs to preceed city's next turn)
       VectoredUnitlist::getInstance()->nextTurn(p);
 
-      //build armies
+      //build new armies
       Citylist::getInstance()->nextTurn(p);
-    }
 
-  //calculate upkeep
+    }
   p->calculateUpkeep();
 
   QuestsManager::getInstance()->nextTurn(p);
@@ -191,12 +198,18 @@ void NextTurn::finishRound()
 	  if ((*it)->isDead())
 	    continue;
 
-	  //produce armies
-	  Citylist::getInstance()->nextTurn(*it);
+	  //collect monies from cities
+	  Citylist::getInstance()->collectTaxes(*it);
 
-	  //heal armies
+	  //pay for existing armies, reset, and heal armies
 	  (*it)->getStacklist()->nextTurn();
 
+	  //vector armies (needs to preceed city's next turn)
+	  VectoredUnitlist::getInstance()->nextTurn(*it);
+
+	  //produce new armies
+	  Citylist::getInstance()->nextTurn(*it);
+
 	}
     }
 
