@@ -1,3 +1,7 @@
+// Copyright (C) 2003, 2004, 2005, 2006 Ulf Lorenz
+// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008 Ole Laursen
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +14,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #ifndef NEXT_TURN_H
 #define NEXT_TURN_H
@@ -68,13 +73,12 @@ class NextTurn: public sigc::trackable
          */
         void endTurn();
 
+        void setContinuingTurn() { continuing_turn = true; }
+        
         /**
            \brief signals for announcing events
-
-           If the splayerStart signal returns true, the main loop will quit,
-           which is useful if a human player's turn starts.
          */
-        sigc::signal<bool, Player*> splayerStart;
+        sigc::signal<void, Player*> splayerStart;
 
 	// emitted whenever a new player's turn starts.
         sigc::signal<void, Player*> snextTurn;
@@ -122,6 +126,8 @@ class NextTurn: public sigc::trackable
         //! If set to true, the game is interrupted at the next occasion
         bool d_stop;
 
+        // whether we're starting a turn again from loading a game
+        bool continuing_turn;
 };
 
 #endif //NEXT_TURN_H
