@@ -1,3 +1,5 @@
+//  Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +12,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #include <iostream>
 #include <sstream>
@@ -35,7 +38,7 @@ QuestCityRaze::QuestCityRaze (QuestsManager& mgr, Uint32 hero)
     : Quest(mgr, hero, Quest::CITYRAZE)
 {
     // find us a victim
-    City* c = chooseToRaze(getHero()->getPlayer());
+    City* c = chooseToRaze(getHero()->getOwner());
     assert(c);      // should never fail because isFeasible is checked first
 
     d_city = c->getId();
@@ -52,9 +55,17 @@ QuestCityRaze::QuestCityRaze (QuestsManager& q_mgr, XML_Helper* helper)
     initDescription();
 }
 //=======================================================================
+QuestCityRaze::QuestCityRaze (QuestsManager& mgr, Uint32 hero, Uint32 target) 
+    : Quest(mgr, hero, Quest::CITYRAZE)
+{
+    d_city = target;
+    d_targets.push_back(getCity()->getPos());
+    initDescription();
+}
+//=======================================================================
 bool QuestCityRaze::isFeasible(Uint32 heroId)
 {
-  if (QuestCityRaze::chooseToRaze(getHeroById(heroId)->getPlayer()))
+  if (QuestCityRaze::chooseToRaze(getHeroById(heroId)->getOwner()))
     return true;
 
   return false;
@@ -121,8 +132,8 @@ City* QuestCityRaze::chooseToRaze(Player *p)
     // Collect all cities
     Citylist* cl = Citylist::getInstance();
     for (Citylist::iterator it = cl->begin(); it != cl->end(); ++it)
-        if (!(*it).isBurnt() && (*it).getPlayer() != p &&
-	    (*it).getPlayer() != Playerlist::getInstance()->getNeutral())
+        if (!(*it).isBurnt() && (*it).getOwner() != p &&
+	    (*it).getOwner() != Playerlist::getInstance()->getNeutral())
             cities.push_back(&(*it));
 
     // Find a suitable city for us to raze 
@@ -155,13 +166,13 @@ void QuestCityRaze::cityAction(City *c, CityDefeatedAction action,
     case CITY_DEFEATED_OCCUPY: //somebody occupied
       if (heroIsCulprit) //quest hero did
 	d_q_mgr.questExpired(d_hero);
-      else if (c->getPlayer() == getHero()->getPlayer()) //our stack did
+      else if (c->getOwner() == getHero()->getOwner()) //our stack did
 	d_q_mgr.questExpired(d_hero);
       break;
     case CITY_DEFEATED_RAZE: //somebody razed
       if (heroIsCulprit) // quest hero
 	d_q_mgr.questCompleted(d_hero);
-      else if (c->getPlayer() == getHero()->getPlayer()) // our stack razed
+      else if (c->getOwner() == getHero()->getOwner()) // our stack razed
 	d_q_mgr.questExpired(d_hero);
       else // their stack did
 	d_q_mgr.questExpired(d_hero);
@@ -169,13 +180,13 @@ void QuestCityRaze::cityAction(City *c, CityDefeatedAction action,
     case CITY_DEFEATED_SACK: //somebody sacked
       if (heroIsCulprit) // quest hero did
 	d_q_mgr.questExpired(d_hero);
-      else if (c->getPlayer() == getHero()->getPlayer()) // our stack did
+      else if (c->getOwner() == getHero()->getOwner()) // our stack did
 	d_q_mgr.questExpired(d_hero);
       break;
     case CITY_DEFEATED_PILLAGE: //somebody pillaged
       if (heroIsCulprit) // quest hero did
 	d_q_mgr.questExpired(d_hero);
-      else if (c->getPlayer() == getHero()->getPlayer()) // our stack did
+      else if (c->getOwner() == getHero()->getOwner()) // our stack did
 	d_q_mgr.questExpired(d_hero);
       break;
     }
