@@ -1,3 +1,8 @@
+// Copyright (C) 2003, 2004, 2005 Ulf Lorenz
+// Copyright (C) 2004 Andrea Paternesi
+// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008 Ole Laursen
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +15,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #include <sstream>
 #include <sigc++/functors/mem_fun.h>
@@ -62,8 +68,7 @@ QuestEnemyArmies::QuestEnemyArmies(QuestsManager& q_mgr, Uint32 hero)
     : Quest(q_mgr, hero, Quest::KILLARMIES), d_killed(0)
 {
     // have us be informed when hostilities break out
-    d_victim_player = getVictimPlayer(getHero()->getPlayer());
-    d_victim_player->sdyingArmy.connect( sigc::mem_fun(*this, &QuestEnemyArmies::dyingArmy));
+    d_victim_player = getVictimPlayer(getHero()->getOwner());
     
     /** we have to kill 14-20 units: 14 + rand(0..6) */
     d_to_kill = 14 + (rand() % 7);
@@ -82,11 +87,20 @@ QuestEnemyArmies::QuestEnemyArmies(QuestsManager& q_mgr, XML_Helper* helper)
     helper->getData(ui, "victim_player");
 
     d_victim_player = Playerlist::getInstance()->getPlayer(ui);
-    // we want to be informed about fight causalties
-    d_victim_player->sdyingArmy.connect( sigc::mem_fun(*this, &QuestEnemyArmies::dyingArmy));
 
     update_targets();
+    initDescription();
+}
+//=======================================================================
+QuestEnemyArmies::QuestEnemyArmies(QuestsManager& q_mgr, Uint32 hero,
+                                   Uint32 armies_to_kill, Uint32 victim_player)
+    : Quest(q_mgr, hero, Quest::KILLARMIES), d_killed(0)
+{
+    // have us be informed when hostilities break out
+    d_victim_player = Playerlist::getInstance()->getPlayer(victim_player);
+    d_to_kill = armies_to_kill;
 
+    update_targets();
     initDescription();
 }
 //=======================================================================
@@ -125,29 +139,6 @@ void QuestEnemyArmies::getExpiredMsg(std::queue<std::string>& msgs) const
     // This quest should never expire, so this is just a dummy function
 }
 //=======================================================================
-void QuestEnemyArmies::dyingArmy(Army *army, std::vector<Uint32> culprits)
-{
-    debug("QuestEnemyArmies: dyingArmy - pending = " << (int)d_pending);
-
-    if (!isActive())
-        return;
-    
-    // did our hero kill them?
-    for (unsigned int i = 0; i < culprits.size(); i++)
-    {
-        if (culprits[i] == d_hero)
-        {
-            d_killed++;
-            if (d_killed >= d_to_kill)
-            {
-                debug("CONGRATULATIONS: QUEST 'ENEMY ARMIES' IS COMPLETED!");
-                d_q_mgr.questCompleted(d_hero);
-            }
-            break;
-        }
-    }
-}
-//=======================================================================
 void QuestEnemyArmies::initDescription()
 {
     char buffer[101]; buffer[100]='\0';
@@ -159,16 +150,17 @@ void QuestEnemyArmies::initDescription()
 
 bool QuestEnemyArmies::isFeasible(Uint32 heroId)
 {
-  if (getVictimPlayer(getHeroById(heroId)->getPlayer()))
+  if (getVictimPlayer(getHeroById(heroId)->getOwner()))
     return true;
   return false;
 }
+
 void QuestEnemyArmies::armyDied(Army *a, bool heroIsCulprit)
 {
   if (!isActive())
     return;
 
-  if (heroIsCulprit == true && a->getPlayer() == d_victim_player)
+  if (heroIsCulprit == true && a->getOwner() == d_victim_player)
     {
       d_killed++;
       if (d_killed >= d_to_kill)
