@@ -1,3 +1,5 @@
+//  Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +12,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #include <sstream>
 #include <sigc++/functors/mem_fun.h>
@@ -66,8 +69,7 @@ int getVictimArmytype(Player *p, std::list<Vector<int> >&targets)
 QuestEnemyArmytype::QuestEnemyArmytype(QuestsManager& q_mgr, Uint32 hero)
     : Quest(q_mgr, hero, Quest::KILLARMYTYPE)
 {
-    // have us be informed when hostilities break out
-    Player *p = getHero()->getPlayer();
+    Player *p = getHero()->getOwner();
     
     // pick a victim
     d_type_to_kill = getVictimArmytype (p, d_targets);
@@ -83,6 +85,16 @@ QuestEnemyArmytype::QuestEnemyArmytype(QuestsManager& q_mgr, XML_Helper* helper)
     initDescription();
 }
 //=======================================================================
+QuestEnemyArmytype::QuestEnemyArmytype(QuestsManager& q_mgr, Uint32 hero,
+                                       Uint32 type_to_kill)
+    : Quest(q_mgr, hero, Quest::KILLARMYTYPE)
+{
+    // pick a victim
+    d_type_to_kill = type_to_kill;
+    
+    initDescription();
+}
+//=======================================================================
 bool QuestEnemyArmytype::save(XML_Helper *helper) const
 {
     bool retval = true;
@@ -98,7 +110,6 @@ bool QuestEnemyArmytype::save(XML_Helper *helper) const
 std::string QuestEnemyArmytype::getProgress() const
 {
     Armysetlist *al = Armysetlist::getInstance();
-    //FIXME: we're picking a type that *we* own, not what our enemy owns
     Uint32 set = Playerlist::getInstance()->getActiveplayer()->getArmyset();
     const Army *a = al->getArmy(set, d_type_to_kill);
     char buffer[101]; buffer[100]='\0';
@@ -139,7 +150,7 @@ void QuestEnemyArmytype::initDescription()
 bool QuestEnemyArmytype::isFeasible(Uint32 heroId)
 {
   std::list< Vector<int> >targets;
-  int type = getVictimArmytype(getHeroById(heroId)->getPlayer(), targets);
+  int type = getVictimArmytype(getHeroById(heroId)->getOwner(), targets);
   if (type >= 0)
     return true;
   return false;
