@@ -1,3 +1,8 @@
+// Copyright (C) 2003, 2004, 2005 Ulf Lorenz
+// Copyright (C) 2004 Andrea Paternesi
+// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2008 Ole Laursen
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +15,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #include <iostream>
 #include <sstream>
@@ -36,7 +42,7 @@ QuestKillHero::QuestKillHero(QuestsManager& mgr, Uint32 hero)
     assert(hunted);         // should never fail, since isFeasible is checked
 
     d_victim = hunted->getId();
-    d_targets.push_back(hunted->getPlayer()->getStacklist()->getPosition(d_victim));
+    d_targets.push_back(hunted->getOwner()->getStacklist()->getPosition(d_victim));
     initDescription();
 }
 //=======================================================================
@@ -49,7 +55,20 @@ QuestKillHero::QuestKillHero(QuestsManager& q_mgr, XML_Helper* helper)
     // double and triple check :)
     Hero *hero = Quest::getHeroById(d_victim);
     assert(hero);
-    d_targets.push_back(hero->getPlayer()->getStacklist()->getPosition(d_victim));
+    d_targets.push_back(hero->getOwner()->getStacklist()->getPosition(d_victim));
+
+    initDescription();
+}
+//=======================================================================
+QuestKillHero::QuestKillHero(QuestsManager& q_mgr, Uint32 hero, Uint32 victim) 
+    : Quest(q_mgr, hero, Quest::KILLHERO)
+{
+    d_victim = victim;
+
+    // double and triple check :)
+    Hero *h = Quest::getHeroById(d_victim);
+    assert(h);
+    d_targets.push_back(h->getOwner()->getStacklist()->getPosition(d_victim));
 
     initDescription();
 }
@@ -110,7 +129,7 @@ void QuestKillHero::initDescription()
     Hero* v = Quest::getHeroById(d_victim);
     
     snprintf(buffer, 100, _("Kill the hero named %s, servant of player %s"),
-            v->getName().c_str(), v->getPlayer()->getName().c_str());
+            v->getName().c_str(), v->getOwner()->getName().c_str());
     
     d_description = std::string(buffer);
 }
