@@ -1,3 +1,5 @@
+//  Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +12,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #include <sstream>
 #include <sigc++/functors/mem_fun.h>
@@ -43,6 +46,14 @@ QuestPillageGold::QuestPillageGold(QuestsManager& q_mgr, XML_Helper* helper)
     initDescription();
 }
 //=======================================================================
+QuestPillageGold::QuestPillageGold(QuestsManager& q_mgr, Uint32 hero, Uint32 gold)
+    : Quest(q_mgr, hero, Quest::PILLAGEGOLD), d_pillaged(0)
+{
+    d_to_pillage = gold;
+
+    initDescription();
+}
+//=======================================================================
 bool QuestPillageGold::save(XML_Helper *helper) const
 {
     bool retval = true;
