@@ -142,43 +142,74 @@ Quest* QuestsManager::createNewQuest(Uint32 heroId, bool razing_possible)
     
     return quest;
 }
-//========================================================================
-Quest* QuestsManager::createNewQuest(Uint32 hero, Uint32 questtype,
-                                     Uint32 data, Uint32 victim_player)
+
+Quest* QuestsManager::createNewKillHeroQuest(Uint32 heroId, Uint32 targetHeroId)
 {
-  Quest *quest = NULL;
-  switch (Quest::Type(questtype))
-  {
-  case Quest::KILLHERO:
-    quest = new QuestKillHero(*this, hero, data);
-    break;
-  case Quest::KILLARMIES:
-    quest = new QuestEnemyArmies(*this, hero, data, victim_player);
-    break;
-  case Quest::CITYSACK:
-    quest = new QuestCitySack(*this, hero, data);
-    break;
-  case Quest::CITYRAZE:
-    quest = new QuestCityRaze(*this, hero, data);
-    break;
-  case Quest::CITYOCCUPY:
-    quest = new QuestCityOccupy(*this, hero, data);
-    break;
-  case Quest::KILLARMYTYPE:
-    quest = new QuestEnemyArmytype(*this, hero, data);
-    break;
-  case Quest::PILLAGEGOLD:
-    quest = new QuestPillageGold(*this, hero, data);
-    break;
-  }
+  Quest *quest = new QuestKillHero(*this, heroId, targetHeroId);
     
-  if (quest)
-  {
-    d_quests[hero] = quest;
-  }
+  d_quests[heroId] = quest;
   
   return quest;
 }
+
+Quest* QuestsManager::createNewEnemyArmiesQuest(Uint32 heroId, 
+						Uint32 num_armies, 
+						Uint32 victim_player_id)
+{
+  Quest *quest = new QuestEnemyArmies(*this, heroId, num_armies, 
+				      victim_player_id);
+    
+  d_quests[heroId] = quest;
+  
+  return quest;
+}
+
+Quest* QuestsManager::createNewCitySackQuest(Uint32 heroId, Uint32 cityId)
+{
+  Quest *quest = new QuestCitySack(*this, heroId, cityId);
+
+  d_quests[heroId] = quest;
+  
+  return quest;
+}
+
+Quest* QuestsManager::createNewCityRazeQuest(Uint32 heroId, Uint32 cityId)
+{
+  Quest *quest = new QuestCityRaze(*this, heroId, cityId);
+
+  d_quests[heroId] = quest;
+  
+  return quest;
+}
+
+Quest* QuestsManager::createNewCityOccupyQuest(Uint32 heroId, Uint32 cityId)
+{
+  Quest *quest = new QuestCityOccupy(*this, heroId, cityId);
+
+  d_quests[heroId] = quest;
+  
+  return quest;
+}
+
+Quest* QuestsManager::createNewEnemyArmytypeQuest(Uint32 heroId, 
+						  Uint32 armyTypeId)
+{
+  Quest *quest = new QuestEnemyArmytype(*this, heroId, armyTypeId);
+
+  d_quests[heroId] = quest;
+  
+  return quest;
+}
+
+Quest* QuestsManager::createNewPillageGoldQuest(Uint32 heroId, Uint32 amount)
+{
+  Quest *quest = new QuestPillageGold(*this, heroId, amount);
+
+  d_quests[heroId] = quest;
+  
+  return quest;
+}
+
 //========================================================================
 void QuestsManager::questCompleted(Uint32 heroId)
 {
@@ -192,7 +223,7 @@ void QuestsManager::questCompleted(Uint32 heroId)
       {
 	int gold = Reward_Gold::getRandomGoldPieces();
         Reward_Gold reward(gold);
-        p->giveReward(NULL, &reward);
+        p->giveReward(p->getActivestack(), &reward);
         quest_completed.emit(quest, &reward);
       }
     else if (num == 1)
@@ -205,7 +236,7 @@ void QuestsManager::questCompleted(Uint32 heroId)
 	    
 	History_HeroFindsAllies* item = new History_HeroFindsAllies();
 	item->fillData(quest->getHero());
-	p->getHistorylist()->push_back(item);
+	p->addHistory(item);
       }
     else if (num == 2)
       {
@@ -219,7 +250,7 @@ void QuestsManager::questCompleted(Uint32 heroId)
           {
 	    int gold = Reward_Gold::getRandomGoldPieces();
             Reward_Gold reward(gold);
-            p->giveReward(NULL, &reward);
+            p->giveReward(p->getActivestack(), &reward);
             quest_completed.emit(quest, &reward);
           }
       }
@@ -235,7 +266,7 @@ void QuestsManager::questCompleted(Uint32 heroId)
           {
             int gold = Reward_Gold::getRandomGoldPieces();
             Reward_Gold reward(gold);
-            p->giveReward(NULL, &reward);
+            p->giveReward(p->getActivestack(), &reward);
             quest_completed.emit(quest, &reward);
           }
       }
