@@ -51,12 +51,16 @@ Action::Action(Type type)
 {
 }
 
+Action::Action(const Action &action)
+:d_type(action.d_type)
+{
+
+}
 Action::Action(XML_Helper *helper)
 {
   Uint32 t;
   helper->getData(t, "type");
   d_type = Action::Type(t);
-  helper->getData(d_player, "player");
 }
 
 Action::~Action()
@@ -68,14 +72,22 @@ bool Action::save(XML_Helper* helper) const
     bool retval = true;
 
     retval &= helper->openTag("action");
-    retval &= helper->saveData("type", d_type);
-    retval &= helper->saveData("player", d_player);
-    retval &= doSave(helper);
+    retval &= saveContents(helper);
     retval &= helper->closeTag();
 
     return retval;
 }
 
+bool Action::saveContents(XML_Helper* helper) const
+{
+    bool retval = true;
+
+    retval &= helper->saveData("type", d_type);
+    retval &= doSave(helper);
+
+    return retval;
+}
+
 Action* Action::handle_load(XML_Helper* helper)
 {
     Uint32 t;
@@ -147,11 +159,16 @@ Action* Action::handle_load(XML_Helper* helper)
             return (new Action_ConquerCity(helper));
         case RECRUIT_HERO:
             return (new Action_RecruitHero(helper));
+        case PLAYER_RENAME:
+            return (new Action_RenamePlayer(helper));
+        case CITY_DESTITUTE:
+            return (new Action_CityTooPoorToProduce(helper));
     }
 
     return 0;
 }
 
+
 Action* Action::copy(const Action* a)
 {
     switch(a->getType())
@@ -234,6 +251,14 @@ Action* Action::copy(const Action* a)
             return 
               (new Action_RecruitHero
                 (*dynamic_cast<const Action_RecruitHero*>(a)));
+        case PLAYER_RENAME:
+            return 
+              (new Action_RenamePlayer
+                (*dynamic_cast<const Action_RenamePlayer*>(a)));
+        case CITY_DESTITUTE:
+            return 
+              (new Action_CityTooPoorToProduce
+                (*dynamic_cast<const Action_CityTooPoorToProduce*>(a)));
     }
 
     return 0;
@@ -248,6 +273,11 @@ Action_Move::Action_Move()
     d_dest.x = d_dest.y = 0;
 }
 
+Action_Move::Action_Move (const Action_Move &action)
+:Action(action), d_stack(action.d_stack), d_dest(action.d_dest)
+{
+}
+
 Action_Move::Action_Move(XML_Helper* helper)
     :Action(helper)
 {
@@ -302,6 +332,14 @@ Action_Split::Action_Split()
         d_armies_moved[i] = 0;
 }
 
+Action_Split::Action_Split(const Action_Split &action)
+: Action(action), d_orig(action.d_orig), 
+    d_added(action.d_added)
+{
+  for (unsigned int i = 0; i < MAX_STACK_SIZE; i++)
+    d_armies_moved[i] = action.d_armies_moved[i];
+}
+
 Action_Split::Action_Split(XML_Helper* helper)
     :Action(helper)
 {
@@ -384,6 +422,12 @@ Action_Fight::Action_Fight()
 {
 }
 
+Action_Fight::Action_Fight(const Action_Fight &action)
+: Action(action), d_history(action.d_history), d_attackers(action.d_attackers), 
+    d_defenders(action.d_defenders)
+{
+}
+
 Action_Fight::Action_Fight(XML_Helper* helper)
     :Action(helper)
 {
@@ -495,6 +539,11 @@ Action_Join::Action_Join()
 {
 }
 
+Action_Join::Action_Join(const Action_Join &action)
+: Action(action), d_orig_id(action.d_orig_id), d_joining_id(action.d_joining_id)
+{
+}
+
 Action_Join::Action_Join(XML_Helper* helper)
     :Action(helper)
 {
@@ -551,6 +600,12 @@ Action_Ruin::Action_Ruin()
 {
 }
 
+Action_Ruin::Action_Ruin(const Action_Ruin&action)
+: Action(action), d_ruin(action.d_ruin), d_stack(action.d_stack),
+    d_searched(action.d_searched)
+{
+}
+
 Action_Ruin::Action_Ruin(XML_Helper* helper)
     :Action(helper)
 {
@@ -567,7 +622,7 @@ std::string Action_Ruin::dump() const
 {
     std::stringstream s;
 
-    s <<"Ruin " <<d_ruin <<" searched by stack " <<d_stack <<".\n";
+    s <<"Ruin " <<d_ruin <<" searched by stack " <<d_stack <<".  ";
     s <<"Ruin has" <<(d_searched? " ":" not ") <<"been searched.\n";
 
     return s.str();
@@ -602,6 +657,11 @@ Action_Temple::Action_Temple()
 {
 }
 
+Action_Temple::Action_Temple(const Action_Temple &action)
+: Action(action), d_temple(action.d_temple), d_stack(action.d_stack)
+{
+}
+
 Action_Temple::Action_Temple(XML_Helper* helper)
     :Action(helper)
 {
@@ -649,6 +709,11 @@ Action_Occupy::Action_Occupy()
 {
 }
 
+Action_Occupy::Action_Occupy(const Action_Occupy &action)
+: Action(action), d_city(action.d_city)
+{
+}
+
 Action_Occupy::Action_Occupy(XML_Helper* helper)
     :Action(helper)
 {
@@ -691,6 +756,11 @@ Action_Pillage::Action_Pillage()
 {
 }
 
+Action_Pillage::Action_Pillage(const Action_Pillage &action)
+: Action(action), d_city(action.d_city)
+{
+}
+
 Action_Pillage::Action_Pillage(XML_Helper* helper)
     :Action(helper)
 {
@@ -731,6 +801,11 @@ Action_Sack::Action_Sack()
 {
 }
 
+Action_Sack::Action_Sack(const Action_Sack &action)
+: Action(action), d_city(action.d_city)
+{
+}
+
 Action_Sack::Action_Sack(XML_Helper* helper)
     :Action(helper)
 {
@@ -771,6 +846,11 @@ Action_Raze::Action_Raze()
 {
 }
 
+Action_Raze::Action_Raze(const Action_Raze &action)
+: Action(action), d_city(action.d_city)
+{
+}
+
 Action_Raze::Action_Raze(XML_Helper* helper)
     :Action(helper)
 {
@@ -813,6 +893,11 @@ Action_Upgrade::Action_Upgrade()
 {
 }
 
+Action_Upgrade::Action_Upgrade(const Action_Upgrade &action)
+: Action(action), d_city(action.d_city)
+{
+}
+
 Action_Upgrade::Action_Upgrade(XML_Helper* helper)
     :Action(helper)
 {
@@ -855,6 +940,12 @@ Action_Buy::Action_Buy()
 {
 }
 
+Action_Buy::Action_Buy(const Action_Buy &action)
+: Action(action), d_city(action.d_city), d_slot(action.d_slot), 
+    d_prod(action.d_prod)
+{
+}
+
 Action_Buy::Action_Buy(XML_Helper* helper)
     :Action(helper)
 {
@@ -905,6 +996,11 @@ Action_Production::Action_Production()
 {
 }
 
+Action_Production::Action_Production (const Action_Production &action)
+: Action(action), d_city(action.d_city), d_prod(action.d_prod)
+{
+}
+
 Action_Production::Action_Production(XML_Helper* helper)
     :Action(helper)
 {
@@ -975,6 +1071,12 @@ bool Action_Reward::load(std::string tag, XML_Helper *helper)
     return false;
 }
 
+Action_Reward::Action_Reward (const Action_Reward &action)
+: Action(action), d_stack(action.d_stack)
+{
+  d_reward = new Reward(*action.d_reward);
+}
+
 Action_Reward::Action_Reward(XML_Helper* helper)
 :Action(helper)
 {
@@ -1030,6 +1132,12 @@ Action_Quest::Action_Quest()
 {
 }
 
+Action_Quest::Action_Quest (const Action_Quest &action)
+: Action(action), d_hero(action.d_hero), d_questtype(action.d_questtype),
+    d_data(action.d_data), d_victim_player(action.d_victim_player)
+{
+}
+
 Action_Quest::Action_Quest(XML_Helper* helper)
 :Action(helper)
 {
@@ -1109,6 +1217,12 @@ Action_Equip::Action_Equip()
 {
 }
 
+Action_Equip::Action_Equip (const Action_Equip &action)
+: Action(action), d_hero(action.d_hero), d_item(action.d_item),
+    d_slot(action.d_slot)
+{
+}
+
 Action_Equip::Action_Equip(XML_Helper* helper)
 :Action(helper)
 {
@@ -1159,6 +1273,11 @@ Action_Level::Action_Level()
 {
 }
 
+Action_Level::Action_Level (const Action_Level &action)
+: Action(action), d_army(action.d_army), d_stat(action.d_stat)
+{
+}
+
 Action_Level::Action_Level(XML_Helper* helper)
 :Action(helper)
 {
@@ -1206,6 +1325,11 @@ Action_Disband::Action_Disband()
 {
 }
 
+Action_Disband::Action_Disband(const Action_Disband &action)
+: Action(action), d_stack(action.d_stack)
+{
+}
+
 Action_Disband::Action_Disband(XML_Helper* helper)
 :Action(helper)
 {
@@ -1244,7 +1368,12 @@ bool Action_Disband::fillData(Stack* s)
 //Action_ModifySignpost
 
 Action_ModifySignpost::Action_ModifySignpost()
-	:Action(Action::MODIFY_SIGNPOST), d_signpost(0), d_message("")
+:Action(Action::MODIFY_SIGNPOST), d_signpost(0), d_message("")
+{
+}
+
+Action_ModifySignpost::Action_ModifySignpost(const Action_ModifySignpost &action)
+: Action(action), d_signpost(action.d_signpost), d_message(action.d_message)
 {
 }
 
@@ -1289,7 +1418,12 @@ bool Action_ModifySignpost::fillData(Signpost * s, std::string message)
 //Action_RenameCity
 
 Action_RenameCity::Action_RenameCity()
-	:Action(Action::CITY_RENAME), d_city(0), d_name("")
+:Action(Action::CITY_RENAME), d_city(0), d_name("")
+{
+}
+
+Action_RenameCity::Action_RenameCity(const Action_RenameCity &action)
+: Action(action), d_city(action.d_city), d_name(action.d_name)
 {
 }
 
@@ -1338,6 +1472,11 @@ Action_Vector::Action_Vector()
 {
 }
 
+Action_Vector::Action_Vector(const Action_Vector &action)
+: Action(action), d_city(action.d_city), d_dest(action.d_dest)
+{
+}
+
 Action_Vector::Action_Vector(XML_Helper* helper)
 :Action(helper)
 {
@@ -1389,6 +1528,11 @@ Action_FightOrder::Action_FightOrder()
 {
 }
 
+Action_FightOrder::Action_FightOrder(const Action_FightOrder &action)
+: Action(action), d_order(action.d_order)
+{
+}
+
 Action_FightOrder::Action_FightOrder(XML_Helper* helper)
 :Action(helper)
 {
@@ -1453,6 +1597,11 @@ Action_Resign::Action_Resign()
 {
 }
 
+Action_Resign::Action_Resign(const Action_Resign &action)
+: Action(action)
+{
+}
+
 Action_Resign::Action_Resign(XML_Helper* helper)
 :Action(helper)
 {
@@ -1490,6 +1639,11 @@ Action_Plant::Action_Plant()
 {
 }
 
+Action_Plant::Action_Plant(const Action_Plant &action)
+: Action(action), d_hero(action.d_hero), d_item(action.d_item)
+{
+}
+
 Action_Plant::Action_Plant(XML_Helper* helper)
 :Action(helper)
 {
@@ -1534,6 +1688,12 @@ Action_Produce::Action_Produce()
 {
 }
 
+Action_Produce::Action_Produce(const Action_Produce &action)
+: Action(action), d_army_type(action.d_army_type), d_city(action.d_city),
+    d_vectored(action.d_vectored)
+{
+}
+
 Action_Produce::Action_Produce(XML_Helper* helper)
 :Action(helper)
 {
@@ -1587,6 +1747,11 @@ Action_ProduceVectored::Action_ProduceVectored()
 {
 }
 
+Action_ProduceVectored::Action_ProduceVectored(const Action_ProduceVectored &action)
+: Action(action), d_army_type(action.d_army_type), d_dest(action.d_dest)
+{
+}
+
 Action_ProduceVectored::Action_ProduceVectored(XML_Helper* helper)
 :Action(helper)
 {
@@ -1637,6 +1802,12 @@ Action_DiplomacyState::Action_DiplomacyState()
 {
 }
 
+Action_DiplomacyState::Action_DiplomacyState(const Action_DiplomacyState &action)
+: Action(action), d_opponent_id(action.d_opponent_id), 
+    d_diplomatic_state(action.d_diplomatic_state)
+{
+}
+
 Action_DiplomacyState::Action_DiplomacyState(XML_Helper* helper)
 :Action(helper)
 {
@@ -1691,6 +1862,12 @@ Action_DiplomacyProposal::Action_DiplomacyProposal()
 {
 }
 
+Action_DiplomacyProposal::Action_DiplomacyProposal(const Action_DiplomacyProposal &action)
+: Action(action), d_opponent_id(action.d_opponent_id), 
+	d_diplomatic_proposal(action.d_diplomatic_proposal)
+{
+}
+
 Action_DiplomacyProposal::Action_DiplomacyProposal(XML_Helper* helper)
 :Action(helper)
 {
@@ -1746,6 +1923,11 @@ Action_DiplomacyScore::Action_DiplomacyScore()
 {
 }
 
+Action_DiplomacyScore::Action_DiplomacyScore(const Action_DiplomacyScore &action)
+: Action(action), d_opponent_id(action.d_opponent_id), d_amount(action.d_amount)
+{
+}
+
 Action_DiplomacyScore::Action_DiplomacyScore(XML_Helper* helper)
 :Action(helper)
 {
@@ -1794,6 +1976,11 @@ Action_EndTurn::Action_EndTurn()
 {
 }
 
+Action_EndTurn::Action_EndTurn(const Action_EndTurn &action)
+: Action(action)
+{
+}
+
 Action_EndTurn::Action_EndTurn(XML_Helper* helper)
 :Action(helper)
 {
@@ -1823,6 +2010,11 @@ Action_ConquerCity::Action_ConquerCity()
 {
 }
 
+Action_ConquerCity::Action_ConquerCity(const Action_ConquerCity &action)
+: Action(action), d_city(action.d_city), d_stack(action.d_stack)
+{
+}
+
 Action_ConquerCity::Action_ConquerCity(XML_Helper* helper)
   :Action(helper)
 {
@@ -1878,6 +2070,13 @@ Action_RecruitHero::Action_RecruitHero(XML_Helper* helper)
     helper->registerTag("hero", sigc::mem_fun(this, &Action_RecruitHero::load));
 }
 
+Action_RecruitHero::Action_RecruitHero(const Action_RecruitHero &action)
+: Action(action), d_city(action.d_city), d_cost(action.d_cost), 
+    d_allies(action.d_allies), d_ally_army_type(action.d_ally_army_type)
+{
+  d_hero = new Hero(*action.d_hero);
+}
+
 bool Action_RecruitHero::load(std::string tag, XML_Helper *helper)
 {
     if (tag == "hero")
@@ -1927,3 +2126,103 @@ bool Action_RecruitHero::fillData(Hero* hero, City *city, int cost, int alliesCo
       d_ally_army_type = 0;
     return true;
 }
+
+//-----------------------------------------------------------------------------
+//Action_RenamePlayer
+
+Action_RenamePlayer::Action_RenamePlayer()
+  :Action(Action::PLAYER_RENAME), d_name("")
+{
+}
+
+Action_RenamePlayer::Action_RenamePlayer(const Action_RenamePlayer &action)
+:Action(action), d_name(action.d_name)
+{
+}
+
+Action_RenamePlayer::Action_RenamePlayer(XML_Helper* helper)
+  :Action(helper)
+{
+    helper->getData(d_name, "name");
+}
+
+Action_RenamePlayer::~Action_RenamePlayer()
+{
+}
+
+std::string Action_RenamePlayer::dump() const
+{
+    std::stringstream s;
+
+    s << "Player changes name to " << d_name <<".\n";
+
+    return s.str();
+}
+
+bool Action_RenamePlayer::doSave(XML_Helper* helper) const
+{
+    bool retval = true;
+
+    retval &= helper->saveData("name", d_name);
+
+    return retval;
+}
+
+bool Action_RenamePlayer::fillData(std::string name)
+{
+  d_name = name;
+  return true;
+}
+
+//-----------------------------------------------------------------------------
+//Action_CityTooPoorToProduce
+
+Action_CityTooPoorToProduce::Action_CityTooPoorToProduce()
+    :Action(Action::CITY_DESTITUTE), d_city(0), d_army_type(0)
+{
+}
+
+Action_CityTooPoorToProduce::Action_CityTooPoorToProduce(const Action_CityTooPoorToProduce &action)
+: Action(action), d_city(action.d_city), d_army_type(action.d_army_type)
+{
+}
+
+Action_CityTooPoorToProduce::Action_CityTooPoorToProduce(XML_Helper* helper)
+    :Action(helper)
+{
+    helper->getData(d_city, "city");
+    helper->getData(d_army_type, "army_type");
+}
+
+Action_CityTooPoorToProduce::~Action_CityTooPoorToProduce()
+{
+}
+
+std::string Action_CityTooPoorToProduce::dump() const
+{
+    std::stringstream s;
+
+    s << "City " << d_city << " is too poor to produce army type " 
+      << d_army_type << "\n";
+
+    return s.str();
+}
+
+bool Action_CityTooPoorToProduce::doSave(XML_Helper* helper) const
+{
+    bool retval = true;
+
+    retval &= helper->saveData("city", d_city);
+    retval &= helper->saveData("army_type", d_army_type);
+
+    return retval;
+}
+
+bool Action_CityTooPoorToProduce::fillData(City* c, const Army *army)
+{
+    d_city = c->getId();
+    d_army_type = army->getType();
+
+    return true;
+}
+
