@@ -29,6 +29,7 @@
 #include "army.h"
 #include "reward.h"
 #include "player.h"
+#include "Ownable.h"
 
 class Quest;
 class Stack;
@@ -127,13 +128,19 @@ class Action
 		DIPLOMATIC_SCORE = 29,
                 END_TURN = 30,
                 CITY_CONQUER = 31,
-                RECRUIT_HERO = 32
+                RECRUIT_HERO = 32,
+                PLAYER_RENAME = 33,
+		CITY_DESTITUTE = 34
         };
                 
         
 	//! Default constructor.
         Action(Type type);
 
+	//! Copy constructor (shallow).
+	Action(const Action &action);
+
+	//! Loading constructor.
         Action(XML_Helper *helper);
 
 	//! Destructor.
@@ -144,6 +151,7 @@ class Action
 
         //! Save function. See XML_Helper for information about saving.
         bool save(XML_Helper* helper) const;
+	bool saveContents(XML_Helper* helper) const;
         
         /** 
 	 * static load function (see XML_Helper)
@@ -163,14 +171,10 @@ class Action
         //! Returns the Action::Type for this action.
         Type getType() const {return d_type;}
 
-        void setPlayer(Uint32 p) { d_player = p; }
-        Uint32 getPlayer() const { return d_player; }
-        
     protected:
         virtual bool doSave(XML_Helper* helper) const = 0;
         
         Type d_type;
-        Uint32 d_player;
 };
 
 //-----------------------------------------------------------------------------
@@ -185,6 +189,8 @@ class Action_Move : public Action
     public:
 	//! Make a new move action.
         Action_Move();
+	//! Copy constructor
+        Action_Move(const Action_Move &action);
 	//! Load a new move action from an opened saved-game file.
         Action_Move(XML_Helper* helper);
 	//! Destroy a move action.
@@ -199,7 +205,10 @@ class Action_Move : public Action
 	//! Populate the move action with the stack and it's new position.
         bool fillData(Stack* s, Vector<int> dest);
     
-        //private:
+	Uint32 getStackId() const {return d_stack;};
+	Vector<int> getEndingPosition() const {return d_dest;};
+
+        private:
         Uint32 d_stack;
         Vector<int> d_dest;
 };
@@ -215,6 +224,8 @@ class Action_Disband: public Action
     public:
 	//! Make a new disband action.
         Action_Disband();
+	//! Copy constructor
+	Action_Disband(const Action_Disband &action);
 	//! Load a new disband action from an opened saved-game file.
         Action_Disband(XML_Helper* helper);
 	//! Destroy a disband action.
@@ -229,7 +240,9 @@ class Action_Disband: public Action
 	//! Populate the action with the Stack being removed.
         bool fillData(Stack* s);
     
-        //private:
+	Uint32 getStackId() const {return d_stack;};
+
+        private:
         Uint32 d_stack;
 };
 
@@ -250,6 +263,8 @@ class Action_Split : public Action
     public:
 	//! Make a new stack split action.
         Action_Split();
+	//! Copy constructor
+	Action_Split(const Action_Split &action);
 	//! Load a new stack split action from an opened saved-game file.
         Action_Split(XML_Helper* helper);
 	//! Destroy a stack split action.
@@ -269,7 +284,10 @@ class Action_Split : public Action
 	//! Populate the action with pertinent data.
         bool fillData(Stack* orig, Stack* added);
     
-        //private:
+	Uint32 getStackId() const {return d_orig;};
+	Uint32 getNewStackId() const {return d_added;};
+	Uint32 getGroupedArmyId(int idx) const {return d_armies_moved[idx];};
+        private:
         Uint32 d_orig, d_added;
         Uint32 d_armies_moved[MAX_STACK_SIZE];
 };
@@ -286,6 +304,8 @@ class Action_Fight : public Action, public sigc::trackable
     public:
 	//! Make a new fight action.
         Action_Fight();
+	//! Copy constructor
+	Action_Fight(const Action_Fight &action);
 	//! Load a new fight action from an opened saved-game file.
         Action_Fight(XML_Helper* helper);
 	//! Destroy a fight action.
@@ -304,12 +324,18 @@ class Action_Fight : public Action, public sigc::trackable
 	//! Fill the action with pertinent data.
         bool fillData(const Fight* f);
 
-        //private:
-        bool loadItem(std::string tag, XML_Helper* helper);
+
+	std::list<FightItem> getBattleHistory() const {return d_history;};
+	std::list<Uint32> getAttackerArmyIds() const {return d_attackers;};
+	std::list<Uint32> getDefenderArmyIds() const {return d_defenders;};
+
+        private:
         
         std::list<FightItem> d_history;
         std::list<Uint32> d_attackers;
         std::list<Uint32> d_defenders;
+
+        bool loadItem(std::string tag, XML_Helper* helper);
 };
 
 //-----------------------------------------------------------------------------
@@ -324,6 +350,8 @@ class Action_Join : public Action
     public:
 	//! Make a new stack join action.
         Action_Join();
+	//! Copy constructor
+	Action_Join(const Action_Join &action);
 	//! Load a new stack join action from an opened saved-game file.
         Action_Join(XML_Helper* helper);
 	//! Destroy a stack join action.
@@ -343,7 +371,9 @@ class Action_Join : public Action
 	//! Populate the action with pertinent data.
         bool fillData(Stack* orig, Stack* joining);
     
-        //private:
+	Uint32 getReceivingStackId() const {return d_orig_id;};
+	Uint32 getJoiningStackId() const {return d_joining_id;};
+        private:
         Uint32 d_orig_id, d_joining_id;
 };
 
@@ -359,6 +389,8 @@ class Action_Ruin : public Action
     public:
 	//! Make a new ruin search attempted action.
         Action_Ruin();
+	//! Copy constructor
+	Action_Ruin(const Action_Ruin&action);
 	//! Load a new ruin search attempted action from a saved-game file.
         Action_Ruin(XML_Helper* helper);
 	//! Destroy a ruin search attempted action.
@@ -380,7 +412,11 @@ class Action_Ruin : public Action
 	//! Set whether or not the Stack was successful in searching the ruin.
         void setSearched(bool searched) {d_searched = searched;}
     
-        //private:
+	Uint32 getRuinId() const {return d_ruin;};
+	Uint32 getStackId() const {return d_stack;};
+	bool getSearchSuccessful() const {return d_searched;};
+
+        private:
         Uint32 d_ruin;
         Uint32 d_stack;
         bool d_searched;
@@ -399,6 +435,8 @@ class Action_Temple : public Action
     public:
 	//! Make a new temple search action.
         Action_Temple();
+	//! Copy constructor
+	Action_Temple(const Action_Temple &action);
 	//! Load a new temple search action from a saved-game file.
         Action_Temple(XML_Helper* helper);
 	//! Destroy a temple search action.
@@ -417,7 +455,10 @@ class Action_Temple : public Action
 	//! Populate the action with pertinent data.
         bool fillData(Temple* t, Stack* s);
     
-        //private:
+	Uint32 getTempleId() const {return d_temple;};
+	Uint32 getStackId() const {return d_stack;};
+
+        private:
         Uint32 d_temple;
         Uint32 d_stack;
 };
@@ -437,6 +478,8 @@ class Action_Occupy : public Action
     public:
 	//! Make a new city occupy action.
         Action_Occupy();
+	//! Copy constructor.
+	Action_Occupy(const Action_Occupy &action);
 	//! Load a new city occupied action from an opened saved-game file.
         Action_Occupy(XML_Helper* helper);
 	//! Destroy a city occupy action.
@@ -451,7 +494,9 @@ class Action_Occupy : public Action
 	//! Populate the action with the City being occupied.
         bool fillData (City* c);
     
-        //private:
+	Uint32 getCityId() const {return d_city;};
+
+        private:
         Uint32 d_city;
 };
 
@@ -469,6 +514,8 @@ class Action_Pillage : public Action
     public:
 	//! Make a new city pillaged action.
         Action_Pillage();
+	//! Copy constructor
+	Action_Pillage(const Action_Pillage &action);
 	//! Load a new city pillaged action from an opened saved-game file.
         Action_Pillage(XML_Helper* helper);
 	//! Destroy a city pillaged action.
@@ -483,7 +530,9 @@ class Action_Pillage : public Action
 	//! Populate the action with the City that has been pillaged.
         bool fillData(City* c);
 
-        //private:
+	Uint32 getCityId() const {return d_city;};
+
+        private:
         Uint32 d_city;
 };
 
@@ -501,6 +550,8 @@ class Action_Sack : public Action
     public:
 	//! Make a new city sacked action.
         Action_Sack();
+	//! Copy constructor
+	Action_Sack(const Action_Sack &action);
 	//! Load a new city sacked action from an opened saved-game file.
         Action_Sack(XML_Helper* helper);
 	//! Destroy a city sacked action.
@@ -515,7 +566,9 @@ class Action_Sack : public Action
 	//! Populate the action with the City that has been sacked.
         bool fillData(City* c);
 
-        //private:
+	Uint32 getCityId() const {return d_city;};
+
+        private:
         Uint32 d_city;
 };
 
@@ -532,6 +585,8 @@ class Action_Raze : public Action
     public:
 	//! Make a new city razed action.
         Action_Raze();
+	//! Copy constructor
+	Action_Raze(const Action_Raze &action);
 	//! Load a new city razed action from an opened saved-game file.
         Action_Raze(XML_Helper* helper);
 	//! Destroy a city razed action.
@@ -546,7 +601,9 @@ class Action_Raze : public Action
 	//! Populate the action with the City that has been razed.
         bool fillData (City* c);
     
-        //private:
+	Uint32 getCityId() const {return d_city;};
+
+        private:
         Uint32 d_city;
 };
 
@@ -563,6 +620,8 @@ class Action_Upgrade : public Action
     public:
 	//! Make a new city upgraded action.
         Action_Upgrade();
+	//! Copy constructor
+	Action_Upgrade(const Action_Upgrade &action);
 	//! Load a new city upgraded action from an opened saved-game file.
         Action_Upgrade(XML_Helper* helper);
 	//! Destroy a city upgraded action.
@@ -577,7 +636,9 @@ class Action_Upgrade : public Action
 	//! Populate the action with the City that has been upgraded.
         bool fillData(City* c);
 
-        //private:
+	Uint32 getCityId() const {return d_city;};
+
+        private:
         Uint32 d_city;
 };
 
@@ -599,6 +660,8 @@ class Action_Buy : public Action
     public:
 	//! Make a new city buy production action.
         Action_Buy();
+	//! Copy constructor
+	Action_Buy(const Action_Buy &action);
 	//! Load a new city buy production action from a saved-game file.
         Action_Buy(XML_Helper* helper);
 	//! Destroy a city buy production action.
@@ -619,7 +682,10 @@ class Action_Buy : public Action
 	//! Populate the action with pertinent data.
         bool fillData(City* c, int slot, const Army *prod);
 
-        //private:
+	Uint32 getCityId() const {return d_city;};
+	int getProductionSlot() const {return d_slot;};
+	int getBoughtArmyTypeId() const {return d_prod;};
+        private:
         Uint32 d_city;
         int d_slot, d_prod;
 };
@@ -639,6 +705,8 @@ class Action_Production : public Action
     public:
 	//! Make a new city change production action.
         Action_Production();
+	//! Copy constructor
+	Action_Production (const Action_Production &action);
 	//! Load a new city change production action from a saved-game file.
         Action_Production(XML_Helper* helper);
 	//! Destroy a city change production action.
@@ -658,7 +726,10 @@ class Action_Production : public Action
 	//! Populate the action with pertinent data.
         bool fillData(City* c, int slot);
 
-        //private:
+	Uint32 getCityId() const {return d_city;};
+	int getSlot() const {return d_prod;};
+
+        private:
         Uint32 d_city;
         int d_prod;
 };
@@ -680,6 +751,8 @@ class Action_Reward : public Action
     public:
 	//! Make a new player rewarded action.
         Action_Reward();
+	//! Copy constructor
+	Action_Reward (const Action_Reward &action);
 	//! Load a new player rewarded action from a saved-game file.
         Action_Reward(XML_Helper* helper);
 	//! Destroy a player rewarded action.
@@ -694,10 +767,15 @@ class Action_Reward : public Action
 	//! Populate the Action_Reward with a Reward.
         bool fillData (Stack *stack, Reward *r);
     
-        //private:
-        bool load(std::string tag, XML_Helper *helper);
+
+	Reward *getReward() const {return d_reward;};
+	Uint32 getStackId() const {return d_stack;};
+
+        private:
 	Reward *d_reward;
         Uint32 d_stack;
+
+        bool load(std::string tag, XML_Helper *helper);
 	
 };
 
@@ -713,6 +791,8 @@ class Action_Quest : public Action
     public:
 	//! Make a new hero quest assigned action.
         Action_Quest();
+	//! Copy constructor
+	Action_Quest (const Action_Quest &action);
 	//! Load a new hero quest assigned action from a saved-game file.
         Action_Quest(XML_Helper* helper);
 	//! Destroy a hero quest assigned action.
@@ -727,7 +807,12 @@ class Action_Quest : public Action
 	//! Populate the Action_Quest with a Quest.
         bool fillData(Quest* q);
 
-        //private:
+	Uint32 getHeroId() const {return d_hero;};
+	Uint32 getQuestType() const {return d_questtype;};
+	Uint32 getData() const {return d_data;};
+	Uint32 getVictimPlayerId() const {return d_victim_player;};
+
+        private:
         Uint32 d_hero;
         Uint32 d_questtype;
         Uint32 d_data;
@@ -755,6 +840,8 @@ class Action_Equip : public Action
         
 	//! Make a new item equipped action.
         Action_Equip();
+	//! Copy constructor
+	Action_Equip (const Action_Equip &action);
 	//! Load a new item equipped action from an opened saved-game file.
         Action_Equip(XML_Helper* helper);
 	//! Destroy an item equipped action.
@@ -774,7 +861,11 @@ class Action_Equip : public Action
 	//! Populate the action with pertinent data.
         bool fillData(Hero *hero, Item *item, Slot slot);
 
-        //private:
+	Uint32 getHeroId() const {return d_hero;};
+	Uint32 getItemId() const {return d_item;};
+	Uint32 getToBackpackOrToGround() const {return d_slot;};
+
+        private:
         Uint32 d_hero;
         Uint32 d_item;
         Uint32 d_slot;
@@ -794,6 +885,8 @@ class Action_Level : public Action
     public:
 	//! Make a new level advancement action.
         Action_Level();
+	//! Copy constructor
+	Action_Level (const Action_Level &action);
 	//! Load a new level advancement action from an opened saved-game file.
         Action_Level(XML_Helper* helper);
 	//! Destroy a level advancement action.
@@ -813,7 +906,10 @@ class Action_Level : public Action
 	//! Populate the action with pertinent data.
         bool fillData(Army *unit, Army::Stat raised);
 
-        //private:
+	Uint32 getArmyId() const {return d_army;};
+	Uint32 getStatToIncrease() const {return d_stat;};
+
+        private:
         Uint32 d_army;
         Uint32 d_stat;
 };
@@ -832,6 +928,8 @@ class Action_ModifySignpost: public Action
     public:
 	//! Make a new change signpost action.
         Action_ModifySignpost();
+	//! Copy constructor
+	Action_ModifySignpost(const Action_ModifySignpost &action);
 	//! Load a new change signpost action from an opened saved-game file.
         Action_ModifySignpost(XML_Helper* helper);
 	//! Destroy a change signpost action.
@@ -846,7 +944,10 @@ class Action_ModifySignpost: public Action
 	//! Populate the action with the signpost and the new message.
         bool fillData(Signpost * s, std::string message);
     
-        //private:
+	Uint32 getSignpostId() const {return d_signpost;};
+	std::string getSignContents() const {return d_message;};
+
+        private:
         Uint32 d_signpost;
 	std::string d_message;
 };
@@ -864,6 +965,8 @@ class Action_RenameCity: public Action
     public:
 	//! Make a new city rename action.
         Action_RenameCity();
+	//! Copy constructor
+	Action_RenameCity(const Action_RenameCity &action);
 	//! Load a new city rename action from an opened saved-game file.
         Action_RenameCity(XML_Helper* helper);
 	//! Destroy a city rename action.
@@ -878,7 +981,9 @@ class Action_RenameCity: public Action
 	//! Populate the action with the city being renamed and the new name.
         bool fillData(City *c, std::string name);
     
-        //private:
+	Uint32 getCityId() const {return d_city;};
+	std::string getNewCityName() const {return d_name;};
+        private:
         Uint32 d_city;
 	std::string d_name;
 };
@@ -898,6 +1003,8 @@ class Action_Vector: public Action
     public:
 	//! Make a new city vector action.
         Action_Vector();
+	//! Copy constructor
+	Action_Vector(const Action_Vector &action);
 	//! Load a new city vector action from an opened saved-game file.
         Action_Vector(XML_Helper* helper);
 	//! Destroy a city vector action.
@@ -916,7 +1023,10 @@ class Action_Vector: public Action
 	//! Populate the action with pertinent data.
         bool fillData(City* src, Vector <int> dest);
     
-        //private:
+	Uint32 getCityId() const {return d_city;};
+	Vector<int> getVectoringDestination() const {return d_dest;};
+
+        private:
         Uint32 d_city;
         Vector<int> d_dest;
 };
@@ -933,6 +1043,8 @@ class Action_FightOrder: public Action
     public:
 	//! Make a new fight order action.
         Action_FightOrder();
+	//! Copy constructor
+	Action_FightOrder(const Action_FightOrder &action);
 	//! Load a new fight order action from an opened saved-game file.
         Action_FightOrder(XML_Helper* helper);
 	//! Destroy a fight order action.
@@ -947,7 +1059,9 @@ class Action_FightOrder: public Action
 	//! Populate the action with a list of ranks, one per Army unit type.
         bool fillData(std::list<Uint32> order);
     
-        //private:
+	std::list<Uint32> getFightOrder() const {return d_order;};
+
+        private:
 	std::list<Uint32> d_order;
 };
 
@@ -964,6 +1078,8 @@ class Action_Resign: public Action
     public:
 	//! Make a new player resignation action.
         Action_Resign();
+	//! Copy constructor
+	Action_Resign(const Action_Resign &action);
 	//! Load a new player resignation action from an opened saved-game file.
         Action_Resign(XML_Helper* helper);
 	//! Destroy a player resignation action.
@@ -992,6 +1108,8 @@ class Action_Plant: public Action
     public:
 	//! Make a new item planted action.
         Action_Plant();
+	//! Copy constructor
+	Action_Plant(const Action_Plant &action);
 	//! Load a new item planted action from an opened saved-game file.
         Action_Plant(XML_Helper* helper);
 	//! Destroy a item planted action.
@@ -1006,7 +1124,10 @@ class Action_Plant: public Action
 	//! Populate the action with the Id of the Hero and the Id of the Item.
         bool fillData(Hero *hero, Item *item);
 
-        //private:
+	Uint32 getHeroId() const {return d_hero;};
+	Uint32 getItemId() const {return d_item;};
+
+        private:
         Uint32 d_hero;
         Uint32 d_item;
 };
@@ -1020,6 +1141,8 @@ class Action_Plant: public Action
  * The City might be vectoring elsewhere, so the unit doesn't show up in the
  * City that produced it.  If vectoring is not enabled the Army unit shows
  * up right away in the host City.
+ * This action is used primarily for reporting purposes.  The player's 
+ * production report shows which army units were created in what cities.
  * The army unit is taken from the Player's Armyset.
  */
 class Action_Produce: public Action
@@ -1027,6 +1150,8 @@ class Action_Produce: public Action
     public:
 	//! Make a new unit produced action.
         Action_Produce();
+	//! Copy constructor
+	Action_Produce(const Action_Produce &action);
 	//! Load a new unit produced action from an opened saved-game file.
         Action_Produce(XML_Helper* helper);
 	//! Destroy a unit produced action.
@@ -1070,6 +1195,8 @@ class Action_Produce: public Action
  * vectored Army unit arrives at it's destination.  The idea here is that
  * two turns have passed since a unit was vectored, and now the unit has
  * shown up.
+ * This action is used primarily for reporting purposes.  The player's 
+ * production report shows which vectored army units arrived in what cities.
  * The army unit is taken from the Player's Armyset.
  */
 class Action_ProduceVectored: public Action
@@ -1077,6 +1204,8 @@ class Action_ProduceVectored: public Action
     public:
 	//! Make a new vector arrival action.
         Action_ProduceVectored();
+	//! Copy constructor
+	Action_ProduceVectored(const Action_ProduceVectored &action);
 	//! Load a new vector arrival action from an opened saved-game file.
         Action_ProduceVectored(XML_Helper* helper);
 	//! Destroy a vector arrival action.
@@ -1121,6 +1250,8 @@ class Action_DiplomacyState: public Action
     public:
 	//! Make a new diplomatic state action.
         Action_DiplomacyState();
+	//! Copy constructor
+	Action_DiplomacyState(const Action_DiplomacyState &action);
 	//! Load a new diplomatic state action from an opened saved-game file.
         Action_DiplomacyState(XML_Helper* helper);
 	//! Destroy a diplomatic state action.
@@ -1165,6 +1296,8 @@ class Action_DiplomacyProposal: public Action
     public:
 	//! Make a new diplomatic proposal action.
         Action_DiplomacyProposal();
+	//! Copy constructor
+	Action_DiplomacyProposal(const Action_DiplomacyProposal &action);
 	//! Load a new diplomatic proposal action from a saved-game file.
         Action_DiplomacyProposal(XML_Helper* helper);
 	//! Destroy a diplomatic proposal action.
@@ -1209,6 +1342,8 @@ class Action_DiplomacyScore: public Action
     public:
 	//! Make a new diplomatic score action.
         Action_DiplomacyScore();
+	//! Copy constructor.
+	Action_DiplomacyScore(const Action_DiplomacyScore &action);
 	//! Load a new diplomatic score action from an opened saved-game file.
         Action_DiplomacyScore(XML_Helper* helper);
 	//! Destroy a diplomatic score action.
@@ -1247,6 +1382,8 @@ class Action_EndTurn: public Action
     public:
 	//! Make a new end turn action.
         Action_EndTurn();
+	//! Copy constructor
+	Action_EndTurn(const Action_EndTurn &action);
 	//! Load a new end turn action from an opened saved-game file.
         Action_EndTurn(XML_Helper* helper);
 	//! Destroy a end turn action.
@@ -1266,6 +1403,8 @@ class Action_ConquerCity : public Action
     public:
 	//! Make a new city conquer action.
         Action_ConquerCity();
+	//! Copy constructor
+	Action_ConquerCity(const Action_ConquerCity &action);
 	//! Load a new city conquer action from an opened saved-game file.
         Action_ConquerCity(XML_Helper* helper);
 	//! Destroy a city conquer action.
@@ -1280,7 +1419,9 @@ class Action_ConquerCity : public Action
 	//! Populate the action with the City being conquered.
         bool fillData (City* c, Stack *s);
     
-        //private:
+	Uint32 getCityId() const {return d_city;};
+	Uint32 getStackId() const {return d_stack;};
+        private:
         Uint32 d_city, d_stack;
 };
 
@@ -1291,6 +1432,8 @@ class Action_RecruitHero : public Action
     public:
 	//! Make a new recruit hero action.
         Action_RecruitHero();
+	//! Copy a new recruit hero action
+	Action_RecruitHero(const Action_RecruitHero &action);
 	//! Load a new recruit hero action from an opened saved-game file.
         Action_RecruitHero(XML_Helper* helper);
 	//! Destroy a recruit hero action.
@@ -1305,11 +1448,76 @@ class Action_RecruitHero : public Action
 	//! Populate the action.
         bool fillData(Hero* hero, City *city, int cost, int alliesCount, const Army *ally);
     
-        //private:
+	Hero* getHero() const {return d_hero;};
+	Uint32 getCityId() const {return d_city;};
+	Uint32 getCost() const {return d_cost;};
+	Uint32 getNumAllies() const {return d_allies;};
+	Uint32 getAllyArmyType() const {return d_ally_army_type;};
+
+        private:
         Hero *d_hero;
         Uint32 d_city, d_cost, d_allies, d_ally_army_type;
 
         bool load(std::string tag, XML_Helper *helper);
 };
 
+//-----------------------------------------------------------------------------
+
+class Action_RenamePlayer: public Action
+{
+    public:
+	//! Make a new rename player action
+        Action_RenamePlayer();
+	//! Copy constructor
+	Action_RenamePlayer(const Action_RenamePlayer &action);
+	//! Load a new rename player action from an opened saved-game file.
+        Action_RenamePlayer(XML_Helper* helper);
+	//! Destroy a rename player action.
+        ~Action_RenamePlayer();
+
+	//! Return some debug information about this action.
+        std::string dump() const;
+
+	//! Save this city occupied action to an opened saved-game file.
+        virtual bool doSave(XML_Helper* helper) const;
+
+	//! Populate the action.
+        bool fillData(std::string name);
+    
+	std::string getName() const {return d_name;};
+
+        private:
+	std::string d_name;
+};
+
+//-----------------------------------------------------------------------------
+
+class Action_CityTooPoorToProduce: public Action
+{
+    public:
+	//! Make a new city-too-poor action
+        Action_CityTooPoorToProduce();
+	//! Copy constructor
+	Action_CityTooPoorToProduce(const Action_CityTooPoorToProduce &action);
+	//! Load a new too-poor action from an opened saved-game file.
+        Action_CityTooPoorToProduce(XML_Helper* helper);
+	//! Destroy a too-poor action.
+        ~Action_CityTooPoorToProduce();
+
+	//! Return some debug information about this action.
+        std::string dump() const;
+
+	//! Save this city occupied action to an opened saved-game file.
+        virtual bool doSave(XML_Helper* helper) const;
+
+	//! Populate the action.
+        bool fillData(City *city, const Army *army);
+    
+	Uint32 getCityId() const {return d_city;}
+	Uint32 getArmyType() const {return d_army_type;}
+
+        private:
+	Uint32 d_city;
+	Uint32 d_army_type;
+};
 #endif //ACTION_H
