@@ -1,3 +1,9 @@
+// Copyright (C) 2002, 2003, 2004, 2005 Ulf Lorenz
+// Copyright (C) 2003 Michael Bartl
+// Copyright (C) 2006 Andrea Paternesi
+// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008 Ole Laursen
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +16,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #include <stdlib.h>
 #include <algorithm>
@@ -52,39 +59,24 @@ bool AI_Dummy::startTurn()
 {
     //this is a dummy AI (neutral player) so there is not much point in
     //doing anything
-    RealPlayer::startTurn();
-
     return true;
 }
 
-bool AI_Dummy::invadeCity(City* c)
+void AI_Dummy::invadeCity(City* c)
 {
-    //dummy ai player should never invade an enmy city, but if it happens, we
+    //dummy ai player should never invade an enemy city, but if it happens, we
     //make sure there is no inconsistency
-    bool retval = cityOccupy(c);
-    sinvadingCity.emit(c);
-    soccupyingCity.emit(c, getActivestack());
-
-    return retval;
+    cityOccupy(c);
 }
 
-bool AI_Dummy::recruitHero(Hero* hero, City *city, int cost)
+void AI_Dummy::levelArmy(Army* a)
 {
-    return false;   //never recruit a hero
-}
+    Army::Stat stat = Army::STRENGTH;
+    doLevelArmy(a, stat);
 
-bool AI_Dummy::levelArmy(Army* a)
-{
-    if (!a->canGainLevel())
-        return false;
-
-    a->gainLevel(Army::STRENGTH);
-
-    Action_Level* item=0;
-    item->fillData(a->getId(), Army::STRENGTH);
-    d_actions.push_back(item);
-
-    return true;
+    Action_Level* item = new Action_Level();
+    item->fillData(a, stat);
+    addAction(item);
 }
 
 // End of file
