@@ -93,7 +93,11 @@ class AI_Fast : public RealPlayer
 
     private:
         //! The actual core function of the ai's logic.
-        void computerTurn(); 
+        bool computerTurn(); 
+
+	//! search through our stacklist for a stack we can join
+	Stack *findNearOwnStackToJoin(Stack *s, int max_distance);
+
 
 	//! Determines whether to join units or move them separately.
         bool d_join;
