@@ -52,8 +52,8 @@ City::City(Vector<int> pos, string name, Uint32 gold)
 
 {
     // Initialise armytypes
-    for (int i = 0; i < getMaxNoOfProductionBases(); i++)
-        d_prodbase[i] = NULL; 
+    for (int i = 0; i < MAX_PRODUCTION_SLOTS_IN_A_CITY; i++)
+      d_prodbase[i] = NULL;
 
     // set the tiles to city type
     for (int i = 0; i < 2; i++)
@@ -66,13 +66,13 @@ City::City(Vector<int> pos, string name, Uint32 gold)
 
 City::City(XML_Helper* helper)
     :Ownable(helper), Location(helper, 2), Renamable(helper), 
-    d_numprodbase(MAX_PRODUCTION_SLOTS_IN_A_CITY)
+    d_numprodbase(0)
 {
   //note: the armies get loaded in citylist
 
     //initialize the city
 
-    for (int i = 0; i < getMaxNoOfProductionBases(); i++)
+    for (int i = 0; i < MAX_PRODUCTION_SLOTS_IN_A_CITY; i++)
       d_prodbase[i] = NULL;
 
     helper->getData(d_defense_level, "defense");
@@ -119,7 +119,7 @@ City::City(const City& c)
     d_vectoring(c.d_vectoring),d_vector(c.d_vector), d_capital(c.d_capital), 
     d_capital_owner(c.d_capital_owner)
 {
-    for (int i = 0; i < getMaxNoOfProductionBases(); i++)
+    for (int i = 0; i < MAX_PRODUCTION_SLOTS_IN_A_CITY; i++)
       {
 	if (c.d_prodbase[i] != NULL)
 	  d_prodbase[i] = new Army(*c.d_prodbase[i]);
@@ -162,9 +162,10 @@ bool City::save(XML_Helper* helper) const
 
     for (int i = 0; i < d_numprodbase; i++)
       {
-	if (d_prodbase[i] == NULL)
-	  continue;
-	retval &= d_prodbase[i]->save(helper, Army::PRODUCTION_BASE);
+	retval &= helper->openTag("slot");
+	if (d_prodbase[i])
+	  retval &= d_prodbase[i]->save(helper, Army::PRODUCTION_BASE);
+	retval &= helper->closeTag();
       }
     retval &= helper->closeTag();
     return retval;
@@ -254,59 +255,70 @@ bool City::hasProductionBase(const Army * army)
   return hasProductionBase(army->getType(), army->getArmyset());
 }
 
-void City::addProductionBase(int index, Army *army)
+void City::addProductionBase(int idx, Army *army)
 {
     army->setOwner(d_owner);
 
-    if (index < 0)
+    if (idx < 0)
     {
         // try to find an unoccupied production slot. If there is none, pick 
         // the slot with the highest index.
         for (int i = 0; i < d_numprodbase; i++)
             if (d_prodbase[i] == NULL)
             {
-                index = i;
+                idx = i;
                 break;
             }
 
-        if (index < 0)
+        if (idx < 0)
         {
-            index = d_numprodbase - 1;
+            idx = d_numprodbase - 1;
         }
     }
+    if (idx >= d_numprodbase)
+      return;
     
-    bool restore_production = false;
-    if (d_active_production_slot == index)
-      restore_production = true;
-    removeProductionBase(index);
-    d_prodbase[index] = army;
-    if (restore_production)
-      setActiveProductionSlot(index);
+    if (d_prodbase[idx])
+      {
+	bool restore_production = false;
+	if (d_active_production_slot == idx)
+	  restore_production = true;
+	removeProductionBase(idx);
+	d_prodbase[idx] = army;
+	if (restore_production)
+	  setActiveProductionSlot(idx);
+      }
+    else
+      d_prodbase[idx] = army;
 }
 
-void City::removeProductionBase(int index)
+void City::removeProductionBase(int idx)
 {
-    if ((index < 0) || (index > (getMaxNoOfProductionBases() - 1)))
+    if ((idx < 0) || (idx > (getMaxNoOfProductionBases() - 1)))
         return;
 
-    if (d_prodbase[index])
-      delete d_prodbase[index];
-    d_prodbase[index] = NULL;
+    if (d_prodbase[idx])
+      delete d_prodbase[idx];
+    d_prodbase[idx] = NULL;
 
-    if (d_active_production_slot == index)
+    if (d_active_production_slot == idx)
         setActiveProductionSlot(-1);
 }
 
 void City::conquer(Player* newowner)
 {
   Citylist::getInstance()->stopVectoringTo(this);
+
   setOwner(newowner);
 
     // remove vectoring info 
     setVectoring(Vector<int>(-1,-1));
 
-    for (int j = 0; j < getNoOfProductionBases(); j++)
-      d_prodbase[j]->setOwner(newowner);
+    for (int j = 0; j < getMaxNoOfProductionBases(); j++)
+      {
+	if (d_prodbase[j])
+	  d_prodbase[j]->setOwner(newowner);
+      }
 
     deFog(newowner);
 
@@ -354,8 +366,11 @@ void City::sortProduction()
     {
       std::list<Army*> productibles;
       int j;
-      for (j = 0; j < getNoOfProductionBases(); j++)
-        productibles.push_back(d_prodbase[j]);
+      for (j = 0; j < getMaxNoOfProductionBases(); j++)
+	{
+	  if (d_prodbase[j])
+	    productibles.push_back(d_prodbase[j]);
+	}
       productibles.sort(armyCompareStrength);
       j = 0;
       for (std::list<Army*>::iterator it = productibles.begin();
@@ -368,7 +383,8 @@ void City::sortProduction()
 void City::setRandomArmytypes(bool produce_allies, int likely)
 {
   //remove armies any that happen to be being produced
-  for (int i = 0; i < getMaxNoOfProductionBases(); i++)
+  int max = getMaxNoOfProductionBases();
+  for (int i = 0; i < max; i++)
     removeProductionBase(i);
 
   const Armysetlist* al = Armysetlist::getInstance();
@@ -394,7 +410,8 @@ void City::setRandomArmytypes(bool produce_allies, int likely)
   randomlyImproveOrDegradeArmy(army);
   addProductionBase(0, army);
 
-  if ((rand() % 10) < 3 && !isCapital() && likely < 1 )
+  if ((rand() % 10) < 3 && !isCapital() && likely < 1 ||
+      template_army->getAwardable())
     {
       sortProduction();
       return;
@@ -413,7 +430,8 @@ void City::setRandomArmytypes(bool produce_allies, int likely)
   randomlyImproveOrDegradeArmy(army);
   addProductionBase(1, army);
 
-  if ((rand() % 10) < 4 && !isCapital() && likely < 2)
+  if ((rand() % 10) < 4 && !isCapital() && likely < 2 ||
+      template_army->getAwardable())
     {
       sortProduction();
       return;
@@ -435,7 +453,8 @@ void City::setRandomArmytypes(bool produce_allies, int likely)
   randomlyImproveOrDegradeArmy(army);
   addProductionBase(2, army);
 
-  if ((rand() % 10) < 6 && !isCapital() && likely < 3)
+  if ((rand() % 10) < 6 && !isCapital() && likely < 3 ||
+      template_army->getAwardable())
     {
       sortProduction();
       return;
@@ -492,7 +511,7 @@ void City::produceScout()
 {
   const Armysetlist* al = Armysetlist::getInstance();
   Uint32 set = d_owner->getArmyset();
-  Army *scout = al->getArmy(set, 0);
+  Army *scout = al->getScout(set);
   Army *a = new Army(*scout, d_owner);
   GameMap::getInstance()->addArmy(this, a);
 
@@ -530,6 +549,27 @@ void City::produceWeakestProductionBase()
     }
 }
 
+const Army *City::armyArrives()
+{
+  const Army *army;
+  // vector the army to the new spot
+  if (d_vectoring)
+    {
+      VectoredUnitlist *vul = VectoredUnitlist::getInstance();
+      VectoredUnit *v = new VectoredUnit 
+	(getPos(), d_vector, new Army(*(d_prodbase[d_active_production_slot])),
+	 MAX_TURNS_FOR_VECTORING, d_owner);
+      vul->push_back(v);
+      d_owner->cityChangeProduction(this, d_active_production_slot);
+      army = getProductionBase(d_active_production_slot);
+    }
+  else //or make it here
+    {
+      army = produceArmy();
+    }
+  return army;
+}
+
 void City::nextTurn()
 {
   if (d_burnt)
@@ -542,35 +582,13 @@ void City::nextTurn()
 	{
 	  //dont make or vector the unit
 	  //and also stop production
-	  setActiveProductionSlot(-1);
-	  d_vectoring = false;
-	  d_vector.x = -1;
-	  d_vector.y = -1;
+	  d_owner->cityChangeProduction(this, -1);
+	  d_owner->vectorFromCity(this, Vector<int>(-1,-1));
 	  return;
 	}
 
-      Action_Produce *item = new Action_Produce();
-      // vector the army to the new spot
-      if (d_vectoring)
-	{
-	  VectoredUnitlist *vul = VectoredUnitlist::getInstance();
-	  VectoredUnit *v = new VectoredUnit
-	    (getPos(), d_vector, 
-	     new Army(*(d_prodbase[d_active_production_slot])),
-	     MAX_TURNS_FOR_VECTORING, d_owner);
-	  vul->push_back(v);
-	  setActiveProductionSlot(d_active_production_slot);
-	  item->fillData(getProductionBase(d_active_production_slot), this, 
-			 true);
-	}
-      else //or make it here
-	{
-	  Army *a = produceArmy();
-	  item->fillData(a, this, false);
-	}
-      //FIXME: a cookie goes to the person who can figure out how
-      //to get this action into the realplayer class.
-      d_owner->getActionlist()->push_back(item);
+      d_owner->cityProducesArmy(this);
+
     }
 }
 
@@ -689,4 +707,31 @@ bool City::changeVectorDestination(Vector<int> dest)
   return true;
 }
 
+Uint32 City::countDefenders()
+{
+  std::vector<Stack*> defenders;
+  defenders = getOwner()->getStacklist()->defendersInCity(this);
+
+  Uint32 armies = 0;
+  std::vector<Stack*>::iterator it = defenders.begin();
+  for (;it != defenders.end(); it++)
+    armies += (*it)->size();
+
+  return armies;
+}
+
+Uint32 City::countCitiesVectoringToHere()
+{
+  Citylist *cl = Citylist::getInstance();
+  Uint32 count = 0;
+  for (Citylist::iterator it = cl->begin(); it != cl->end(); it++)
+    {
+      if ((*it).getOwner() != getOwner())
+	continue;
+      if ((*it).getVectoring() == getPos())
+	count++;
+    }
+
+  return count;
+}
 // End of file
