@@ -208,6 +208,8 @@ class City : public Ownable, public Location, public Renamable
 	 */
         int getMaxNoOfProductionBases() const {return d_numprodbase;};
 
+	void setMaxNoOfProductionBases(int max) {d_numprodbase = max;};
+
         //! Return the number of basic productions of the city.
 	/**
 	 * Scan the production slots and count how many are filled with an
@@ -324,6 +326,14 @@ class City : public Ownable, public Location, public Renamable
 	 */
 	bool changeVectorDestination(Vector<int> dest);
 
+	//! Return how many armies are in the city.
+	Uint32 countDefenders();
+
+	Uint32 countCitiesVectoringToHere();
+
+	//! This makes the army show up.  called when it's time.
+	const Army *armyArrives();
+
     private:
 
         //! Produces the currently active Army production base.
