@@ -68,6 +68,7 @@ Citylist::Citylist(XML_Helper* helper)
     // simply ask the helper to inform us when a city tag is opened
     helper->registerTag("city", sigc::mem_fun(this, &Citylist::load));
     helper->registerTag("army", sigc::mem_fun(this, &Citylist::load));
+    helper->registerTag("slot", sigc::mem_fun(this, &Citylist::load));
 }
 
 Citylist::~Citylist()
@@ -88,24 +89,76 @@ int Citylist::countCities(Player* player) const
     return cities;
 }
 
+void Citylist::collectTaxes(Player* p)
+{
+  // Collect the taxes
+  for (const_iterator it = begin(); it != end(); it++)
+    if ((*it).getOwner() == p && (*it).isBurnt() == false)
+      p->addGold((*it).getGold());
+}
+
+//calculate the amount of money new armies will cost in the upcoming turn.
+Uint32 Citylist::calculateUpcomingUpkeep(Player *p)
+{
+  Uint32 total = 0;
+  for (const_iterator it = begin(); it != end(); it++)
+    if ((*it).getOwner() == p && (*it).isBurnt() == false)
+      {
+	if ((*it).getDuration() == 1)
+	  {
+	    int slot =(*it).getActiveProductionSlot();
+	    if (slot == -1)
+	      continue;
+	    const Army *a = (*it).getProductionBase(slot);
+	    total += a->getUpkeep();
+	  }
+      }
+  return total;
+}
+
 void Citylist::nextTurn(Player* p)
 {
     debug("next_turn(" <<p->getName() <<")");
 
+    // Because players are nextTurn'd before cities, the income, treasury, 
+    // and upkeep are calculated already for the upcoming round.
+
+    //we've already collected taxes this round, so hopefully our
+    //treasury has enough money to pay our city upkeep.
+
+    //fixme: here we want the upkeep that we would pay out to all cities.
+    //and not the total upkeep.
+    Uint32 upkeep_for_new_armies = calculateUpcomingUpkeep(p);
+    if (p->getGold() < upkeep_for_new_armies)
+      {
+	int diff = upkeep_for_new_armies - p->getGold();
+	//then we have to turn off enough production to make up for diff
+	//gold pieces.
+	for (iterator it = begin(); it != end(); it++)
+	  {
+	    if ((*it).isBurnt() == true)
+	      continue;
+	    if ((*it).getOwner() != p)
+	      continue;
+	    int slot =(*it).getActiveProductionSlot();
+	    if (slot == -1)
+	      continue;
+	    const Army *a = (*it).getProductionBase(slot);
+	    diff -= a->getUpkeep();
+    
+	    p->cityTooPoorToProduce(&(*it), slot);
+	    if (diff < 0)
+	      break;
+	  }
+      }
+
     // This iteration adds the city production to the player    
     for (iterator it = begin(); it != end(); it++)
-    {
+      {
         if ((*it).getOwner() == p)
             (*it).nextTurn();
-    }
+      }
 
-    // In a second round, add the gold. The idea is that a player cannot
-    // produce units if his gold is <0. However, to be consistent, we may not
-    // add the gold in the first run, because then the player may come above 0
-    // gold, which means some cities produce units, others not.
-    for (const_iterator it = begin(); it != end(); it++)
-        if ((*it).getOwner() == p)
-            p->addGold((*it).getGold());
 }
 static bool isFogged(void *object)
 {
@@ -144,6 +197,15 @@ static bool isNotOwnedByEnemy(void *object)
   return true;
 }
 
+static bool canNotAcceptVectoring(void *object)
+{
+  City *c = ((City*)object);
+  Uint32 num = c->countCitiesVectoringToHere();
+  if (num < MAX_ARMIES_VECTORED_TO_ONE_CITY)
+    return false;
+  return true;
+}
+
 City* Citylist::getNearestEnemyCity(const Vector<int>& pos)
 {
   std::list<bool (*)(void *)> filters;
@@ -273,6 +335,14 @@ City* Citylist::getNearestNeutralCity(const Vector<int>& pos)
   return getNearestObject(pos, &filters);
 }
 
+City* Citylist::getNearestFriendlyVectorableCity(const Vector<int>& pos)
+{
+  std::list<bool (*)(void *)> filters;
+  filters.push_back(isBurnt);
+  filters.push_back(isNotOwnedByActivePlayer);
+  filters.push_back(canNotAcceptVectoring);
+  return getNearestObject(pos, &filters);
+}
 
 City* Citylist::getFirstCity(Player* p)
 {
@@ -302,11 +372,21 @@ bool Citylist::load(std::string tag, XML_Helper* helper)
     if (tag == "army")
       {
 	//add it to the right city
+	//how do i add it to the right slot?
 	Citylist::iterator it = end();
 	it--;
 	City *city = &*it;
 	Army *a = new Army (helper, Army::PRODUCTION_BASE);
-	city->addProductionBase(-1, a);
+	int slot = city->getMaxNoOfProductionBases() - 1;
+	city->addProductionBase(slot, a);
+	return true;
+      }
+    if (tag == "slot")
+      {
+	Citylist::iterator it = end();
+	it--;
+	City *city = &*it;
+	city->setMaxNoOfProductionBases(city->getMaxNoOfProductionBases() + 1);
 	return true;
       }
     if (tag == "city")
