@@ -57,6 +57,8 @@ class Citylist : public LocationList<City>, public sigc::trackable
          */
         void nextTurn(Player* p);
 
+	void collectTaxes(Player* p);
+
         //! Save the list of City objects to an opened saved-game file.
         bool save(XML_Helper* helper) const;
        
@@ -337,6 +339,12 @@ class Citylist : public LocationList<City>, public sigc::trackable
 	 */
 	City* getNearestCityPast(const Vector<int>& pos, int dist);
 
+
+	//! Get the nearest city to POS that can be vectored to.
+	City* getNearestFriendlyVectorableCity(const Vector<int>& pos);
+
+	Uint32 calculateUpcomingUpkeep(Player *p);
+
     protected:
         // CREATORS
 	//! Default constructor.
@@ -353,6 +361,7 @@ class Citylist : public LocationList<City>, public sigc::trackable
 	//! Destructor.
         ~Citylist();
 
+
     private:
         //! A callback for loading City objects into the list of cities.
         bool load(std::string tag, XML_Helper* helper);
