@@ -27,8 +27,8 @@
 
 #include <libintl.h>
 
-#define LORDSAWAR_SAVEGAME_VERSION "0.0.9"
-#define LORDSAWAR_CONFIG_VERSION "0.0.9"
+#define LORDSAWAR_SAVEGAME_VERSION "0.1.0"
+#define LORDSAWAR_CONFIG_VERSION "0.1.0"
 #define ENABLE_NLS 1 // Very important toactivate localization
 #define _(string) gettext(string) // Macro for the gettext
 #define __(astring) std::string(gettext(astring.c_str()))
@@ -88,4 +88,14 @@ private:
 };
 
 
+const unsigned short LORDSAWAR_PORT = 14998;
+#define HUMAN_PLAYER_TYPE _("Human")
+#define EASY_PLAYER_TYPE _("Easy")
+#define HARD_PLAYER_TYPE _("Hard")
+#define NO_PLAYER_TYPE _("Off")
+
+#define PLAYER_MOVING _("moving")
+#define PLAYER_WATCHING _("watching")
+#define PLAYER_NOT_HERE _("not here")
+
 #endif // DEFINITIONS_H
