@@ -1,3 +1,6 @@
+//  Copyright (C) 2007, Ole Laursen
+//  Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +13,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #ifndef CITY_DIALOG_H
 #define CITY_DIALOG_H
@@ -27,13 +31,15 @@
 #include <gtkmm/liststore.h>
 
 
+class CreateScenarioRandomize;
 class City;
 class Army;
 
+//! Scenario editor.  Edits a City object.
 class CityDialog: public sigc::trackable
 {
  public:
-    CityDialog(City *city);
+    CityDialog(City *city, CreateScenarioRandomize *randomizer);
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -63,18 +69,23 @@ class CityDialog: public sigc::trackable
     Glib::RefPtr<Gtk::ListStore> army_list;
     Gtk::Button *add_button;
     Gtk::Button *remove_button;
-    Gtk::Button *randomize_button;
+    Gtk::Button *randomize_armies_button;
+    Gtk::Button *randomize_name_button;
+    Gtk::Button *randomize_income_button;
 
     City *city;
 
     void on_add_clicked();
     void on_remove_clicked();
-    void on_randomize_clicked();
+    void on_randomize_armies_clicked();
+    void on_randomize_name_clicked();
+    void on_randomize_income_clicked();
     void on_selection_changed();
     void on_player_changed();
 
     void add_army(const Army *a);
     void set_button_sensitivity();
+    CreateScenarioRandomize *d_randomizer;
 };
 
 #endif
