@@ -1,3 +1,6 @@
+//  Copyright (C) 2007, Ole Laursen
+//  Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +13,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #include <config.h>
 
@@ -39,6 +43,7 @@
 #include "../File.h"
 #include "../GameMap.h"
 #include "../Configuration.h"
+#include "../rewardlist.h"
 #include "../GraphicsCache.h"
 #include "../armysetlist.h"
 #include "../sdl-draw.h"
@@ -279,7 +284,7 @@ void EditorBigMap::after_draw()
 	    break;
 	    
 	case ROAD:
-	    pic = GraphicsCache::getInstance()->getRoadPic(Roadlist::getInstance()->calculateType(*i));
+	    pic = GraphicsCache::getInstance()->getRoadPic(calculateRoadType(*i));
 	    SDL_BlitSurface(pic, 0, buffer, &r);
 	    break;
 	case PORT:
@@ -424,7 +429,7 @@ void EditorBigMap::change_map_under_cursor()
 	    // first stack, it's above everything else
 	    if (Stack* s = Stacklist::getObjectAt(tile))
 	    {
-		s->getPlayer()->deleteStack(s);
+		s->getOwner()->deleteStack(s);
 		break;
 	    }
 	    
@@ -435,6 +440,24 @@ void EditorBigMap::change_map_under_cursor()
 	    // ... or a port ...
 	    remove_from_map(Portlist::getInstance(), tile);
 	    // ... or a ruin ...
+	    {
+	      if (Ruinlist::getInstance()->getObjectAt(tile))
+		{
+		  Rewardlist *rl = Rewardlist::getInstance();
+		  for (Rewardlist::iterator it = rl->begin(); 
+		       it != rl->end(); it++)
+		    {
+		      if ((*it)->getType() == Reward::RUIN)
+			{
+			  Reward_Ruin *rr = static_cast<Reward_Ruin*>(*it);
+			  if (rr->getRuin()->getPos() == tile)
+			    {
+			      rl->remove(*it);
+			    }
+			}
+		    }
+		}
+	    }
 	    remove_from_map(Ruinlist::getInstance(), tile);
 	    // ... or a road ...
 	    remove_from_map(Roadlist::getInstance(), tile);
@@ -465,18 +488,18 @@ void EditorBigMap::change_map_under_cursor()
 		  {
 		    Citylist *clist = Citylist::getInstance();
 		    City *c = clist->getNearestCity(s->getPos());
-			if (s->getPlayer() != c->getPlayer())
+			if (s->getOwner() != c->getOwner())
 			  {
 			    //remove it from the old player's list of stacks
-			    s->getPlayer()->getStacklist()->remove(s);
+			    s->getOwner()->getStacklist()->remove(s);
 			    //and give it to the new player list of stacks
-			    c->getPlayer()->getStacklist()->push_back(s);
+			    c->getOwner()->getStacklist()->push_back(s);
 			    //change the ownership of the stack
-			    s->setPlayer(c->getPlayer());
+			    s->setOwner(c->getOwner());
 			    //and all of it's armies
 			    for (Stack::iterator it = s->begin(); 
 				 it != s->end(); it++)
-			      (*it)->setPlayer(c->getPlayer());
+			      (*it)->setOwner(c->getOwner());
 			  }
 	          }
 	    }
@@ -505,15 +528,18 @@ void EditorBigMap::change_map_under_cursor()
 	    
 	    // create the city
 	    City c(tile);
-	    c.setPlayer(Playerlist::getInstance()->getNeutral());
+	    c.setOwner(Playerlist::getInstance()->getNeutral());
 	    Citylist::getInstance()->push_back(c);
 
+	    bool replaced_grass = false;
 	    // notify the maptiles that a city has been placed here
 	    Rectangle r = c.get_area();
 	    for (int x = r.x; x < r.x + r.w; ++x)
 		for (int y = r.y; y < r.y + r.h; ++y)
 		{
 		    Maptile* t = GameMap::getInstance()->getTile(Vector<int>(x, y));
+		    if (t->getMaptileType() != Tile::GRASS)
+		      replaced_grass = true;
 		    t->setBuilding(Maptile::CITY);
 		    t->setType(grass_index);
 		}
@@ -527,18 +553,18 @@ void EditorBigMap::change_map_under_cursor()
 						      c.getPos().y + y);
 		    if (s)
 		      {
-			if (s->getPlayer() != c.getPlayer())
+			if (s->getOwner() != c.getOwner())
 			  {
 			    //remove it from the old player's list of stacks
-			    s->getPlayer()->getStacklist()->remove(s);
+			    s->getOwner()->getStacklist()->remove(s);
 			    //and give it to the new player list of stacks
-			    c.getPlayer()->getStacklist()->push_back(s);
+			    c.getOwner()->getStacklist()->push_back(s);
 			    //change the ownership of the stack
-			    s->setPlayer(c.getPlayer());
+			    s->setOwner(c.getOwner());
 			    //and all of it's armies
 			    for (Stack::iterator it = s->begin(); 
 				 it != s->end(); it++)
-			      (*it)->setPlayer(c.getPlayer());
+			      (*it)->setOwner(c.getOwner());
 			  }
 		      }
 		  }
@@ -546,9 +572,9 @@ void EditorBigMap::change_map_under_cursor()
 	      }
 
 	    // finally, smooth the surrounding map
-	    GameMap::getInstance()->applyTileStyles(r.y - 1, r.x - 1, 
-						    r.y + r.h + 1, 
-						    r.x + r.w + 1, true);
+	    if (replaced_grass)
+	      GameMap::getInstance()->applyTileStyles
+		(0, 0, GameMap::getHeight(), GameMap::getWidth(), true);
 	}
 	break;
 	    
@@ -557,14 +583,15 @@ void EditorBigMap::change_map_under_cursor()
 		&& maptile->getMaptileType() != Tile::WATER)
 	    {
 		maptile->setBuilding(Maptile::RUIN);
+		bool replaced_grass = false;
+		if (maptile->getMaptileType() != Tile::GRASS)
+		  replaced_grass = true;
 		maptile->setType(grass_index);
-		Ruinlist::getInstance()->push_back(Ruin(tile));
-		Rectangle r = Ruinlist::getInstance()->back().get_area();
-		// fixme, demote lone tiles, etc
-		GameMap::getInstance()->applyTileStyles(r.y - 1, r.x - 1, 
-							r.y + r.h + 1, 
-							r.x + r.w + 1, 
-							true);
+		Ruin *ruin = new Ruin(tile);
+		Ruinlist::getInstance()->push_back(*ruin);
+		if (replaced_grass)
+		  GameMap::getInstance()->applyTileStyles
+		    (0, 0, GameMap::getHeight(), GameMap::getWidth(), true);
 	    }
 	    break;
 	    
@@ -572,14 +599,15 @@ void EditorBigMap::change_map_under_cursor()
 	    if (maptile->getBuilding() == Maptile::NONE 
 		&& maptile->getMaptileType() != Tile::WATER)
 	    {
+	        bool replaced_grass = false;
 		maptile->setBuilding(Maptile::TEMPLE);
+		if (maptile->getMaptileType() != Tile::GRASS)
+		  replaced_grass = true;
 		maptile->setType(grass_index);
 		Templelist::getInstance()->push_back(Temple(tile));
-		Rectangle r = Templelist::getInstance()->back().get_area();
-		GameMap::getInstance()->applyTileStyles(r.y - 1, r.x - 1, 
-							r.y + r.h + 1, 
-							r.x + r.w + 1,
-							true);
+		if (replaced_grass)
+		  GameMap::getInstance()->applyTileStyles
+		    (0, 0, GameMap::getHeight(), GameMap::getWidth(), true);
 	    }
 	    break;
 	    
@@ -613,7 +641,7 @@ void EditorBigMap::change_map_under_cursor()
 		else
 		{
 		    maptile->setBuilding(Maptile::BRIDGE);
-		    Bridgelist::getInstance()->push_back(Bridge(tile, "", type));
+		    Bridgelist::getInstance()->push_back(Bridge(tile, type));
 		}
 	        changed_tiles.dim = Vector<int>(1, 1);
 	    }
@@ -624,11 +652,11 @@ void EditorBigMap::change_map_under_cursor()
 		 || maptile->getBuilding() == Maptile::ROAD)
 		&& maptile->getMaptileType() != Tile::WATER)
 	    {
-		int type = Roadlist::getInstance()->calculateType(tile);
+		int type = calculateRoadType(tile);
 		if (maptile->getBuilding() == Maptile::NONE)
 		{
 		    maptile->setBuilding(Maptile::ROAD);
-		    Roadlist::getInstance()->push_back(Road(tile, "", type));
+		    Roadlist::getInstance()->push_back(Road(tile, type));
 		}
 
 		// now reconfigure all roads in the surroundings
@@ -642,7 +670,7 @@ void EditorBigMap::change_map_under_cursor()
 			Vector<int> pos(x, y);
 			if (Road *r = Roadlist::getInstance()->getObjectAt(pos))
 			{
-			    int newtype = Roadlist::getInstance()->calculateType(pos);
+			    int newtype = calculateRoadType(pos);
 			    r->setType(newtype);
 			}
 		    }
@@ -666,3 +694,72 @@ void EditorBigMap::smooth_view()
 					  view.x+view.w, true);
   draw();
 }
+
+int EditorBigMap::calculateRoadType (Vector<int> t)
+{
+    Roadlist *rl = Roadlist::getInstance();
+    Bridgelist *bl = Bridgelist::getInstance();
+
+    // examine neighbour tiles to discover whether there's a road or
+    // bridge on them
+    bool u = false; //up
+    bool b = false; //bottom
+    bool l = false; //left
+    bool r = false; //right
+
+    if (t.y > 0)
+      u = rl->getObjectAt(t + Vector<int>(0, -1));
+    if (t.y < GameMap::getHeight() - 1)
+      b = rl->getObjectAt(t + Vector<int>(0, 1));
+    if (t.x > 0)
+      l = rl->getObjectAt(t + Vector<int>(-1, 0));
+    if (t.x < GameMap::getWidth() - 1)
+      r = rl->getObjectAt(t + Vector<int>(1, 0));
+
+    if (!u && t.y > 0)
+      u = bl->getObjectAt(t + Vector<int>(0, -1));
+    if (!b && t.y < GameMap::getHeight() - 1)
+      b = bl->getObjectAt(t + Vector<int>(0, 1));
+    if (!l && t.x > 0)
+      l = bl->getObjectAt(t + Vector<int>(-1, 0));
+    if (!r && t.x < GameMap::getWidth() - 1)
+      r = bl->getObjectAt(t + Vector<int>(1, 0));
+
+    // then translate this to the type
+    int type = 2; 
+    //show road type 2 when no other road tiles are around
+    if (!u && !b && !l && !r)
+	type = 2;
+    else if (u && b && l && r)
+	type = 2;
+    else if (!u && b && l && r)
+	type = 9;
+    else if (u && !b && l && r)
+	type = 8;
+    else if (u && b && !l && r)
+	type = 7;
+    else if (u && b && l && !r)
+	type = 10;
+    else if (u && b && !l && !r)
+	type = 1;
+    else if (!u && !b && l && r)
+	type = 0;
+    else if (u && !b && l && !r)
+	type = 3;
+    else if (u && !b && !l && r)
+	type = 4;
+    else if (!u && b && l && !r)
+	type = 6;
+    else if (!u && b && !l && r)
+	type = 5;
+    else if (u && !b && !l && !r)
+	type = 1;
+    else if (!u && b && !l && !r)
+	type = 1;
+    else if (!u && !b && l && !r)
+	type = 0;
+    else if (!u && !b && !l && r)
+	type = 0;
+    return type;
+}
+
