@@ -1,3 +1,6 @@
+//  Copyright (C) 2007, Ole Laursen
+//  Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +13,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #ifndef GUI_MAIN_WINDOW_H
 #define GUI_MAIN_WINDOW_H
@@ -32,14 +36,17 @@
 
 #include "../map-tip-position.h"
 #include "editorbigmap.h"
+#include "RenamableLocation.h"
 
 class SDL_Surface;
 class EditorBigMap;
 class SmallMap;
 class GameScenario;
+class CreateScenarioRandomize;
 
-// the top-level window of the map with menu, bigmap, smallmap, drawing
-// controls
+#include "../UniquelyIdentified.h"
+
+//! Scenario editor.  Edits a Scenario.
 class MainWindow: public sigc::trackable
 {
  public:
@@ -76,6 +83,7 @@ class MainWindow: public sigc::trackable
     bool sdl_inited;
 
     std::auto_ptr<GameScenario> game_scenario;
+    std::auto_ptr<CreateScenarioRandomize> d_create_scenario_names;
     GdkEventButton *button_event;
 
     bool on_delete_event(GdkEventAny *e);
@@ -97,9 +105,21 @@ class MainWindow: public sigc::trackable
     void on_edit_players_activated();
     void on_smooth_map_activated();
     void on_smooth_screen_activated();
+    void on_edit_items_activated();
+    void on_edit_rewards_activated();
 
     void on_fullscreen_activated();
 
+    void on_random_all_cities_activated();
+    void on_random_unnamed_cities_activated();
+    void on_random_all_ruins_activated();
+    void on_random_unnamed_ruins_activated();
+    void on_random_all_temples_activated();
+    void on_random_unnamed_temples_activated();
+    void on_random_all_signs_activated();
+    void on_random_unnamed_signs_activated();
+
+    void on_help_about_activated();
     
     struct PointerItem
     {
@@ -139,25 +159,28 @@ class MainWindow: public sigc::trackable
     void init_maps();
     void set_filled_map(int width, int height, int fill_style, 
 			std::string tileset, std::string shieldset, 
-			std::string cityset);
+			std::string cityset, std::string armyset);
     void set_random_map(int width, int height,
 			int grass, int water, int swamp, int forest,
 			int hills, int mountains,
 			int cities, int ruins, int temples, int signposts,
 			std::string tileset, std::string shieldset,
-			std::string cityset);
+			std::string cityset, std::string armyset);
 
     void clear_map_state();
     void init_map_state();
     void remove_tile_style_buttons();
     void setup_tile_style_buttons(Tile::Type terrain);
+    void randomize_signpost(Signpost *signpost);
+    void randomize_city(City *city);
+    void randomize_ruin(Ruin *ruin);
 
     // map callbacks
     void on_smallmap_changed(SDL_Surface *map);
-    void on_objects_selected(std::vector<Object *> objects);
+    void on_objects_selected(std::vector<UniquelyIdentified *> objects);
     void on_mouse_on_tile(Vector<int> tile);
     
-    void popup_dialog_for_object(Object *object);
+    void popup_dialog_for_object(UniquelyIdentified *object);
 
     int d_width;
     int d_height;
