@@ -1,3 +1,6 @@
+//  Copyright (C) 2007, Ole Laursen
+//  Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +13,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #ifndef NEW_MAP_DIALOG_H
 #define NEW_MAP_DIALOG_H
@@ -28,6 +32,7 @@
 #include "../Tile.h"
 #include "../game-parameters.h"
 
+//! Scenario editor.  Edit parameters to make a new map.
 class NewMapDialog
 {
  public:
@@ -48,6 +53,7 @@ class NewMapDialog
 	std::string tileset;
 	std::string shieldset;
 	std::string cityset;
+	std::string armyset;
     };
 
     Map map;
@@ -62,6 +68,7 @@ class NewMapDialog
     Gtk::Widget *random_map_container;
     Gtk::ComboBoxText *tile_theme_combobox;
     Gtk::ComboBoxText *city_theme_combobox;
+    Gtk::ComboBoxText *army_theme_combobox;
     Gtk::ComboBoxText *shield_theme_combobox;
     Gtk::Scale *grass_scale;
     Gtk::Scale *water_scale;
