@@ -1,3 +1,6 @@
+//  Copyright (C) 2007, Ole Laursen
+//  Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +13,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #ifndef SELECT_ARMY_DIALOG_H
 #define SELECT_ARMY_DIALOG_H
@@ -23,7 +27,6 @@
 #include <gtkmm/table.h>
 #include <gtkmm/togglebutton.h>
 #include <gtkmm/button.h>
-#include <gtkmm/comboboxtext.h>
 #include <SDL/SDL_types.h>
 
 #include "../gui/army-info-tip.h"
@@ -32,11 +35,12 @@ class Army;
 class City;
 class Player;
 
-// dialog for buying a production slot for a city
+//! Scenario editor.  Select an Army prototype.
 class SelectArmyDialog: public sigc::trackable
 {
  public:
-    SelectArmyDialog(Player *p);
+    SelectArmyDialog(Player *p, bool defends_ruins = false,
+		     bool rewardable = false);
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -47,7 +51,6 @@ class SelectArmyDialog: public sigc::trackable
  private:
     std::auto_ptr<Gtk::Dialog> dialog;
     std::auto_ptr<ArmyInfoTip> army_info_tip;
-    Gtk::ComboBoxText *armyset_combobox;
     Gtk::Label *army_info_label1;
     Gtk::Label *army_info_label2;
     Gtk::Table *toggles_table;
@@ -56,6 +59,8 @@ class SelectArmyDialog: public sigc::trackable
 
     const Army *selected_army;
     Player *player;
+    bool d_defends_ruins;
+    bool d_awardable;
 
     std::vector<Gtk::ToggleButton *> army_toggles;
     bool ignore_toggles;
@@ -63,7 +68,6 @@ class SelectArmyDialog: public sigc::trackable
 
     void on_army_toggled(Gtk::ToggleButton *toggle);
     bool on_army_button_event(GdkEventButton *e, Gtk::ToggleButton *toggle);
-    void on_armyset_changed();
     
     void fill_in_army_toggles();
     void fill_in_army_info();
