@@ -1,3 +1,6 @@
+//  Copyright (C) 2007, Ole Laursen
+//  Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +13,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #ifndef SIGNPOST_DIALOG_H
 #define SIGNPOST_DIALOG_H
@@ -19,13 +23,16 @@
 #include <sigc++/trackable.h>
 #include <gtkmm/dialog.h>
 #include <gtkmm/textview.h>
+#include <gtkmm/button.h>
 
 class Signpost;
+class CreateScenarioRandomize;
 
+//! Scenario editor.  Change the contents of a signpost.
 class SignpostDialog: public sigc::trackable
 {
  public:
-    SignpostDialog(Signpost *signpost);
+    SignpostDialog(Signpost *signpost, CreateScenarioRandomize *randomizer);
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -35,6 +42,10 @@ class SignpostDialog: public sigc::trackable
     std::auto_ptr<Gtk::Dialog> dialog;
     Gtk::TextView *sign_textview;
     Signpost *signpost;
+    Gtk::Button *randomize_button;
+    CreateScenarioRandomize *d_randomizer;
+    
+    void on_randomize_clicked();
 };
 
 #endif
