@@ -1,3 +1,6 @@
+//  Copyright (C) 2007, Ole Laursen
+//  Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +13,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.*
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #include <config.h>
 
@@ -49,7 +53,7 @@ StackDialog::StackDialog(Stack *s, int m)
     xml->get_widget("dialog", d);
     dialog.reset(d);
 
-    if (stack->getPlayer())
+    if (stack->getOwner())
     {
 	// setup the player combo
 	player_combobox = manage(new Gtk::ComboBoxText);
@@ -60,7 +64,7 @@ StackDialog::StackDialog(Stack *s, int m)
 	{
 	    Player *player = *i;
 	    player_combobox->append_text(player->getName());
-	    if (player == stack->getPlayer())
+	    if (player == stack->getOwner())
 		player_no = c;
 	}
 
@@ -161,21 +165,21 @@ void StackDialog::run()
 		    break;
 		}
 
-	    Player *stack_player = stack->getPlayer();
+	    Player *stack_player = stack->getOwner();
 	    if (stack_player)
 		stack_player->getStacklist()->remove(stack);
 	
 	    player->addStack(stack);
 	    stack->setPlayer(player);
 	    for (Stack::iterator it = stack->begin(); it != stack->end(); it++)
-	      (*it)->setPlayer(player);
+	      (*it)->setOwner(player);
 	}
     }
 }
 
 void StackDialog::on_add_clicked()
 {
-    SelectArmyDialog d(stack->getPlayer());
+    SelectArmyDialog d(stack->getOwner());
     d.set_parent_window(*dialog.get());
     d.run();
 
