@@ -1,3 +1,6 @@
+//  Copyright (C) 2007, Ole Laursen
+//  Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +13,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #ifndef TEMPLE_DIALOG_H
 #define TEMPLE_DIALOG_H
@@ -21,12 +25,15 @@
 #include <gtkmm/entry.h>
 #include <gtkmm/spinbutton.h>
 
+class CreateScenarioRandomize;
+
 class Temple;
 
+//! Scenario editor.  Edits a Temple object.
 class TempleDialog: public sigc::trackable
 {
  public:
-    TempleDialog(Temple *temple);
+    TempleDialog(Temple *temple, CreateScenarioRandomize *randomizer);
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -37,6 +44,10 @@ class TempleDialog: public sigc::trackable
     Gtk::Entry *name_entry;
     Gtk::SpinButton *type_entry;
     Temple *temple;
+    Gtk::Button *randomize_name_button;
+    CreateScenarioRandomize *d_randomizer;
+
+    void on_randomize_name_clicked();
 };
 
 #endif
