@@ -56,6 +56,7 @@
 #include "File.h"
 #include "Quest.h"
 #include "reward.h"
+#include "action.h"
 #include "game-parameters.h"
 #include "FogMap.h"
 #include "GameMap.h"
@@ -96,6 +97,9 @@ void Game::addPlayer(Player *p)
 	(p->hero_arrives_with_allies.connect
          (sigc::mem_fun
           (hero_arrives, &sigc::signal<void, int>::emit)));
+      connections[p->getId()].push_back
+	(p->advice_asked.connect
+	 (sigc::mem_fun(advice_asked, &sigc::signal<void, float>::emit)));
     }
 	
       
@@ -121,9 +125,6 @@ void Game::addPlayer(Player *p)
       (ruinfight_finished, &sigc::signal<void, Fight::Result>::emit)));
   connections[p->getId()].push_back
     (p->cityfight_finished.connect (sigc::mem_fun(*this, &Game::on_city_fight_finished))); 
-  connections[p->getId()].push_back
-    (p->advice_asked.connect
-     (sigc::mem_fun(advice_asked, &sigc::signal<void, float>::emit)));
 }
 
 #define NETWORK_TESTING 1
@@ -265,13 +266,8 @@ void Game::update_sidebar_stats()
     s.name = player->getName();
     s.gold = player->getGold();
     s.income = s.cities = 0;
-    for (Citylist::iterator i = Citylist::getInstance()->begin(),
-	     end = Citylist::getInstance()->end(); i != end; ++i)
-	if (i->getOwner() == player)
-	{
-	    s.income += i->getGold();
-	    ++s.cities;
-	}
+    s.income = player->getIncome();
+    s.cities = Citylist::getInstance()->countCities(player);
 
     s.units = 0;
     s.upkeep = player->getUpkeep();
@@ -402,7 +398,9 @@ void Game::move_all_stacks()
 	  select_active_stack();
 	  if (player->getActivestack()->isGrouped() == false)
 	    player->stackSplit(player->getActivestack());
-	  player->stackMove(player->getActivestack());
+	  bool moved = player->stackMove(player->getActivestack());
+	  if (!moved)
+	    break;
 	  i = sl->begin();
 	}
     }
@@ -735,9 +733,11 @@ void Game::invading_city(City* city, int gold)
 	break;
 
       case CITY_DEFEATED_PILLAGE:
-	int pillaged_army_type;
-	player->cityPillage(city, gold, pillaged_army_type);
-	city_pillaged.emit(city, gold, pillaged_army_type);
+	  {
+	    int pillaged_army_type = -1;
+	    player->cityPillage(city, gold, &pillaged_army_type);
+	    city_pillaged.emit(city, gold, pillaged_army_type);
+	  }
 	break;
 
       case CITY_DEFEATED_SACK:
@@ -926,7 +926,7 @@ void Game::update_control_panel()
       can_plant_standard_selected_stack.emit(false);
     }
 
-  if (d_gameScenario->getRound() > 0)
+  if (d_gameScenario->getRound() > 1)
     can_see_history.emit(true);
   else
     can_see_history.emit(false);
@@ -971,7 +971,8 @@ void Game::loadGame()
       game_loaded.emit(player);
     }
 
-  d_nextTurn->setContinuingTurn();
+  if (player->getType() == Player::HUMAN)
+    d_nextTurn->setContinuingTurn();
   d_nextTurn->start();
 #if 0
   else
@@ -1006,7 +1007,7 @@ void Game::init_turn_for_player(Player* p)
       smallmap->blank();
       bigmap->blank();
     }
-  next_player_turn.emit(p, d_gameScenario->getRound() + 1);
+  next_player_turn.emit(p, d_gameScenario->getRound());
   center_view_on_city();
   if (p->getType() == Player::HUMAN)
     {
@@ -1016,12 +1017,6 @@ void Game::init_turn_for_player(Player* p)
       update_stack_info();
       update_control_panel();
 
-      //if (d_gameScenario->getRound() == 0)
-	//{
-	  //Citylist *clist = Citylist::getInstance();
-	  //city_visited.emit(clist->getFirstCity(p));
-	//}
-
       // update the diplomacy icon if we've received a proposal
       bool proposal_received = false;
       for (Playerlist::iterator it = pl->begin(); it != pl->end(); ++it)
@@ -1039,6 +1034,19 @@ void Game::init_turn_for_player(Player* p)
 	    }
 	}
       received_diplomatic_proposal.emit(proposal_received);
+      //check to see if we've turned off production due to destitution.
+      bool destitute = false;
+      std::list<Action*> actions = p->getReportableActions();
+      std::list<Action*>::iterator it = actions.begin();
+      for (;it != actions.end(); it++)
+	{
+	  if ((*it)->getType() == Action::CITY_DESTITUTE)
+	    {
+	      destitute = true;
+	      break;
+	    }
+	}
+      city_too_poor_to_produce.emit(destitute);
     }
   else
     {
@@ -1146,7 +1154,7 @@ bool Game::maybeTreachery(Stack *stack, Player *them, Vector<int> pos)
   them->declareDiplomacy (Player::AT_WAR, me);
   History_DiplomacyTreachery *item = new History_DiplomacyTreachery();
   item->fillData(them);
-  me->getHistorylist()->push_back(item);
+  me->addHistory(item);
 
   me->deteriorateDiplomaticRelationship (5);
   them->improveDiplomaticRelationship (2, me);
@@ -1157,7 +1165,8 @@ bool Game::maybeTreachery(Stack *stack, Player *them, Vector<int> pos)
 void Game::nextRound()
 {
   Playerlist::getInstance()->nextRound
-    (GameScenario::s_diplomacy, &GameScenario::s_surrender_already_offered);
+    (GameScenarioOptions::s_diplomacy, 
+     &GameScenarioOptions::s_surrender_already_offered);
 }
     
 void Game::on_surrender_offered(Player *recipient)
@@ -1222,7 +1231,7 @@ void Game::on_city_fight_finished(City *city, Fight::Result result)
 bool Game::recruitHero(Hero *hero, City *city, int gold)
 {
   bool retval = hero_offers_service (city->getOwner(), hero, city, gold);
-  if (d_gameScenario->getRound() == 0)
+  if (d_gameScenario->getRound() == 1)
     city_visited.emit(city);
   return retval;
 }
