@@ -173,7 +173,9 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 	  // split if ungrouped
 	  Playerlist::getActiveplayer()->stackSplit(stack); 
 
-	  stack->getPath()->calculate(stack, p);
+	  int dist = stack->getPath()->calculate(stack, p);
+	  if (dist == -2)
+	    cerr << _("error calculating path!");
 
 	  Vector<int>* dest = 0;
 	  if (!stack->getPath()->empty())
@@ -271,6 +273,36 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 	    }
 	}
     }
+  else if (e.button == MouseButtonEvent::LEFT_BUTTON
+      && e.state == MouseButtonEvent::RELEASED)
+    {
+      if (mouse_state == DRAGGING_STACK)
+	{
+	  Stack* stack = Playerlist::getActiveplayer()->getActivestack();
+	  //march a dragged stack!
+	  mouse_state = NONE;
+	  d_cursor = GraphicsCache::FEET;
+	  cursor_changed.emit(d_cursor);
+	  //watch out here.  
+	  //we recurse for least amount of code and most programmer confusion.
+	  e.state = MouseButtonEvent::PRESSED;
+	  //go get the final spot in the path
+	  if (stack->getPath()->empty() == false)
+	    {
+	      //check if we dropped on the same tile that the stack lives on.
+	      if (mouse_pos_to_tile(e.pos) != stack->getPos())
+		{
+		  int ts = GameMap::getInstance()->getTileset()->getTileSize();
+		  e.pos = tile_to_buffer_pos (*stack->getPath()->back());
+		  e.pos.x -= ts/2;
+		  e.pos.y -= ts/2;
+		  mouse_button_event(e);
+		}
+	    }
+	}
+      else
+	mouse_state = NONE;
+    }
 
 
   // right mousebutton to get information about things on the map and to
@@ -323,7 +355,12 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 	{
 	  switch(mouse_state)
 	    {
-	    case DRAGGING:
+
+	    case DRAGGING_STACK:
+	      //no-op
+	      break;
+
+	    case DRAGGING_MAP:
 	      break;
 
 	    case SHOWING_CITY:
@@ -364,7 +401,11 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 
 void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 {
-  if (stack)
+  if (stack && mouse_state == DRAGGING_STACK)
+    {
+      d_cursor = GraphicsCache::GOTO_ARROW;
+    }
+  else if (stack)
     {
       d_cursor = GraphicsCache::FEET;
       if (stack->getPos() == tile)
@@ -414,33 +455,33 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 	      Maptile *t = GameMap::getInstance()->getTile(tile);
 	      Stack *st = Stacklist::getObjectAt(tile);
 	      if (st && st->getOwner() != Playerlist::getActiveplayer())
-	        {
-	          int delta = abs(stack->getPos().x - st->getPos().x);
-	          if (delta <= 1)
-	            delta = abs(stack->getPos().y - st->getPos().y);
-	          if (delta <= 1)
-	            {
-	              if (is_shift_key_down())
-	        	    d_cursor = GraphicsCache::QUESTION;
-	              else
-	                {
-	                  Player *me = stack->getOwner();
-	                  Player *them = st->getOwner();
-	                  bool friendly = (me->getDiplomaticState(them) == 
-	            		       Player::AT_PEACE);
-	                  if (friendly)
-	            	d_cursor = GraphicsCache::HEART;
-	                  else
-	            	d_cursor = GraphicsCache::SWORD;
-	                }
-	            }
-	          else
-	            d_cursor = GraphicsCache::HAND;
-	        }
-              else
 		{
-                  Path path;
-                  int moves = path.calculate(stack, tile);
+		  int delta = abs(stack->getPos().x - st->getPos().x);
+		  if (delta <= 1)
+		    delta = abs(stack->getPos().y - st->getPos().y);
+		  if (delta <= 1)
+		    {
+		      if (is_shift_key_down())
+			d_cursor = GraphicsCache::QUESTION;
+		      else
+			{
+			  Player *me = stack->getOwner();
+			  Player *them = st->getOwner();
+			  bool friendly = (me->getDiplomaticState(them) == 
+					   Player::AT_PEACE);
+			  if (friendly)
+			    d_cursor = GraphicsCache::HEART;
+			  else
+			    d_cursor = GraphicsCache::SWORD;
+			}
+		    }
+		  else
+		    d_cursor = GraphicsCache::HAND;
+		}
+	      else
+		{
+		  Path path;
+		  int moves = path.calculate(stack, tile);
 		  if (moves == 0)
 		    d_cursor = GraphicsCache::HAND;
 		  else
@@ -448,7 +489,12 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 		      Bridgelist *bl = Bridgelist::getInstance();
 		      if (t->getMaptileType() == Tile::WATER &&
 			  bl->getObjectAt(tile) == NULL)
-			d_cursor = GraphicsCache::SHIP;
+			{
+			  if (stack->isFlying() == true)
+			    d_cursor = GraphicsCache::FEET;
+			  else
+			    d_cursor = GraphicsCache::SHIP;
+			}
 		      else
 			d_cursor = GraphicsCache::FEET;
 		    }
@@ -498,9 +544,27 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
   if (input_locked)
     return;
 
-  // drag with left mouse button
+  Stack* stack = Playerlist::getActiveplayer()->getActivestack();
+  Vector<int> tile = mouse_pos_to_tile(e.pos);
+  if (tile.x < 0)
+    tile.x = 0;
+  if (tile.y < 0)
+    tile.y = 0;
+  if (tile.x >= GameMap::getWidth())
+    tile.x = GameMap::getWidth() - 1;
+  if (tile.y >= GameMap::getHeight())
+    tile.y = GameMap::getHeight() - 1;
+
+
   if (e.pressed[MouseMotionEvent::LEFT_BUTTON]
-      && (mouse_state == NONE || mouse_state == DRAGGING))
+      && (mouse_state == NONE || mouse_state == SHOWING_STACK) && 
+      stack && stack->getPos() == tile)
+    {
+      //initial drag
+      mouse_state = DRAGGING_STACK;
+    }
+  else if (e.pressed[MouseMotionEvent::LEFT_BUTTON]
+	   && (mouse_state == NONE || mouse_state == DRAGGING_MAP) && !stack)
     {
       Vector<int> delta = -(e.pos - prev_mouse_pos);
 
@@ -530,17 +594,51 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
 	}
 
       draw(redraw_buffer);
-      mouse_state = DRAGGING;
+      mouse_state = DRAGGING_MAP;
     }
 
   // the following block of code shows the correct mouse cursor
-  Stack* stack = Playerlist::getActiveplayer()->getActivestack();
-  Vector<int> tile = mouse_pos_to_tile(e.pos);
   if (tile == last_tile)
     {
       prev_mouse_pos = e.pos;
       return;
     }
+
+  // drag stack with left mouse button
+  if (e.pressed[MouseMotionEvent::LEFT_BUTTON]
+      && (mouse_state == DRAGGING_STACK))
+    {
+      //subsequent dragging
+      //alright.  calculate the path, and show it but don't move
+      //be careful that we don't drop our path on bad objects
+      if (is_inside(view, tile) == false)
+	{
+	  Vector<int> delta(0,0);
+	  if (tile.x >= view.x + view.w)
+	    delta.x += 1;
+	  if (tile.x < view.x)
+	    delta.x -= 1;
+	  if (tile.y > view.y + view.h)
+	    delta.y += 1;
+	  if (tile.y < view.y)
+	    delta.y -= 1;
+	  Rectangle new_view = view;
+	  new_view.pos += delta;
+	  set_view (new_view);
+	  view_changed.emit(view);
+	}
+      mouse_state = NONE;
+      determine_mouse_cursor(stack, tile);
+      mouse_state = DRAGGING_STACK;
+      if (d_cursor == GraphicsCache::FEET ||
+	  d_cursor == GraphicsCache::SHIP || 
+	  d_cursor == GraphicsCache::TARGET)
+	{
+	  stack->getPath()->calculate(stack, tile);
+	  draw();
+	}
+    }
+
   determine_mouse_cursor (stack, tile);
 
   prev_mouse_pos = e.pos;
@@ -555,7 +653,8 @@ void GameBigMap::after_draw()
   Stack* stack = Playerlist::getActiveplayer()->getActivestack();
 
   // Draw Path
-  if (stack && stack->getPath()->size())
+  if (stack && stack->getPath()->size() && 
+      stack->getOwner()->getType() == Player::HUMAN)
     {
       Vector<int> pos;
       SDL_Color c;
