@@ -78,8 +78,9 @@ class GameBigMap: public BigMap
     bool input_locked;
 	
     enum {
-	NONE, DRAGGING, SHOWING_CITY, SHOWING_RUIN,
-	SHOWING_TEMPLE, SHOWING_SIGNPOST, SHOWING_STACK
+	NONE, DRAGGING_MAP, SHOWING_CITY, SHOWING_RUIN,
+	SHOWING_TEMPLE, SHOWING_SIGNPOST, SHOWING_STACK,
+	DRAGGING_STACK
     } mouse_state;
     bool shift_key_is_down;
 	
