@@ -65,6 +65,11 @@ void ArmyBonusDialog::set_parent_window(Gtk::Window &parent)
     //dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
 }
 
+void ArmyBonusDialog::hide()
+{
+  dialog->hide();
+}
+
 void ArmyBonusDialog::run()
 {
     static int width = -1;
