@@ -103,6 +103,11 @@ void DiplomacyReportDialog::set_parent_window(Gtk::Window &parent)
   //dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
 }
 
+void DiplomacyReportDialog::hide()
+{
+  dialog->hide();
+}
+
 void DiplomacyReportDialog::run()
 {
   dialog->show_all();
