@@ -29,6 +29,7 @@
 #include "../defs.h"
 #include "../GraphicsCache.h"
 #include "../GameScenario.h"
+#include "game-lobby-dialog.h"
 
 #include "../game-client.h"
 
@@ -39,6 +40,8 @@ Driver::Driver()
     splash_window.reset(new SplashWindow);
     splash_window->new_game_requested.connect(
 	sigc::mem_fun(*this, &Driver::on_new_game_requested));
+    splash_window->new_network_game_requested.connect(
+	sigc::mem_fun(*this, &Driver::on_new_network_game_requested));
     splash_window->load_requested.connect(
 	sigc::mem_fun(*this, &Driver::on_load_requested));
     splash_window->quit_requested.connect(
@@ -96,8 +99,17 @@ Driver::~Driver()
 {
 }
 
+void Driver::on_new_network_game_requested(std::string filename, bool has_ops)
+{
+  GameLobbyDialog gld(filename, has_ops);
+  gld.set_parent_window(*splash_window.get()->get_window());
+  int response = gld.run();
+}
+
 void Driver::on_new_game_requested(GameParameters g)
 {
+    if (splash_window.get())
+	splash_window->hide();
     init_game_window();
     
     game_window->sdl_initialized.connect(
@@ -107,12 +119,15 @@ void Driver::on_new_game_requested(GameParameters g)
 
 void Driver::on_load_requested(std::string filename)
 {
+    if (splash_window.get())
+	splash_window->hide();
     init_game_window();
     
     game_window->sdl_initialized.connect(
 	sigc::bind(sigc::mem_fun(game_window.get(), &GameWindow::load_game),
 		   filename));
     game_window->show();
+
 }
 
 void Driver::on_quit_requested()
@@ -138,9 +153,6 @@ void Driver::on_game_ended()
 
 void Driver::init_game_window()
 {
-    if (splash_window.get())
-	splash_window->hide();
-
     game_window.reset(new GameWindow);
 
     game_window->game_ended.connect(
@@ -149,5 +161,6 @@ void Driver::init_game_window()
 	sigc::mem_fun(*this, &Driver::on_quit_requested));
 
     game_window->init(640, 480);
+
 }
 
