@@ -23,6 +23,7 @@
 #include <sigc++/trackable.h>
 #include <gtkmm/dialog.h>
 #include <gtkmm/combobox.h>
+#include <gtkmm/table.h>
 #include <gtkmm/comboboxtext.h>
 #include <gtkmm/togglebutton.h>
 #include <gtkmm/checkbutton.h>
@@ -36,16 +37,19 @@
 class GameOptionsDialog: public sigc::trackable
 {
  public:
-    GameOptionsDialog();
+    GameOptionsDialog(bool readonly);
 
     void set_parent_window(Gtk::Window &parent);
 
     bool run();
+    void hide();
     
     sigc::signal<void> difficulty_option_changed;
 
  private:
     std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::Table *difficultoptionstable;
+    Gtk::Table *notdifficultoptionstable;
     Gtk::CheckButton *quests_checkbutton;
     Gtk::CheckButton *view_enemies_checkbutton;
     Gtk::CheckButton *view_production_checkbutton;
@@ -71,6 +75,7 @@ class GameOptionsDialog: public sigc::trackable
     void on_quick_start_checkbutton_clicked();
     void on_intense_combat_checkbutton_clicked();
     void on_military_advisor_checkbutton_clicked();
+    bool d_readonly;
 };
 
 #endif
