@@ -27,6 +27,7 @@
 #include "game-preferences-dialog.h"
 
 #include "glade-helpers.h"
+#include "image-helpers.h"
 #include "../ucompose.hpp"
 #include "../defs.h"
 #include "../File.h"
@@ -34,18 +35,14 @@
 #include "../armysetlist.h"
 #include "../shieldsetlist.h"
 #include "../GameScenario.h"
+#include "../GraphicsCache.h"
 #include "../tilesetlist.h"
 #include "../citysetlist.h"
 #include "../player.h"
 
-#define HUMAN_PLAYER_TYPE _("Human")
-#define EASY_PLAYER_TYPE _("Easy")
-#define HARD_PLAYER_TYPE _("Hard")
-#define NO_PLAYER_TYPE _("Off")
-
 static bool inhibit_difficulty_combobox = false;
 
-GamePreferencesDialog::GamePreferencesDialog()
+void GamePreferencesDialog::init()
 {
     Glib::RefPtr<Gnome::Glade::Xml> xml
 	= Gnome::Glade::Xml::create(get_glade_path() + "/game-preferences-dialog.glade");
@@ -57,6 +54,7 @@ GamePreferencesDialog::GamePreferencesDialog()
     xml->get_widget("start_game_button", start_game_button);
     xml->get_widget("difficulty_label", difficulty_label);
     xml->get_widget("random_map_radio", random_map_radio);
+    xml->get_widget("load_map_radio", load_map_radio);
     xml->get_widget("load_map_filechooser", load_map_filechooser);
     load_map_filechooser->signal_selection_changed().connect
        (sigc::mem_fun(*this, &GamePreferencesDialog::on_map_chosen));
@@ -192,6 +190,8 @@ GamePreferencesDialog::GamePreferencesDialog()
       }
 
     shield_theme_combobox->set_active(default_id);
+    shield_theme_combobox->signal_changed().connect
+      (sigc::mem_fun(this, &GamePreferencesDialog::update_shields));
 
     xml->get_widget("shield_theme_box", box);
     box->pack_start(*shield_theme_combobox, Gtk::PACK_SHRINK);
@@ -226,10 +226,28 @@ GamePreferencesDialog::GamePreferencesDialog()
 
     xml->get_widget("cities_can_produce_allies_checkbutton", 
 		    cities_can_produce_allies_checkbutton);
-  game_options_dialog = new GameOptionsDialog();
+  game_options_dialog = new GameOptionsDialog(false);
   game_options_dialog->difficulty_option_changed.connect(
 	sigc::mem_fun(*this, 
 		      &GamePreferencesDialog::update_difficulty_rating));
+      
+  return;
+}
+
+GamePreferencesDialog::GamePreferencesDialog()
+{
+  init();
+}
+
+GamePreferencesDialog::GamePreferencesDialog(std::string filename)
+{
+  init ();
+  load_map_radio->set_active(true);
+  load_map_filechooser->set_filename(filename);
+  load_map_radio->set_sensitive(false);
+  random_map_radio->set_sensitive(false);
+  load_map_filechooser->set_sensitive(false);
+  dialog->set_title(_("New Scenario"));
 }
 
 GamePreferencesDialog::~GamePreferencesDialog()
@@ -242,10 +260,35 @@ void GamePreferencesDialog::set_parent_window(Gtk::Window &parent)
     dialog->set_transient_for(parent);
 }
 
-void GamePreferencesDialog::run()
+void GamePreferencesDialog::hide()
 {
+  dialog->hide();
+}
+
+bool GamePreferencesDialog::run()
+{
+  Shieldsetlist::getInstance()->instantiatePixmaps();
     dialog->show_all();
-    dialog->run();
+  update_shields();
+    int response = dialog->run();
+    if (response == 0)
+      return true;
+    return false;
+}
+
+SDL_Surface *GamePreferencesDialog::getShieldPic(Uint32 type, Uint32 owner)
+{
+  Shieldsetlist *sl = Shieldsetlist::getInstance();
+  std::string shieldset = "default";
+  if (shield_theme_combobox->is_sensitive() == true)
+    shieldset = sl->getShieldsetDir
+      (Glib::filename_from_utf8(shield_theme_combobox->get_active_text()));
+  else if (load_map_parameters.shield_theme != "")
+    shieldset = load_map_parameters.shield_theme;
+
+  ShieldStyle *sh= sl->getShield(shieldset, type, owner);
+  SDL_Color color = sl->getMaskColor(shieldset, owner);
+  return GraphicsCache::applyMask(sh->getPixmap(), sh->getMask(), color, false);
 }
 
 void GamePreferencesDialog::add_player(const Glib::ustring &type,
@@ -273,9 +316,10 @@ void GamePreferencesDialog::add_player(const Glib::ustring &type,
   else if (type== NO_PLAYER_TYPE)
     player_type->set_active(3);
 
+
   player_types.push_back(player_type);
   player_names.push_back(player_name);
-  player_hbox->add(*manage(player_name));
+  player_hbox->pack_start(*manage(player_name), Gtk::PACK_SHRINK, 10);
   player_hbox->add(*manage(player_type));
   players_vbox->add(*manage(player_hbox));
 }
@@ -334,7 +378,7 @@ void GamePreferencesDialog::on_random_map_toggled()
 		(*c)->set_sensitive(true);
 		(*c)->set_active((*i).type);
 		(*e)->set_sensitive(true);
-		(*e)->set_name((*i).name);
+		(*e)->set_text((*i).name);
 	      }
 	  }
 	else
@@ -345,6 +389,7 @@ void GamePreferencesDialog::on_random_map_toggled()
 
     load_map_filechooser->set_sensitive(!random_map);
     random_map_container->set_sensitive(random_map);
+    update_shields();
 }
 
 void GamePreferencesDialog::on_map_size_changed()
@@ -403,6 +448,41 @@ void GamePreferencesDialog::update_difficulty_combobox()
   else
     difficulty_combobox->set_active(CUSTOM);
 }
+
+void GamePreferencesDialog::update_shields()
+{
+  if (dialog->is_realized() == false)
+    return;
+  //get rid of the old shields
+  player_shields.clear();
+
+  std::vector<Gtk::Widget*> list;
+  list = players_vbox->get_children();
+
+  for (unsigned int i = 0; i < MAX_PLAYERS; i++)
+    {
+      Gtk::HBox *player_hbox = static_cast<Gtk::HBox*>(list[i + 1]);
+      std::vector<Gtk::Widget*> sublist;
+      sublist = player_hbox->get_children();
+      if (sublist.size() > 2)
+	  player_hbox->remove(*sublist[0]);
+    }
+
+  //make the shields and display them
+  for (unsigned int i = 0; i < MAX_PLAYERS; i++)
+    {
+      Gtk::Image *player_shield = new Gtk::Image
+	(to_pixbuf(getShieldPic(2, i)));
+      player_shields.push_back(player_shield);
+      Gtk::HBox *player_hbox = static_cast<Gtk::HBox*>(list[i + 1]);
+      player_hbox->pack_start(*manage(player_shield), Gtk::PACK_SHRINK, 10);
+      player_hbox->reorder_child(*player_shield, 0);
+      player_hbox->show_all();
+    }
+  players_vbox->show_all();
+
+}
+
 void GamePreferencesDialog::on_player_type_changed()
 {
   Uint32 offcount = 0;
@@ -542,14 +622,16 @@ void GamePreferencesDialog::on_start_game_clicked()
     else
 	g.map_path = load_map_filechooser->get_filename();
 
+    int id = 0;
     std::list<Gtk::ComboBoxText *>::iterator c = player_types.begin();
     std::list<Gtk::Entry *>::iterator e = player_names.begin();
-    for (; c != player_types.end(); c++, e++)
+    for (; c != player_types.end(); c++, e++, id++)
       {
 	GameParameters::Player p;
 	p.type = player_type_to_enum((*c)->get_active_text());
 	Glib::ustring name = (*e)->get_text();
 	p.name = name;
+	p.id = id;
 	g.players.push_back(p);
       }
 
@@ -594,6 +676,7 @@ void GamePreferencesDialog::on_start_game_clicked()
     else
       {
 	// and call callback
+	dialog->hide();
 	game_started(g);
       }
 }
@@ -686,7 +769,10 @@ void GamePreferencesDialog::on_difficulty_changed()
 	{
 	  std::list<Gtk::ComboBoxText *>::iterator c = player_types.begin();
 	  for (; c != player_types.end(); c++)
-	    (*c)->set_active (type_num);
+	    {
+	      if ((*c)->get_active_row_number() != 3)
+		(*c)->set_active (type_num);
+	    }
 	}
       update_difficulty_rating();
     }
@@ -748,6 +834,8 @@ void GamePreferencesDialog::on_map_chosen()
   load_map_parameters.players.clear();
   helper.registerTag("player",
 		     sigc::mem_fun(this, &GamePreferencesDialog::scan_players));
+  helper.registerTag("map",
+		     sigc::mem_fun(this, &GamePreferencesDialog::scan_shieldset));
 
   if (!helper.parse())
     {
@@ -756,8 +844,17 @@ void GamePreferencesDialog::on_map_chosen()
       return;
     }
   helper.close();
+  update_shields();
   return;
 }
+bool GamePreferencesDialog::scan_shieldset(std::string tag, XML_Helper* helper)
+{
+    if (tag == "map")
+      {
+        helper->getData(load_map_parameters.shield_theme, "shieldset");
+      }
+    return true;
+}
 bool GamePreferencesDialog::scan_players(std::string tag, XML_Helper* helper)
 {
     if (tag == "player")
