@@ -23,17 +23,20 @@
 #include <vector>
 #include <sigc++/signal.h>
 #include <gtkmm/window.h>
+#include <gtkmm/container.h>
 #include <gtkmm/dialog.h>
 #include <gtkmm/combobox.h>
 #include <gtkmm/comboboxtext.h>
 #include <gtkmm/radiobutton.h>
 #include <gtkmm/togglebutton.h>
+#include <gtkmm/image.h>
 #include <gtkmm/checkbutton.h>
 #include <gtkmm/filechooserbutton.h>
 #include <gtkmm/widget.h>
 #include <gtkmm/scale.h>
 
 #include "../game-parameters.h"
+#include <SDL.h>
 #include "game-options-dialog.h"
 
 class XML_Helper;
@@ -43,15 +46,18 @@ class GamePreferencesDialog
 {
  public:
     GamePreferencesDialog();
+    GamePreferencesDialog(std::string filename);
     ~GamePreferencesDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
     sigc::signal<void, GameParameters> game_started;
     
-    void run();
+    bool run();
+    void hide();
     
  private:
+    void init();
     std::auto_ptr<Gtk::Dialog> dialog;
 
     Gtk::Button *start_game_button;
@@ -61,6 +67,7 @@ class GamePreferencesDialog
     Gtk::ComboBoxText *city_theme_combobox;
     Gtk::Label *difficulty_label;
     Gtk::RadioButton *random_map_radio;
+    Gtk::RadioButton *load_map_radio;
     Gtk::FileChooserButton *load_map_filechooser;
     Gtk::Widget *random_map_container;
     Gtk::ComboBox *map_size_combobox;
@@ -92,6 +99,7 @@ class GamePreferencesDialog
     
     std::list<Gtk::ComboBoxText *> player_types;
     std::list<Gtk::Entry *> player_names;
+    std::list<Gtk::Image *> player_shields;
 
     GameOptionsDialog *game_options_dialog;
 
@@ -117,7 +125,10 @@ class GamePreferencesDialog
     bool is_greatest();
     void update_difficulty_combobox();
     void update_difficulty_rating();
+    void update_shields();
     bool scan_players(std::string tag, XML_Helper* helper);
+    bool scan_shieldset(std::string tag, XML_Helper* helper);
+SDL_Surface *getShieldPic(Uint32 type, Uint32 owner);
     GameParameters load_map_parameters;
 };
 
