@@ -76,6 +76,7 @@
 #include "diplomacy-report-dialog.h"
 #include "diplomacy-dialog.h"
 #include "stack-info-dialog.h"
+#include "timed-message-dialog.h"
 
 #include "../ucompose.hpp"
 #include "../defs.h"
@@ -84,7 +85,7 @@
 #include "../game.h"
 #include "../gamebigmap.h"
 #include "../smallmap.h"
-#include "../GameScenario.h"
+#include "../GameScenarioOptions.h"
 #include "../army.h"
 #include "../ruin.h"
 #include "../path.h"
@@ -113,6 +114,7 @@
 #include "../Configuration.h"
 #include "../GameMap.h"
 #include "../Item.h"
+#include "../shieldsetlist.h"
 
 
 GameWindow::GameWindow()
@@ -320,6 +322,7 @@ void GameWindow::show()
     
     sdl_container->show_all();
     window->show();
+    on_sdl_surface_changed();
 }
 
 void GameWindow::hide()
@@ -367,13 +370,14 @@ void GameWindow::init(int width, int height)
 }
 
 std::string
-create_and_dump_scenario(const std::string &file, const GameParameters &g)
+GameWindow::create_and_dump_scenario(const std::string &file, const GameParameters &g)
 {
     CreateScenario creator (g.map.width, g.map.height);
 
     // then fill the other players
     int c = 0;
     int army_id = Armysetlist::getInstance()->getArmysetId(g.army_theme);
+    Shieldsetlist *ssl = Shieldsetlist::getInstance();
     for (std::vector<GameParameters::Player>::const_iterator
 	     i = g.players.begin(), end = g.players.end();
 	 i != end; ++i, ++c) {
@@ -392,11 +396,13 @@ create_and_dump_scenario(const std::string &file, const GameParameters &g)
 	else
 	    type = Player::HUMAN;
 
-	creator.addPlayer(i->name, army_id, Player::get_color_for_no(c), type);
+	creator.addPlayer(i->name, army_id, ssl->getColor(g.shield_theme, 
+							  c), type);
     }
 
     // the neutral player must come last so it has the highest id among players
-    creator.addNeutral(_("Neutral"), army_id, Player::get_color_for_neutral(),
+    creator.addNeutral(_("Neutral"), army_id, 
+		       ssl->getColor(g.shield_theme, MAX_PLAYERS),
 		       Player::AI_DUMMY);
 
     // now fill in some map information
@@ -425,12 +431,16 @@ create_and_dump_scenario(const std::string &file, const GameParameters &g)
     std::string path = File::getSavePath();
     path += file;
     
+    //GenerationProgressWindow gpw;
+    //gpw.show_all();
+    //gpw.setGenerator(creator.getGenerator());
     creator.create(g);
     creator.dump(path);
     
     return path;
 }
 
+    
 void GameWindow::new_game(GameParameters g)
 {
     if (g.map_path.empty()) {
@@ -439,7 +449,29 @@ void GameWindow::new_game(GameParameters g)
 	g.map_path = path;
     }
 
-    bool success = setup_game(g.map_path);
+    stop_game();
+
+    bool broken = false;
+    GameScenario* game_scenario = new GameScenario(g.map_path, broken);
+
+    if (broken)
+      {
+	on_message_requested("Corrupted saved game file.");
+	game_ended.emit();
+	return;
+      }
+
+    if (game_scenario->getRound() == 0)
+      {
+	Playerlist::getInstance()->syncPlayers(g.players);
+	game_scenario->setupFog(g.hidden_map);
+	game_scenario->setupCities(g.quick_start);
+	game_scenario->setupDiplomacy(g.diplomacy);
+	game_scenario->nextRound();
+      }
+
+
+    bool success = setup_game(game_scenario);
     if (!success)
       return;
     setup_signals();
@@ -451,7 +483,20 @@ void GameWindow::new_game(GameParameters g)
 void GameWindow::load_game(std::string file_path)
 {
     current_save_filename = file_path;
-    bool success = setup_game(file_path);
+
+    stop_game();
+
+    bool broken = false;
+    GameScenario* game_scenario = new GameScenario(file_path, broken);
+
+    if (broken)
+      {
+	on_message_requested("Corrupted saved game file.");
+	game_ended.emit();
+	return;
+      }
+
+    bool success = setup_game(game_scenario);
     if (!success)
       return;
     setup_signals();
@@ -500,6 +545,9 @@ void GameWindow::setup_signals()
   connections.push_back 
     (game->received_diplomatic_proposal.connect 
      (sigc::mem_fun(*this, &GameWindow::change_diplomacy_button_image)));
+  connections.push_back 
+    (game->city_too_poor_to_produce.connect 
+     (sigc::mem_fun(*this, &GameWindow::show_city_production_report)));
   connections.push_back 
     (game->can_end_turn.connect 
      (sigc::mem_fun(*this, &GameWindow::update_diplomacy_button)));
@@ -711,6 +759,16 @@ void GameWindow::setup_signals()
 
 }
 
+void GameWindow::show_city_production_report (bool destitute)
+{
+  if (!destitute)
+    return;
+  ReportDialog d(Playerlist::getActiveplayer(), ReportDialog::PRODUCTION);
+  d.set_parent_window(*window.get());
+  d.run();
+  d.hide();
+}
+
 void GameWindow::change_diplomacy_button_image (bool proposals_present)
 {
   /* switch up the image. */
@@ -735,20 +793,9 @@ void GameWindow::update_diplomacy_button (bool sensitive)
   diplomacy_button->set_sensitive(sensitive);
 }
 
-bool GameWindow::setup_game(std::string file_path)
+bool GameWindow::setup_game(GameScenario *game_scenario)
 {
-  stop_game();
 
-  bool broken = false;
-  GameScenario* game_scenario = new GameScenario(file_path, broken);
-
-  if (broken)
-  {
-    on_message_requested("Corrupted saved game file.");
-    game_ended.emit();
-    return false;
-  }
-  
   Sound::getInstance()->haltMusic(false);
   Sound::getInstance()->enableBackground();
 
@@ -863,11 +910,11 @@ void GameWindow::on_load_game_activated()
 
   chooser.show_all();
   int res = chooser.run();
+  chooser.hide();
 
   if (res == Gtk::RESPONSE_ACCEPT)
     {
       std::string filename = chooser.get_filename();
-      chooser.hide();
       load_game(filename);
     }
 }
@@ -902,11 +949,11 @@ void GameWindow::on_save_game_as_activated()
 
   chooser.show_all();
   int res = chooser.run();
+  chooser.hide();
 
   if (res == Gtk::RESPONSE_ACCEPT)
     {
       std::string filename = chooser.get_filename();
-      chooser.hide();
 
       current_save_filename = filename;
 
@@ -930,6 +977,7 @@ void GameWindow::on_quit_activated()
   dialog->set_transient_for(*window.get());
 
   int response = dialog->run();
+  dialog->hide();
 
   if (response == 0) //end the game
     {
@@ -940,6 +988,8 @@ void GameWindow::on_quit_activated()
 
 void GameWindow::on_quests_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   Player *player = Playerlist::getActiveplayer();
   std::vector<Quest*> quests
     = QuestsManager::getInstance()->getPlayerQuests(player);
@@ -947,13 +997,17 @@ void GameWindow::on_quests_activated()
     {
       QuestReportDialog d(quests[0]);
       d.set_parent_window(*window.get());
-      return d.run();
+      d.run();
+      d.hide();
+      return;
     }
   else //no quest!
     {
       QuestReportDialog d(NULL);
       d.set_parent_window(*window.get());
-      return d.run();
+      d.run();
+      d.hide();
+      return;
     }
 }
 
@@ -967,6 +1021,8 @@ void GameWindow::on_fullscreen_activated()
 
 void GameWindow::on_signpost_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   std::auto_ptr<Gtk::Dialog> dialog;
 
   Glib::RefPtr<Gnome::Glade::Xml> xml
@@ -991,8 +1047,10 @@ void GameWindow::on_signpost_activated()
   Gtk::Entry *e;
   xml->get_widget("message_entry", e);
   e->set_text(s->getName());
+  e->set_activates_default(true);
   dialog->show_all();
   int response = dialog->run();
+  dialog->hide();
 
   if (response == 0)
     Playerlist::getActiveplayer()->signpostChange(s, e->get_text());
@@ -1003,9 +1061,12 @@ void GameWindow::on_signpost_activated()
   
 void GameWindow::on_stack_info_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   StackInfoDialog d(currently_selected_stack);
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
   //on_stack_info_changed(currently_selected_stack);
   //FIXME, armies don't stay selected in the right way.  to reproduce:
   //go in with all three selected.  deselect middle one in stackinfodialog,
@@ -1014,6 +1075,8 @@ void GameWindow::on_stack_info_activated()
 
 void GameWindow::on_disband_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   std::auto_ptr<Gtk::Dialog> dialog;
 
   Glib::RefPtr<Gnome::Glade::Xml> xml
@@ -1032,6 +1095,7 @@ void GameWindow::on_disband_activated()
   l->set_text(_("Are you sure you want to disband this group?"));
   dialog->show_all();
   int response = dialog->run();
+  dialog->hide();
 
   if (response == 0) //disband the active stack
     Playerlist::getActiveplayer()->stackDisband(NULL);
@@ -1039,8 +1103,31 @@ void GameWindow::on_disband_activated()
   return;
 }
 
+void GameWindow::on_resignation_completed()
+{
+  std::auto_ptr<Gtk::Dialog> dialog;
+
+  Glib::RefPtr<Gnome::Glade::Xml> xml
+    = Gnome::Glade::Xml::create(get_glade_path() + 
+				"/player-resign-completed-dialog.glade");
+
+  Gtk::Dialog *d;
+  xml->get_widget("dialog", d);
+  dialog.reset(d);
+  dialog->set_transient_for(*window.get());
+
+  dialog->show_all();
+  dialog->run();
+  dialog->hide();
+
+  return;
+}
+
 void GameWindow::on_resign_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
+
   std::auto_ptr<Gtk::Dialog> dialog;
 
   Glib::RefPtr<Gnome::Glade::Xml> xml
@@ -1061,7 +1148,11 @@ void GameWindow::on_resign_activated()
   int response = dialog->run();
 
   if (response == 0) //disband all stacks, raze all cities
-    Playerlist::getActiveplayer()->resign();
+    {
+      Playerlist::getActiveplayer()->resign();
+      dialog->hide();
+      on_resignation_completed();
+    }
 
   return;
 }
@@ -1069,34 +1160,45 @@ void GameWindow::on_resign_activated()
 void GameWindow::on_preferences_activated()
 {
   Player *current = Playerlist::getInstance()->getActiveplayer();
-  PreferencesDialog d;
+  PreferencesDialog d(false);
   d.set_parent_window(*window.get());
   d.run(game.get());
+  d.hide();
   if (current != Playerlist::getInstance()->getActiveplayer())
     game->end_turn();
 }
 
 void GameWindow::on_group_ungroup_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   group_ungroup_toggle->set_active(!group_ungroup_toggle->get_active());
 }
 
 void GameWindow::on_fight_order_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   FightOrderDialog d(Playerlist::getActiveplayer());
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_levels_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   HeroLevelsDialog d(Playerlist::getActiveplayer());
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_ruin_report_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   Vector<int> pos;
   pos.x = 0;
   pos.y = 0;
@@ -1106,93 +1208,130 @@ void GameWindow::on_ruin_report_activated()
   RuinReportDialog d(pos);
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_army_bonus_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   ArmyBonusDialog d(Playerlist::getActiveplayer());
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_item_bonus_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   ItemBonusDialog d;
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_army_report_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   ReportDialog d(Playerlist::getActiveplayer(), ReportDialog::ARMY);
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_city_report_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   ReportDialog d(Playerlist::getActiveplayer(), ReportDialog::CITY);
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_gold_report_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   ReportDialog d(Playerlist::getActiveplayer(), ReportDialog::GOLD);
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_production_report_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   ReportDialog d(Playerlist::getActiveplayer(), ReportDialog::PRODUCTION);
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_winning_report_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   ReportDialog d(Playerlist::getActiveplayer(), ReportDialog::WINNING);
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 void GameWindow::on_city_history_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   HistoryReportDialog d(Playerlist::getActiveplayer(), 
 			HistoryReportDialog::CITY);
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_event_history_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   HistoryReportDialog d(Playerlist::getActiveplayer(),
 			HistoryReportDialog::EVENTS);
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_gold_history_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   HistoryReportDialog d(Playerlist::getActiveplayer(),
 			HistoryReportDialog::GOLD);
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_winner_history_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   HistoryReportDialog d(Playerlist::getActiveplayer(),
 			HistoryReportDialog::WINNING);
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_triumphs_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   TriumphsDialog d(Playerlist::getActiveplayer());
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_help_about_activated()
@@ -1212,22 +1351,29 @@ void GameWindow::on_help_about_activated()
   dialog->set_logo(to_pixbuf(logo));
   dialog->show_all();
   dialog->run();
+  dialog->hide();
 
   return;
 }
 
 void GameWindow::on_diplomacy_report_activated()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   DiplomacyReportDialog d(Playerlist::getActiveplayer());
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_diplomacy_button_clicked()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   DiplomacyDialog d(Playerlist::getActiveplayer());
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::stop_game()
@@ -1272,6 +1418,7 @@ void GameWindow::on_game_over(Player *winner)
 
   dialog->show_all();
   dialog->run();
+  dialog->hide();
 
   stop_game();
   game_ended.emit();
@@ -1281,18 +1428,6 @@ void GameWindow::on_player_died(Player *player)
 {
   assert(player);
 
-  std::auto_ptr<Gtk::Dialog> dialog;
-
-  Glib::RefPtr<Gnome::Glade::Xml> xml
-    = Gnome::Glade::Xml::create(get_glade_path() + "/player-died-dialog.glade");
-
-  Gtk::Dialog *d;
-  xml->get_widget("dialog", d);
-  dialog.reset(d);
-  dialog->set_transient_for(*window.get());
-
-  Gtk::Label *label;
-  xml->get_widget("label", label);
   Glib::ustring s;
   s += String::ucompose(_("The rule of %1 has permanently ended!"),
 			player->getName());
@@ -1308,18 +1443,22 @@ void GameWindow::on_player_died(Player *player)
       s += "\n";
       s += _("and visit the sites of thy old battles.");
     }
-  label->set_text(s);
 
-  dialog->show_all();
-  dialog->run();
+  TimedMessageDialog dialog(*window.get(), s, 30);
+
+  dialog.show_all();
+  dialog.run();
+  dialog.hide();
 }
 
 void GameWindow::on_message_requested(std::string msg)
 {
   // FIXME: this is a bit crude, maybe beef it up
   Gtk::MessageDialog dialog(*window.get(), msg);
+  //TimedMessageDialog dialog(*window.get(), msg, 30, 5);
   dialog.show_all();
   dialog.run();
+  dialog.hide();
 }
 
 void GameWindow::on_army_toggled(Gtk::ToggleButton *toggle, Army *army)
@@ -1419,7 +1558,7 @@ void GameWindow::on_sidebar_stats_changed(SidebarStats s)
   gold_stats_label->set_text(String::ucompose("%1", s.gold));
   income_stats_label->set_text(String::ucompose("%1", s.income));
   upkeep_stats_label->set_text(String::ucompose("%1", s.upkeep));
-  turn_label->set_text(String::ucompose("Turn %1", s.turns + 1));
+  turn_label->set_text(String::ucompose("Turn %1", s.turns));
 }
 
 void GameWindow::on_smallmap_changed(SDL_Surface *map)
@@ -1594,6 +1733,7 @@ void GameWindow::on_sage_visited (Ruin *ruin, Stack *stack)
 	       static_cast<Hero*>(stack->getFirstHero()), ruin);
   d.set_parent_window(*window.get());
   Reward *reward = d.run();
+  d.hide();
   ruin->setReward(reward);
 }
 
@@ -1602,6 +1742,7 @@ void GameWindow::on_ruin_rewarded (Reward_Ruin *reward)
   RuinRewardedDialog d(reward);
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_ruin_searched(Ruin *ruin, Stack *stack, Reward *reward)
@@ -1629,32 +1770,33 @@ void GameWindow::on_ruin_searched(Ruin *ruin, Stack *stack, Reward *reward)
 
   Glib::ustring s = label->get_text();
   s += "\n\n";
-  s += String::ucompose("%1 finds ", stack->getFirstHero()->getName());
+  s += String::ucompose(_("%1 finds "), stack->getFirstHero()->getName());
   if (reward->getType() == Reward::GOLD)
     {
       Reward_Gold *gold = dynamic_cast<Reward_Gold*>(reward);
-      s += String::ucompose("%1 gold pieces.", gold->getGold());
+      s += String::ucompose(_("%1 gold pieces."), gold->getGold());
     }
   else if (reward->getType() == Reward::ALLIES)
     {
       Reward_Allies *allies = dynamic_cast<Reward_Allies*>(reward);
-      s += String::ucompose("%1 allies.", allies->getNoOfAllies());
+      s += String::ucompose(_("%1 allies!"), allies->getNoOfAllies());
     }
   else if (reward->getType() == Reward::ITEM)
     {
       Reward_Item *item = dynamic_cast<Reward_Item*>(reward);
-      s += String::ucompose("the %1.", item->getItem()->getName());
+      s += String::ucompose(_("the %1!"), item->getItem()->getName());
     }
   else if (reward->getType() == Reward::MAP)
     {
       Reward_Map *map = dynamic_cast<Reward_Map*>(reward);
-      s += String::ucompose("the %2.", map->getName());
+      s += String::ucompose(_("a map!"), map->getName());
     }
 
   label->set_text(s);
 
   dialog->show_all();
   dialog->run();
+  dialog->hide();
 }
 
 void GameWindow::on_ruinfight_started(Stack *attackers, Stack *defenders)
@@ -1682,6 +1824,7 @@ void GameWindow::on_ruinfight_started(Stack *attackers, Stack *defenders)
 
   dialog->show_all();
   dialog->run();
+  dialog->hide();
 }
 void GameWindow::on_ruinfight_finished(Fight::Result result)
 {
@@ -1719,6 +1862,7 @@ void GameWindow::on_ruinfight_finished(Fight::Result result)
 
   dialog->show_all();
   dialog->run();
+  dialog->hide();
 }
 
 void GameWindow::on_fight_started(Fight &fight)
@@ -1727,6 +1871,7 @@ void GameWindow::on_fight_started(Fight &fight)
 
   d.set_parent_window(*window.get());
   d.run(&d_quick_fights);
+  d.hide();
   if (Playerlist::getActiveplayer()->getType() == Player::HUMAN)
     d_quick_fights = false;
 }
@@ -1755,20 +1900,25 @@ void GameWindow::on_hero_brings_allies (int numAllies)
 
   dialog->show_all();
   dialog->run();
+  dialog->hide();
 }
 
 bool GameWindow::on_hero_offers_service(Player *player, Hero *hero, City *city, int gold)
 {
   HeroOfferDialog d(player, hero, city, gold);
   d.set_parent_window(*window.get());
-  return d.run();
+  bool retval = d.run();
+  d.hide();
+  return retval;
 }
 
 bool GameWindow::on_enemy_offers_surrender(int numPlayers)
 {
   SurrenderDialog d(numPlayers);
   d.set_parent_window(*window.get());
-  return d.run();
+  bool retval = d.run();
+  d.hide();
+  return retval;
 }
 
 void GameWindow::on_surrender_answered (bool accepted)
@@ -1781,6 +1931,7 @@ void GameWindow::on_surrender_answered (bool accepted)
       SurrenderRefusedDialog d;
       d.set_parent_window(*window.get());
       d.run();
+      d.hide();
     }
 }
 
@@ -1806,6 +1957,7 @@ bool GameWindow::on_stack_considers_treachery (Player *me, Stack *stack,
   label->set_text(s);
   dialog->show_all();
   int retval = dialog->run();
+  dialog->hide();
   if (retval == Gtk::RESPONSE_DELETE_EVENT)
     return false;
   else if (retval)
@@ -1820,6 +1972,7 @@ void GameWindow::on_temple_visited(Temple *temple)
   RuinReportDialog d(temple->getPos());
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 bool GameWindow::on_temple_searched(bool hasHero, Temple *temple, int blessCount)
@@ -1876,6 +2029,7 @@ bool GameWindow::on_temple_searched(bool hasHero, Temple *temple, int blessCount
     }
 
   int response = dialog->run();
+  dialog->hide();
 
   if (hasHero == false || GameScenario::s_play_with_quests == false)
     response = 1;
@@ -1890,7 +2044,8 @@ void GameWindow::on_quest_assigned(Hero *hero, Quest *quest)
 {
   QuestAssignedDialog d(hero, quest);
   d.set_parent_window(*window.get());
-  return d.run();
+  d.run();
+  d.hide();
 }
 
 static bool
@@ -2014,8 +2169,8 @@ CityDefeatedAction GameWindow::on_city_defeated(City *city, int gold)
   xml->get_widget("raze_button", raze_button);
 
   raze_button->set_sensitive
-    (game->getScenario()->s_razing_cities == GameParameters::ON_CAPTURE || 
-     game->getScenario()->s_razing_cities == GameParameters::ALWAYS);
+    (GameScenarioOptions::s_razing_cities == GameParameters::ON_CAPTURE || 
+     GameScenarioOptions::s_razing_cities == GameParameters::ALWAYS);
 
   if (h) /* if there was a hero in the stack */
     {
@@ -2062,6 +2217,7 @@ CityDefeatedAction GameWindow::on_city_defeated(City *city, int gold)
   dialog->show();
 
   int response = dialog->run();
+  dialog->hide();
   switch (response) {
   default:
   case 0: return CITY_DEFEATED_OCCUPY;
@@ -2096,6 +2252,7 @@ void GameWindow::on_city_looted (City *city, int gold)
 
   dialog->show_all();
   dialog->run();
+  dialog->hide();
 }
 void GameWindow::on_city_pillaged(City *city, int gold, int pillaged_army_type)
 {
@@ -2147,6 +2304,7 @@ void GameWindow::on_city_pillaged(City *city, int gold, int pillaged_army_type)
 
   dialog->show_all();
   dialog->run();
+  dialog->hide();
 }
 
 void GameWindow::on_city_sacked(City *city, int gold, std::list<Uint32> sacked_types)
@@ -2247,6 +2405,7 @@ void GameWindow::on_city_sacked(City *city, int gold, std::list<Uint32> sacked_t
     }
   dialog->show_all();
   dialog->run();
+  dialog->hide();
 }
 
 void GameWindow::on_city_razed (City *city)
@@ -2271,16 +2430,18 @@ void GameWindow::on_city_razed (City *city)
 
   dialog->show_all();
   dialog->run();
+  dialog->hide();
 }
 
 void GameWindow::on_city_visited(City *city)
 {
   CityWindow d(city, 
-	       game->getScenario()->s_razing_cities == GameParameters::ALWAYS,
-	       GameScenario::s_see_opponents_production);
+	       GameScenarioOptions::s_razing_cities == GameParameters::ALWAYS,
+	       GameScenarioOptions::s_see_opponents_production);
 
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::on_ruin_visited(Ruin *ruin)
@@ -2288,6 +2449,7 @@ void GameWindow::on_ruin_visited(Ruin *ruin)
   RuinReportDialog d(ruin->getPos());
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 
 void GameWindow::show_shield_turn()
@@ -2352,6 +2514,7 @@ void GameWindow::on_next_player_turn(Player *player, unsigned int turn_number)
 
       dialog->show_all();
       dialog->run();
+      dialog->hide();
       show();
     }
 	
@@ -2385,6 +2548,7 @@ void GameWindow::on_medal_awarded_to_army(Army *army)
 
   dialog->show_all();
   dialog->run();
+  dialog->hide();
 }
 
 Army::Stat GameWindow::on_army_gains_level(Army *army)
@@ -2393,6 +2557,7 @@ Army::Stat GameWindow::on_army_gains_level(Army *army)
 
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 
   return d.get_selected_stat();
 }
@@ -2417,13 +2582,15 @@ void GameWindow::on_game_loaded(Player *player)
 
   dialog->show_all();
   dialog->run();
+  dialog->hide();
 }
 
 void GameWindow::on_quest_completed(Quest *quest, Reward *reward)
 {
   QuestCompletedDialog d(quest, reward);
   d.set_parent_window(*window.get());
-  return d.run();
+  d.run();
+  d.hide();
 }
 
 void GameWindow::on_quest_expired(Quest *quest)
@@ -2460,22 +2627,30 @@ void GameWindow::on_quest_expired(Quest *quest)
 
   dialog->show_all();
   dialog->run();
+  dialog->hide();
 }
 
 void GameWindow::on_inspect_activated ()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   HeroDialog d(dynamic_cast<Hero*>(currently_selected_stack->getFirstHero()), 
 	       currently_selected_stack->getPos());
   d.set_parent_window(*window.get());
   d.run();
+  d.hide();
 }
 void GameWindow::on_plant_standard_activated ()
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   Playerlist::getActiveplayer()->heroPlantStandard(NULL);
 }
     
 void GameWindow::on_advice_asked(float percent)
 {
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
   //we asked for advice on a fight, and we're being told that we 
   //have a PERCENT chance of winning the fight
   std::auto_ptr<Gtk::Dialog> dialog;
@@ -2549,5 +2724,7 @@ void GameWindow::on_advice_asked(float percent)
 
   dialog->show_all();
   dialog->run();
+  dialog->hide();
   return;
 }
+
