@@ -47,6 +47,7 @@
 #include "../vector.h"
 #include "../army.h"
 #include "../GraphicsCache.h"
+#include "../GameScenario.h"
 
 class Game;
 class SDL_Surface;
@@ -92,6 +93,9 @@ class GameWindow: public sigc::trackable
 
     sigc::signal<void> sdl_initialized;
     
+
+    static std::string create_and_dump_scenario(const std::string &file, const GameParameters &g);
+
  private:
     std::auto_ptr<Gtk::Window> window;
     std::auto_ptr<Gtk::Window> map_tip;	// tooltip appears over the map
@@ -180,6 +184,7 @@ class GameWindow: public sigc::trackable
     void on_disband_activated();
     void on_stack_info_activated();
     void on_resign_activated();
+    void on_resignation_completed();
     void on_signpost_activated();
     void on_inspect_activated();
     void on_plant_standard_activated();
@@ -269,9 +274,10 @@ class GameWindow: public sigc::trackable
     void on_city_looted(City *city, int gold);
     void hide_map_tip();
     void change_diplomacy_button_image (bool proposals_present);
+    void show_city_production_report (bool destitute);
     void update_diplomacy_button (bool sensitive);
 
-    bool setup_game(std::string file_path);
+    bool setup_game(GameScenario *game_scenario);
     void setup_signals();
     void stop_game();
     std::list<sigc::connection> connections;
