@@ -74,6 +74,11 @@ void HeroLevelsDialog::set_parent_window(Gtk::Window &parent)
     //dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
 }
 
+void HeroLevelsDialog::hide()
+{
+  dialog->hide();
+}
+
 void HeroLevelsDialog::run()
 {
     static int width = -1;
