@@ -101,6 +101,11 @@ void HeroOfferDialog::set_parent_window(Gtk::Window &parent)
     //dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
 }
 
+void HeroOfferDialog::hide()
+{
+  dialog->hide();
+}
+
 bool HeroOfferDialog::run()
 {
     heromap->resize();
