@@ -308,6 +308,7 @@ void HistoryReportDialog::generatePastCitylists()
 	break;
 
     }
+  past_citylists.erase(--past_citylists.end());
 }
 
 void HistoryReportDialog::set_parent_window(Gtk::Window &parent)
@@ -316,6 +317,11 @@ void HistoryReportDialog::set_parent_window(Gtk::Window &parent)
   //dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
 }
 
+void HistoryReportDialog::hide()
+{
+  dialog->hide();
+}
+
 void HistoryReportDialog::run()
 {
   historymap->resize();
@@ -397,7 +403,7 @@ void HistoryReportDialog::fill_in_turn_info(Uint32 turn)
   //update the city chart
   std::list<Uint32> citylist = *past_citycounts.begin();
   it = citylist.begin();
-  count=1;
+  count = 0;
   for (; it != citylist.end(); it++, count++)
     {
       if (count == turn)
@@ -524,7 +530,7 @@ void HistoryReportDialog::addHistoryEvent(History *event)
 	{
 	  History_PlayerVanquished *ev;
 	  ev = static_cast<History_PlayerVanquished*>(event);
-	  s = String::ucompose(_("%1 is vanquished!"), p->getName());
+	  s = String::ucompose(_("%1 utterly vanquished!"), p->getName());
 	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
 	  break;
 	}
