@@ -71,6 +71,11 @@ void LoadScenarioDialog::set_parent_window(Gtk::Window &parent)
     //dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
 }
 
+void LoadScenarioDialog::hide()
+{
+  dialog->hide();
+}
+
 void LoadScenarioDialog::run()
 {
     static int width = -1;
