@@ -37,8 +37,9 @@
 #include "../GraphicsCache.h"
 
 
-PreferencesDialog::PreferencesDialog()
+PreferencesDialog::PreferencesDialog(bool readonly)
 {
+  d_readonly = readonly;
     Glib::RefPtr<Gnome::Glade::Xml> xml
 	= Gnome::Glade::Xml::create(get_glade_path()
 				    + "/preferences-dialog.glade");
@@ -70,6 +71,8 @@ PreferencesDialog::PreferencesDialog()
 	  type->set_active(1);
 	if ((*i)->isDead())
 	  type->set_sensitive(false);
+	if (readonly)
+	  type->set_sensitive(false);
 	player_hbox->pack_start(*manage(image), Gtk::PACK_SHRINK, 
 				Gtk::PACK_SHRINK);
 	player_hbox->pack_start(*manage(type), Gtk::PACK_SHRINK, 10);
@@ -99,6 +102,11 @@ void PreferencesDialog::set_parent_window(Gtk::Window &parent)
     //dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
 }
 
+void PreferencesDialog::hide()
+{
+  dialog->hide();
+}
+
 void PreferencesDialog::run(Game *game)
 {
     static int width = -1;
