@@ -79,16 +79,17 @@ ReportDialog::ReportDialog(Player *player, ReportType type)
   armies_treeview->append_column("", armies_columns.desc);
 
   //loop through the action list looking for production actions
+  std::list<Action*> actions = player->getReportableActions();
   Uint32 total = 0;
-  std::list<Action*> *actions = player->getActionlist();
   std::list<Action*>::const_iterator it;
-  for (it = actions->begin(); it != actions->end(); it++)
-   if ((*it)->getType() == Action::PRODUCE_UNIT ||
-      (*it)->getType() == Action::PRODUCE_VECTORED_UNIT)
-     {
-       addProduction(*it);
-       total++;
-     }
+  for (it = actions.begin(); it != actions.end(); it++)
+    {
+      if ((*it)->getType() == Action::PRODUCE_UNIT ||
+	  (*it)->getType() == Action::PRODUCE_VECTORED_UNIT)
+	total++;
+    addProduction(*it);
+    }
+
   Glib::ustring s;
   s = String::ucompose(ngettext("You produced %1 army this turn!",
 				"You produced %1 armies this turn!",
@@ -124,6 +125,11 @@ void ReportDialog::set_parent_window(Gtk::Window &parent)
   //dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
 }
 
+void ReportDialog::hide()
+{
+  dialog->hide();
+}
+
 void ReportDialog::run()
 {
   citymap->resize();
@@ -370,6 +376,15 @@ void ReportDialog::addProduction(const Action *action)
       else
 	s += _("Standard");
     }
+  else if (action->getType() == Action::CITY_DESTITUTE)
+    {
+      const Action_CityTooPoorToProduce *act;
+      act = dynamic_cast<const Action_CityTooPoorToProduce*>(action);
+      army_type = act->getArmyType();
+      City *c = Citylist::getInstance()->getById(act->getCityId());
+      s = c->getName();
+      s += " stops production!";
+    }
   const Army *a;
   a = Armysetlist::getInstance()->getArmy(p->getArmyset(), army_type);
   Gtk::TreeIter i = armies_list->append();
