@@ -21,12 +21,16 @@
 #include <sigc++/slot.h>
 #include <libglademm/xml.h>
 #include <gtkmm/window.h>
+#include <gtkmm/dialog.h>
 #include <gtkmm/image.h>
 #include <gtkmm/table.h>
+#include <gtkmm/radiobutton.h>
 #include <gtkmm/filechooserdialog.h>
+#include <gtkmm/messagedialog.h>
 #include <gtkmm/stock.h>
 
 #include "splash-window.h"
+#include "game-window.h"
 
 #include "game-preferences-dialog.h"
 #include "load-scenario-dialog.h"
@@ -34,10 +38,24 @@
 #include "../Configuration.h"
 #include "../defs.h"
 #include "../sound.h"
+#include "../File.h"
+#include "../GameScenario.h"
+#include "../playerlist.h"
+#include "game-lobby-dialog.h"
+#include "network-game-selector-dialog.h"
 //#include "../netggz.h"
+#include "gtksdl.h"
 
+namespace
+{
+  void surface_attached_helper(GtkSDL *gtksdl, gpointer data)
+    {
+      static_cast<SplashWindow*>(data)->on_sdl_surface_changed();
+    }
+}
 SplashWindow::SplashWindow()
 {
+  sdl_inited = false;
 #if 0
     d_networkcancelled = false;
     d_networkready = false;
@@ -50,6 +68,7 @@ SplashWindow::SplashWindow()
     xml->get_widget("window", w);
     window.reset(w);
 
+    xml->get_widget("sdl_container", sdl_container);
     w->signal_delete_event().connect(
 	sigc::mem_fun(*this, &SplashWindow::on_delete_event));
     
@@ -71,7 +90,40 @@ SplashWindow::SplashWindow()
     xml->connect_clicked("quit_button",
 			 sigc::mem_fun(*this, &SplashWindow::on_quit_clicked));
 
+    xml->connect_clicked("new_network_game_button",
+			 sigc::mem_fun(*this, &SplashWindow::on_new_network_game_clicked));
     Sound::getInstance()->playMusic("intro");
+
+    if (Configuration::s_autosave_policy == 1)
+      {
+	Gtk::VBox *button_box;
+	xml->get_widget("button_box", button_box);
+  
+	std::string filename = File::getSavePath() + "autosave.sav";
+	FILE *fileptr = fopen (filename.c_str(), "r");
+	if (fileptr)
+	  {
+	    fclose (fileptr);
+	    crash_button = Gtk::manage(new Gtk::Button());
+	    crash_button->set_label(_("Rescue Crashed Game"));
+	    button_box->pack_start(*crash_button, true, true, 0);
+	    crash_button->signal_clicked().connect(sigc::mem_fun(*this, &SplashWindow::on_rescue_crashed_game_clicked));
+	    button_box->reorder_child(*crash_button, 0);
+	  }
+      }
+
+  sdl_widget = Gtk::manage(Glib::wrap(gtk_sdl_new(1,1,0,SDL_SWSURFACE)));
+  sdl_widget->grab_focus();
+  sdl_widget->add_events(Gdk::KEY_PRESS_MASK | Gdk::BUTTON_PRESS_MASK | 
+			 Gdk::BUTTON_RELEASE_MASK | Gdk::POINTER_MOTION_MASK | 
+			 Gdk::LEAVE_NOTIFY_MASK);
+
+      // connect to the special signal that signifies that a new surface has been
+      // generated and attached to the widget 
+  g_signal_connect(G_OBJECT(sdl_widget->gobj()), "surface-attached", 
+     G_CALLBACK(surface_attached_helper), this); 
+      
+      sdl_container->add(*sdl_widget); 
 }
 
 SplashWindow::~SplashWindow()
@@ -82,11 +134,13 @@ SplashWindow::~SplashWindow()
 
 void SplashWindow::show()
 {
+    sdl_container->show_all();
     window->show_all();
 }
 
 void SplashWindow::hide()
 {
+  sdl_container->hide();
     window->hide();
 }
 
@@ -102,6 +156,13 @@ void SplashWindow::on_quit_clicked()
     quit_requested.emit();
 }
 
+void SplashWindow::on_rescue_crashed_game_clicked()
+{
+  delete crash_button;
+  std::string filename = File::getSavePath() + "autosave.sav";
+  load_requested.emit(filename);
+}
+
 void SplashWindow::on_new_game_clicked()
 {
     GamePreferencesDialog d;
@@ -135,6 +196,54 @@ void SplashWindow::on_load_game_clicked()
     }
 }
 
+void SplashWindow::on_new_network_game_clicked()
+{
+  Glib::RefPtr<Gnome::Glade::Xml> xml
+    = Gnome::Glade::Xml::create(get_glade_path() + 
+				"/new-network-game-dialog.glade");
+  std::auto_ptr<Gtk::Dialog> dialog;
+  Gtk::Dialog *d;
+  Gtk::RadioButton *client_radiobutton;
+  xml->get_widget("dialog", d);
+  dialog.reset(d);
+  xml->get_widget("client_radiobutton", client_radiobutton);
+  dialog->set_transient_for(*window.get());
+  int response = dialog->run();
+  if (response == 0) //we hit okay
+    {
+      if (client_radiobutton->get_active() == true)
+	{
+	  Gtk::MessageDialog mdialog(*window.get(), "not implemented yet.");
+	  mdialog.show_all();
+	  mdialog.run();
+	  NetworkGameSelectorDialog ngsd;
+	  ngsd.game_selected.connect(sigc::mem_fun(*this, &SplashWindow::on_network_game_selected));
+	  ngsd.run();
+	  //okay, we're a client.
+	  //ask which ip
+	  //go get the file
+	  //std::string filename;
+	  //launch lobby.. emit something?
+	  //GameLobbyDialog gld(filename, false);
+	  //return gld.run();
+	}
+      else
+	{
+	  Gtk::MessageDialog mdialog(*window.get(), "not implemented yet.");
+	  mdialog.show_all();
+	  mdialog.run();
+	  //okay, we're a server.
+	  GamePreferencesDialog gpd;
+    
+	  gpd.set_parent_window(*window.get());
+	  gpd.game_started.connect(sigc::mem_fun(*this, &SplashWindow::on_network_game_created));
+	  gpd.run();
+	  return;
+	}
+    }
+
+}
+
 void SplashWindow::on_load_scenario_clicked()
 {
     LoadScenarioDialog d;
@@ -145,7 +254,56 @@ void SplashWindow::on_load_scenario_clicked()
     
     std::string filename = d.get_scenario_filename();
     if (!filename.empty())
-	load_requested.emit(filename);
+      {
+	GamePreferencesDialog gp(filename);
+	gp.set_parent_window(*window.get());
+	gp.game_started.connect(sigc::mem_fun(*this, &SplashWindow::on_game_started));
+    
+	gp.run();
+      } 
+	//load_requested.emit(filename);
+}
+
+void SplashWindow::on_network_game_selected(std::string ip, unsigned short port)
+{
+  //go get the file!
+  //download it into a file called network.sav, and then:
+  std::string filename = File::getSavePath() + "network.sav";
+  new_network_game_requested.emit(filename, false);
+}
+
+void SplashWindow::on_network_game_created(GameParameters g)
+{
+  std::string filename;
+  if (g.map_path.empty()) 
+    {
+      // construct new random scenario if we're not going to load the game
+      std::string path = GameWindow::create_and_dump_scenario("random.map", g);
+      g.map_path = path;
+    }
+
+    bool broken = false;
+    GameScenario* game_scenario = new GameScenario(g.map_path, broken);
+
+    if (broken)
+      {
+	//on_message_requested("Corrupted saved game file.");
+	return;
+      }
+
+    if (game_scenario->getRound() == 0)
+      {
+	Playerlist::getInstance()->syncPlayers(g.players);
+	game_scenario->setupFog(g.hidden_map);
+	game_scenario->setupCities(g.quick_start);
+	game_scenario->setupDiplomacy(g.diplomacy);
+	game_scenario->nextRound();
+      }
+
+    filename = File::getSavePath() + "network.sav";
+    game_scenario->saveGame(filename);
+    delete game_scenario;
+    new_network_game_requested.emit(filename, true);
 }
 
 void SplashWindow::on_game_started(GameParameters g)
@@ -322,3 +480,12 @@ void SplashWindow::networkData()
 }
 
 #endif
+void
+SplashWindow::on_sdl_surface_changed()
+{
+  if (!sdl_inited)
+    {
+      sdl_inited = true;
+      sdl_initialized.emit();
+    }
+}
