@@ -21,8 +21,11 @@
 
 #include <memory>
 #include <gtkmm/window.h>
+#include <gtkmm/button.h>
 #include <sigc++/trackable.h>
 #include <sigc++/signal.h>
+#include <gtkmm/container.h>
+#include <gtkmm/widget.h>
 
 #include "../game-parameters.h"
 
@@ -44,13 +47,21 @@ class SplashWindow: public sigc::trackable
     void show();
     void hide();
         
+    Gtk::Window *get_window() {return window.get();}
+
+    sigc::signal<void> sdl_initialized;
+    sigc::signal<void, std::string, bool> new_network_game_requested;
     sigc::signal<void, GameParameters> new_game_requested;
     sigc::signal<void, std::string> load_requested;
     sigc::signal<void> quit_requested;
 
  private:
     std::auto_ptr<Gtk::Window> window;
+    Gtk::Button *crash_button;
 	
+    bool sdl_inited;
+    Gtk::Container *sdl_container;
+    Gtk::Widget *sdl_widget;
     bool on_delete_event(GdkEventAny *e);
     
     void on_new_campaign_clicked();
@@ -60,8 +71,11 @@ class SplashWindow: public sigc::trackable
     void on_load_scenario_clicked();
     void on_preferences_clicked();
     void on_quit_clicked();
+    void on_rescue_crashed_game_clicked();
 	
     void on_game_started(GameParameters g);
+    void on_network_game_created(GameParameters g);
+    void on_network_game_selected(std::string ip, unsigned short port);
 
 #if 0
     //! Separate network input thread
@@ -74,6 +88,8 @@ class SplashWindow: public sigc::trackable
     void networkData();
 #endif
         
+ public:
+    void on_sdl_surface_changed();
 };
 
 
