@@ -65,6 +65,11 @@ void StackInfoDialog::set_parent_window(Gtk::Window &parent)
     //dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
 }
 
+void StackInfoDialog::hide()
+{
+  dialog->hide();
+}
+
 void StackInfoDialog::run()
 {
     static int width = -1;
