@@ -1,3 +1,8 @@
+// Copyright (C) 2003, 2004, 2005, 2006 Ulf Lorenz
+// Copyright (C) 2004, 2005 Andrea Paternesi
+// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2008 Ole Laursen
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,8 +15,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #include <stdlib.h>
 #include <sstream>
@@ -24,15 +29,15 @@
 
 using namespace std;
 
-Hero::Hero(const Army& a, std::string name, Player *owner)
- : Army (a, owner)
+Hero::Hero(const Army& a, std::string name, Player *owner, bool for_template)
+  : Army (a, owner, for_template)
 {
     d_name = name;
     d_hero = true;
 }
 
 Hero::Hero(Hero& h)
-    :Army(h, h.d_player)
+  : Army(h, h.d_owner)
 {
     std::list<Item*>::iterator it;
 
