@@ -166,6 +166,11 @@ History_StartTurn::History_StartTurn()
 {
 }
 
+History_StartTurn::History_StartTurn(const History_StartTurn &history)
+:History(history)
+{
+}
+
 History_StartTurn::History_StartTurn(XML_Helper* helper)
 :History(History::START_TURN)
 {
@@ -208,6 +213,11 @@ History_FoundSage::History_FoundSage()
 {
 }
 
+History_FoundSage::History_FoundSage(const History_FoundSage &history)
+:History(history), d_hero(history.d_hero)
+{
+}
+
 History_FoundSage::History_FoundSage(XML_Helper* helper)
 :History(History::FOUND_SAGE)
 {
@@ -253,6 +263,11 @@ History_GoldTotal::History_GoldTotal()
 {
 }
 
+History_GoldTotal::History_GoldTotal(const History_GoldTotal &history)
+:History(history), d_gold(history.d_gold)
+{
+}
+
 History_GoldTotal::History_GoldTotal(XML_Helper* helper)
 :History(History::GOLD_TOTAL)
 {
@@ -298,6 +313,11 @@ History_HeroEmerges::History_HeroEmerges()
 {
 }
 
+History_HeroEmerges::History_HeroEmerges(const History_HeroEmerges &history)
+:History(history), d_hero(history.d_hero), d_city(history.d_city)
+{
+}
+
 History_HeroEmerges::History_HeroEmerges(XML_Helper* helper)
 :History(History::HERO_EMERGES)
 {
@@ -346,6 +366,11 @@ History_CityWon::History_CityWon()
 {
 }
 
+History_CityWon::History_CityWon(const History_CityWon &history)
+:History(history), d_city(history.d_city)
+{
+}
+
 History_CityWon::History_CityWon(XML_Helper* helper)
 :History(History::CITY_WON)
 {
@@ -392,6 +417,11 @@ History_HeroCityWon::History_HeroCityWon()
 {
 }
 
+History_HeroCityWon::History_HeroCityWon(const History_HeroCityWon &history)
+:History(history), d_hero(history.d_hero), d_city(history.d_city)
+{
+}
+
 History_HeroCityWon::History_HeroCityWon(XML_Helper* helper)
 :History(History::HERO_CITY_WON)
 {
@@ -442,6 +472,11 @@ History_CityRazed::History_CityRazed()
 {
 }
 
+History_CityRazed::History_CityRazed(const History_CityRazed &history)
+:History(history), d_city(history.d_city)
+{
+}
+
 History_CityRazed::History_CityRazed(XML_Helper* helper)
 :History(History::CITY_RAZED)
 {
@@ -487,6 +522,11 @@ History_HeroQuestStarted::History_HeroQuestStarted()
 {
 }
 
+History_HeroQuestStarted::History_HeroQuestStarted(const History_HeroQuestStarted &history)
+:History(history), d_hero(history.d_hero)
+{
+}
+
 History_HeroQuestStarted::History_HeroQuestStarted(XML_Helper* helper)
 :History(History::HERO_QUEST_STARTED)
 {
@@ -532,6 +572,11 @@ History_HeroQuestCompleted::History_HeroQuestCompleted()
 {
 }
 
+History_HeroQuestCompleted::History_HeroQuestCompleted(const History_HeroQuestCompleted &history)
+:History(history), d_hero(history.d_hero)
+{
+}
+
 History_HeroQuestCompleted::History_HeroQuestCompleted(XML_Helper* helper)
 :History(History::HERO_QUEST_COMPLETED)
 {
@@ -577,6 +622,11 @@ History_HeroKilledInCity::History_HeroKilledInCity()
 {
 }
 
+History_HeroKilledInCity::History_HeroKilledInCity(const History_HeroKilledInCity &history)
+:History(history), d_hero(history.d_hero), d_city(history.d_city)
+{
+}
+
 History_HeroKilledInCity::History_HeroKilledInCity(XML_Helper* helper)
 :History(History::HERO_KILLED_IN_CITY)
 {
@@ -625,6 +675,11 @@ History_HeroKilledInBattle::History_HeroKilledInBattle()
 {
 }
 
+History_HeroKilledInBattle::History_HeroKilledInBattle(const History_HeroKilledInBattle &history)
+:History(history), d_hero(history.d_hero)
+{
+}
+
 History_HeroKilledInBattle::History_HeroKilledInBattle(XML_Helper* helper)
 :History(History::HERO_KILLED_IN_BATTLE)
 {
@@ -670,6 +725,11 @@ History_HeroKilledSearching::History_HeroKilledSearching()
 {
 }
 
+History_HeroKilledSearching::History_HeroKilledSearching(const History_HeroKilledSearching &history)
+:History(history), d_hero(history.d_hero)
+{
+}
+
 History_HeroKilledSearching::History_HeroKilledSearching(XML_Helper* helper)
 :History(History::HERO_KILLED_SEARCHING)
 {
@@ -715,6 +775,11 @@ History_Score::History_Score()
 {
 }
 
+History_Score::History_Score(const History_Score &history)
+:History(history), d_score(history.d_score)
+{
+}
+
 History_Score::History_Score(XML_Helper* helper)
 :History(History::SCORE)
 {
@@ -760,6 +825,11 @@ History_PlayerVanquished::History_PlayerVanquished()
 {
 }
 
+History_PlayerVanquished::History_PlayerVanquished(const History_PlayerVanquished &history)
+:History(history)
+{
+}
+
 History_PlayerVanquished::History_PlayerVanquished(XML_Helper* helper)
 :History(History::PLAYER_VANQUISHED)
 {
@@ -797,6 +867,11 @@ History_DiplomacyPeace::History_DiplomacyPeace()
 {
 }
 
+History_DiplomacyPeace::History_DiplomacyPeace(const History_DiplomacyPeace &history)
+:History(history), d_opponent_id(history.d_opponent_id)
+{
+}
+
 History_DiplomacyPeace::History_DiplomacyPeace(XML_Helper* helper)
 :History(History::DIPLOMATIC_PEACE)
 {
@@ -843,6 +918,11 @@ History_DiplomacyWar::History_DiplomacyWar()
 {
 }
 
+History_DiplomacyWar::History_DiplomacyWar(const History_DiplomacyWar &history)
+:History(history), d_opponent_id(history.d_opponent_id)
+{
+}
+
 History_DiplomacyWar::History_DiplomacyWar(XML_Helper* helper)
 :History(History::DIPLOMATIC_WAR)
 {
@@ -889,6 +969,11 @@ History_DiplomacyTreachery::History_DiplomacyTreachery()
 {
 }
 
+History_DiplomacyTreachery::History_DiplomacyTreachery(const History_DiplomacyTreachery &history)
+:History(history), d_opponent_id(history.d_opponent_id)
+{
+}
+
 History_DiplomacyTreachery::History_DiplomacyTreachery(XML_Helper* helper)
 :History(History::DIPLOMATIC_TREACHERY)
 {
@@ -935,6 +1020,11 @@ History_HeroFindsAllies::History_HeroFindsAllies()
 {
 }
 
+History_HeroFindsAllies::History_HeroFindsAllies(const History_HeroFindsAllies &history)
+:History(history), d_hero(history.d_hero)
+{
+}
+
 History_HeroFindsAllies::History_HeroFindsAllies(XML_Helper* helper)
 :History(History::HERO_FINDS_ALLIES)
 {
