@@ -1,3 +1,10 @@
+// Copyright (C) 2001, 2002, 2003 Michael Bartl
+// Copyright (C) 2003, 2004, 2005, 2006 Ulf Lorenz
+// Copyright (C) 2004, 2005, 2006 Andrea Paternesi
+// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2007 Ole Laursen
+// Copyright (C) 2005, 2006 Josef Spillner
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +17,9 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -67,12 +76,6 @@ int main(int argc, char* argv[])
             {
                 kit.start_test_scenario = true;
             }
-#ifdef WITH_GGZ
-            if (parameter == "-g" || parameter == "--ggz")
-            {
-                Configuration::s_ggz = true;
-            }
-#endif 
             if (parameter == "--help" || parameter == "-h")
             {
                 cout << endl;
@@ -81,27 +84,12 @@ int main(int argc, char* argv[])
                 cout << _("-h,      --help             Shows this help screen\n");
                 cout << _("-c <size>                   Set the maximum cache size") <<endl;
                 cout << _("-t,      --test             Starting with a test-scenario") << endl;
-#ifdef WITH_GGZ
-                // deprecated, but should stay reserved for future use
-                //cout << _("-g,      --ggz              Run game in GGZ mode") << endl;
-#endif
 		cout << endl << endl;
                 exit(0);
             }
         }
     }
 
-    // New GGZ versions (>= 0.0.12) support the GGZMODE environment variable
-    // It is recommended over the -g/--ggz usage, which will be kept for compatibility
-#ifdef WITH_GGZ
-    char* ggzmode = getenv("GGZMODE");
-    if(ggzmode)
-    {
-        cout << _("Detected GGZ Gaming Zone environment") << endl;
-        Configuration::s_ggz = true;
-    }
-#endif
-
     // Check if armysets are in the path (otherwise exit)
     File::scanArmysets();
     File::scanTilesets();
