@@ -32,7 +32,8 @@ enum MessageType {
   MESSAGE_TYPE_PONG = 2,
   MESSAGE_TYPE_SENDING_MAP = 3,
   MESSAGE_TYPE_SENDING_ACTIONS = 4,
-  MESSAGE_TYPE_JOIN = 5
+  MESSAGE_TYPE_JOIN = 5,
+  MESSAGE_TYPE_SENDING_HISTORY = 6,
 };
 
 #endif
