@@ -33,6 +33,7 @@
 #include "Itemlist.h"
 #include "rewardlist.h"
 #include "QuestsManager.h"
+#include "Quest.h"
 #include "path.h"
 #include "GameMap.h"
 #include "army.h"
@@ -54,18 +55,19 @@ using namespace std;
 
 NetworkPlayer::NetworkPlayer(string name, Uint32 armyset, SDL_Color color, int width,
 		       int height, Player::Type type, int player_no)
-    :Player(name, armyset, color, width, height, type, player_no)
+    :Player(name, armyset, color, width, height, type, player_no),
+    d_connected(false)
 {
 }
 
 NetworkPlayer::NetworkPlayer(const Player& player)
-    :Player(player)
+    :Player(player), d_connected(false)
 {
     d_type = Player::NETWORKED;
 }
 
 NetworkPlayer::NetworkPlayer(XML_Helper* helper)
-    :Player(helper)
+    :Player(helper), d_connected(false)
 {
 }
 
@@ -106,6 +108,16 @@ void NetworkPlayer::levelArmy(Army* a)
   assert(false);
 }
 
+void NetworkPlayer::decodeActions(std::list<Action *> actions)
+{
+  std::list<Action*>::iterator it = actions.begin();
+  pruneActionlist();
+  for (; it != actions.end(); it++)
+    {
+     decodeAction(*it);
+    }
+}
+
 void NetworkPlayer::decodeAction(const Action *a)
 {
   switch(a->getType())
@@ -186,6 +198,12 @@ void NetworkPlayer::decodeAction(const Action *a)
     case Action::RECRUIT_HERO:
       return decodeActionRecruitHero
         (dynamic_cast<const Action_RecruitHero*>(a));
+    case Action::PLAYER_RENAME:
+      return decodeActionRenamePlayer
+        (dynamic_cast<const Action_RenamePlayer*>(a));
+    case Action::CITY_DESTITUTE:
+      return decodeActionCityTooPoorToProduce
+	(dynamic_cast<const Action_CityTooPoorToProduce*>(a));
     }
 
   return;
@@ -218,17 +236,17 @@ Item *findItemById(const std::list<Item *> &l, Uint32 id)
 
 void NetworkPlayer::decodeActionMove(const Action_Move *action)
 {
-  Stack *stack = d_stacklist->getStackById(action->d_stack);
-  stack->moveToDest(action->d_dest);
+  Stack *stack = d_stacklist->getStackById(action->getStackId());
+  stack->moveToDest(action->getEndingPosition());
   supdatingStack.emit(stack);
 }
 
 void NetworkPlayer::decodeActionSplit(const Action_Split *action)
 {
-  Stack *stack = d_stacklist->getStackById(action->d_orig);
+  Stack *stack = d_stacklist->getStackById(action->getStackId());
   
   for (unsigned int i = 0; i < MAX_STACK_SIZE; ++i) {
-    Uint32 army_id = action->d_armies_moved[i];
+    Uint32 army_id = action->getGroupedArmyId(i);
     if (army_id == 0)
       continue;
 
@@ -236,21 +254,24 @@ void NetworkPlayer::decodeActionSplit(const Action_Split *action)
     army->setGrouped(false);
   }
 
+  //fixme: the new stack should have an Id of getNewStackId()
   doStackSplit(stack);
 }
 
 void NetworkPlayer::decodeActionFight(const Action_Fight *action)
 {
   std::list<Stack *> attackers, defenders;
-  for (std::list<Uint32>::const_iterator i = action->d_attackers.begin(),
-         end = action->d_attackers.end(); i != end; ++i)
+  std::list<Uint32> attacker_army_ids = action->getAttackerArmyIds();
+  for (std::list<Uint32>::const_iterator i = attacker_army_ids.begin(),
+         end = attacker_army_ids.end(); i != end; ++i)
     attackers.push_back(d_stacklist->getStackById(*i));
 
-  for (std::list<Uint32>::const_iterator i = action->d_defenders.begin(),
-         end = action->d_defenders.end(); i != end; ++i)
+  std::list<Uint32> defender_army_ids = action->getDefenderArmyIds();
+  for (std::list<Uint32>::const_iterator i = defender_army_ids.begin(),
+         end = defender_army_ids.end(); i != end; ++i)
     defenders.push_back(findStackById(*i));
 
-  Fight fight(attackers, defenders, action->d_history);
+  Fight fight(attackers, defenders, action->getBattleHistory());
   fight.battleFromHistory();
   fight_started.emit(fight);
 
@@ -259,17 +280,17 @@ void NetworkPlayer::decodeActionFight(const Action_Fight *action)
 
 void NetworkPlayer::decodeActionJoin(const Action_Join *action)
 {
-  Stack *receiver = d_stacklist->getStackById(action->d_orig_id);
-  Stack *joining = d_stacklist->getStackById(action->d_joining_id);
+  Stack *receiver = d_stacklist->getStackById(action->getReceivingStackId());
+  Stack *joining = d_stacklist->getStackById(action->getJoiningStackId());
 
   doStackJoin(receiver, joining, false);
 }
 
 void NetworkPlayer::decodeActionRuin(const Action_Ruin *action)
 {
-  Stack *explorer = d_stacklist->getStackById(action->d_stack);
-  Ruin *r = Ruinlist::getInstance()->getById(action->d_ruin);
-  bool searched = action->d_searched;
+  Stack *explorer = d_stacklist->getStackById(action->getStackId());
+  Ruin *r = Ruinlist::getInstance()->getById(action->getRuinId());
+  bool searched = action->getSearchSuccessful();
 
   Stack* keeper = r->getOccupant();
 
@@ -304,27 +325,27 @@ void NetworkPlayer::decodeActionRuin(const Action_Ruin *action)
 
 void NetworkPlayer::decodeActionTemple(const Action_Temple *action)
 {
-  Stack *stack = d_stacklist->getStackById(action->d_stack);
-  Temple *temple = Templelist::getInstance()->getById(action->d_temple);
+  Stack *stack = d_stacklist->getStackById(action->getStackId());
+  Temple *temple = Templelist::getInstance()->getById(action->getTempleId());
   doStackVisitTemple(stack, temple);
 }
 
 void NetworkPlayer::decodeActionOccupy(const Action_Occupy *action)
 {
-  City *city = Citylist::getInstance()->getById(action->d_city);
+  City *city = Citylist::getInstance()->getById(action->getCityId());
   doCityOccupy(city);
 }
 
 void NetworkPlayer::decodeActionPillage(const Action_Pillage *action)
 {
-  City *city = Citylist::getInstance()->getById(action->d_city);
+  City *city = Citylist::getInstance()->getById(action->getCityId());
   int gold, pillaged_army_type;
-  doCityPillage(city, gold, pillaged_army_type);
+  doCityPillage(city, gold, &pillaged_army_type);
 }
 
 void NetworkPlayer::decodeActionSack(const Action_Sack *action)
 {
-  City *city = Citylist::getInstance()->getById(action->d_city);
+  City *city = Citylist::getInstance()->getById(action->getCityId());
   int gold;
   std::list<Uint32> sacked_types;
   doCitySack(city, gold, &sacked_types);
@@ -334,7 +355,7 @@ void NetworkPlayer::decodeActionSack(const Action_Sack *action)
 
 void NetworkPlayer::decodeActionRaze(const Action_Raze *action)
 {
-  City *city = Citylist::getInstance()->getById(action->d_city);
+  City *city = Citylist::getInstance()->getById(action->getCityId());
   doCityRaze(city);
 }
 
@@ -346,45 +367,69 @@ void NetworkPlayer::decodeActionUpgrade(const Action_Upgrade *action)
 
 void NetworkPlayer::decodeActionBuy(const Action_Buy *action)
 {
-  City *city = Citylist::getInstance()->getById(action->d_city);
-  doCityBuyProduction(city, action->d_slot, action->d_prod);
+  City *city = Citylist::getInstance()->getById(action->getCityId());
+  doCityBuyProduction(city, action->getProductionSlot(), 
+		      action->getBoughtArmyTypeId());
 }
 
 void NetworkPlayer::decodeActionProduction(const Action_Production *action)
 {
-  City *city = Citylist::getInstance()->getById(action->d_city);
-  doCityChangeProduction(city, action->d_prod);
+  City *city = Citylist::getInstance()->getById(action->getCityId());
+  doCityChangeProduction(city, action->getSlot());
 }
 
 void NetworkPlayer::decodeActionReward(const Action_Reward *action)
 {
-  Stack *stack = d_stacklist->getStackById(action->d_stack);
-  doGiveReward(stack, action->d_reward);
+  Stack *stack = d_stacklist->getStackById(action->getStackId());
+  doGiveReward(stack, action->getReward());
   supdatingStack.emit(stack); // make sure we get a redraw
 }
 
 void NetworkPlayer::decodeActionQuest(const Action_Quest *action)
 {
-  QuestsManager::getInstance()->createNewQuest(
-    action->d_hero, action->d_questtype, action->d_data,
-    action->d_victim_player);
+  QuestsManager *qm = QuestsManager::getInstance();
+  switch (Quest::Type(action->getQuestType()))
+    {
+    case Quest::KILLHERO: 
+      qm->createNewKillHeroQuest(action->getHeroId(), action->getData());
+      break;
+    case Quest::KILLARMIES:
+      qm->createNewEnemyArmiesQuest(action->getHeroId(), action->getData(), 
+				    action->getVictimPlayerId());
+      break;
+    case Quest::CITYSACK:
+      qm->createNewCitySackQuest(action->getHeroId(), action->getData());
+      break;
+    case Quest::CITYRAZE:
+      qm->createNewCityRazeQuest(action->getHeroId(), action->getData());
+      break;
+    case Quest::CITYOCCUPY:
+      qm->createNewCityOccupyQuest(action->getHeroId(), action->getData());
+      break;
+    case Quest::KILLARMYTYPE:
+      qm->createNewEnemyArmytypeQuest(action->getHeroId(), action->getData());
+      break;
+    case Quest::PILLAGEGOLD:
+      qm->createNewPillageGoldQuest(action->getHeroId(), action->getData());
+      break;
+    }
 }
 
 void NetworkPlayer::decodeActionEquip(const Action_Equip *action)
 {
-  Stack *stack = d_stacklist->getArmyStackById(action->d_hero);
-  Hero *hero = dynamic_cast<Hero *>(stack->getArmyById(action->d_hero));
+  Stack *stack = d_stacklist->getArmyStackById(action->getHeroId());
+  Hero *hero = dynamic_cast<Hero *>(stack->getArmyById(action->getHeroId()));
   Item *item = 0;
 
-  switch (action->d_slot)
+  switch (action->getToBackpackOrToGround())
   {
   case Action_Equip::BACKPACK:
-    item = findItemById(GameMap::getInstance()->getTile(stack->getPos())->getItems(), action->d_item);
+    item = findItemById(GameMap::getInstance()->getTile(stack->getPos())->getItems(), action->getItemId());
     doHeroPickupItem(hero, item, stack->getPos());
     break;
 
   case Action_Equip::GROUND:
-    item = findItemById(hero->getBackpack(), action->d_item);
+    item = findItemById(hero->getBackpack(), action->getItemId());
     doHeroDropItem(hero, item, stack->getPos());
     break;
   }
@@ -392,39 +437,39 @@ void NetworkPlayer::decodeActionEquip(const Action_Equip *action)
 
 void NetworkPlayer::decodeActionLevel(const Action_Level *action)
 {
-  Stack *stack = d_stacklist->getArmyStackById(action->d_army);
-  Army *army = stack->getArmyById(action->d_army);
+  Stack *stack = d_stacklist->getArmyStackById(action->getArmyId());
+  Army *army = stack->getArmyById(action->getArmyId());
 
-  doLevelArmy(army, Army::Stat(action->d_stat));
+  doLevelArmy(army, Army::Stat(action->getStatToIncrease()));
 }
 
 void NetworkPlayer::decodeActionDisband(const Action_Disband *action)
 {
-  Stack *stack = d_stacklist->getStackById(action->d_stack);
+  Stack *stack = d_stacklist->getStackById(action->getStackId());
   doStackDisband(stack);
 }
 
-void NetworkPlayer::decodeActionModifySignpost(const Action_ModifySignpost *action)
+void NetworkPlayer::decodeActionModifySignpost(const Action_ModifySignpost *act)
 {
-  Signpost *signpost = Signpostlist::getInstance()->getById(action->d_signpost);
-  doSignpostChange(signpost, action->d_message);
+  Signpost *sign = Signpostlist::getInstance()->getById(act->getSignpostId());
+  doSignpostChange(sign, act->getSignContents());
 }
 
 void NetworkPlayer::decodeActionRenameCity(const Action_RenameCity *action)
 {
-  City *city = Citylist::getInstance()->getById(action->d_city);
-  doCityRename(city, action->d_name);
+  City *city = Citylist::getInstance()->getById(action->getCityId());
+  doCityRename(city, action->getNewCityName());
 }
 
 void NetworkPlayer::decodeActionVector(const Action_Vector *action)
 {
-  City *city = Citylist::getInstance()->getById(action->d_city);
-  doVectorFromCity(city, action->d_dest);
+  City *city = Citylist::getInstance()->getById(action->getCityId());
+  doVectorFromCity(city, action->getVectoringDestination());
 }
 
 void NetworkPlayer::decodeActionFightOrder(const Action_FightOrder *action)
 {
-  doSetFightOrder(action->d_order);
+  doSetFightOrder(action->getFightOrder());
 }
 
 void NetworkPlayer::decodeActionResign(const Action_Resign *action)
@@ -434,21 +479,44 @@ void NetworkPlayer::decodeActionResign(const Action_Resign *action)
 
 void NetworkPlayer::decodeActionPlant(const Action_Plant *action)
 {
-  Stack *stack = d_stacklist->getArmyStackById(action->d_hero);
-  Hero *hero = dynamic_cast<Hero *>(stack->getArmyById(action->d_hero));
-  Item *item = findItemById(hero->getBackpack(), action->d_item);
+  Stack *stack = d_stacklist->getArmyStackById(action->getHeroId());
+  Hero *hero = dynamic_cast<Hero *>(stack->getArmyById(action->getHeroId()));
+  Item *item = findItemById(hero->getBackpack(), action->getItemId());
     
   doHeroPlantStandard(hero, item, stack->getPos());
 }
 
 void NetworkPlayer::decodeActionProduce(const Action_Produce *action)
 {
-  // FIXME: needed?
+  //Note: we don't use this to produce new armies in cities
+  //That happens during the city->nextTurn method.
+  //It is enough that we record the changes in city production, and then
+  //let the city->nextTurn method do it's job.
+  //This action is used for the Production Report instead, see
+  //gui/report-dialog.cpp
+ 
+  //there's no real need to send this action back to the server because
+  //only the current player can see her own production report.
+
+  //if we wanted to decode it, we'd do this:
+  //City *city = Citylist::getInstance()->getById(action->getCityId());
+  //doCityProducesArmy(city);
 }
 
 void NetworkPlayer::decodeActionProduceVectored(const Action_ProduceVectored *action)
 {
-  // FIXME: needed?
+  //Note: we don't use this to produce new vectored army units on the map 
+  //That happens during the vectoredunit->nextTurn method.
+  //It is enough that we record the changes in city vectoring, and then
+  //let the vectoredunitlist->nextTurn method do it's job.
+  //This action is used for the Production Report instead, see
+  //gui/report-dialog.cpp
+ 
+  //there's no real need to send this action back to the server because
+  //only the current player can see her own production report.
+
+  //we couldn't decode this action if we wanted to, because there isn't
+  //enough data to make it happen.
 }
 
 void NetworkPlayer::decodeActionDiplomacyState(const Action_DiplomacyState *action)
@@ -476,19 +544,31 @@ void NetworkPlayer::decodeActionEndTurn(const Action_EndTurn *action)
 
 void NetworkPlayer::decodeActionConquerCity(const Action_ConquerCity *action)
 {
-  City *city = Citylist::getInstance()->getById(action->d_city);
-  Stack *stack = d_stacklist->getStackById(action->d_stack);
+  City *city = Citylist::getInstance()->getById(action->getCityId());
+  Stack *stack = d_stacklist->getStackById(action->getStackId());
   conquerCity(city, stack);
 }
 
 void NetworkPlayer::decodeActionRecruitHero(const Action_RecruitHero *action)
 {
-  City *city = Citylist::getInstance()->getById(action->d_city);
+
+  City *city = Citylist::getInstance()->getById(action->getCityId());
   Army *ally = 0;
-  if (action->d_allies)
+  if (action->getNumAllies())
     ally = Armysetlist::getInstance()->getArmy(getArmyset(),
-                                               action->d_ally_army_type);
-  doRecruitHero(action->d_hero, city, action->d_cost, action->d_allies, ally);
+                                               action->getAllyArmyType());
+  doRecruitHero(action->getHero(), city, action->getCost(), 
+		action->getNumAllies(), ally);
+}
+
+void NetworkPlayer::decodeActionRenamePlayer(const Action_RenamePlayer *action)
+{
+  doRename(action->getName());
+}
+
+void NetworkPlayer::decodeActionCityTooPoorToProduce(const Action_CityTooPoorToProduce *action)
+{
+  //this action is only used for reporting purposes.
 }
 
 // End of file
