@@ -52,8 +52,12 @@ class NetworkPlayer : public Player
         virtual void levelArmy(Army* a);
 
 	void decodeAction(const Action *action);
+	void decodeActions(std::list<Action *> actions);
         
+	bool isConnected() const {return d_connected;}
+	void setConnected(bool connected) {d_connected = connected;}
     private:
+	bool d_connected;
 	void decodeActionMove(const Action_Move *action);
 	void decodeActionSplit(const Action_Split *action);
 	void decodeActionFight(const Action_Fight *action);
@@ -86,6 +90,8 @@ class NetworkPlayer : public Player
 	void decodeActionEndTurn(const Action_EndTurn *action);
 	void decodeActionConquerCity(const Action_ConquerCity *action);
 	void decodeActionRecruitHero(const Action_RecruitHero *action);
+	void decodeActionRenamePlayer(const Action_RenamePlayer *action);
+	void decodeActionCityTooPoorToProduce(const Action_CityTooPoorToProduce *action);
 };
 
 #endif // NETWORK_PLAYER_H
