@@ -32,6 +32,7 @@
 #include "playerlist.h"
 #include "stacklist.h"
 #include "citylist.h"
+#include "templelist.h"
 #include "city.h"
 #include "path.h"
 #include "armysetlist.h"
@@ -44,15 +45,18 @@
 #include "army.h"
 #include "hero.h"
 #include "Configuration.h"
-#include "GameScenario.h"
+#include "GameScenarioOptions.h"
 #include "action.h"
+#include "network-action.h"
 #include "history.h"
+#include "network-history.h"
 #include "AI_Analysis.h"
 #include "AI_Allocation.h"
 #include "FogMap.h"
 #include "QuestsManager.h"
 #include "GameMap.h"
 #include "signpost.h"
+#include "vectoredunit.h"
 #include "ucompose.hpp"
 
 using namespace std;
@@ -60,33 +64,6 @@ using namespace std;
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<flush<<endl;}
 #define debug(x)
 
-SDL_Color Player::get_color_for_no(int player_no)
-{
-    SDL_Color color;
-    color.r = color.b = color.g = color.unused = 0;
-    switch (player_no % MAX_PLAYERS)
-    {
-    case 0: color.r = 252; color.b = 252; color.g = 252; break;
-    //case 1: color.r = 80; color.b = 28; color.g = 172; break;
-    case 1: color.r = 80; color.b = 28; color.g = 193; break;
-    case 2: color.r = 252; color.b = 32; color.g = 236; break;
-    case 3: color.r = 92; color.b = 208; color.g = 92; break;
-    case 4: color.r = 252; color.b = 0; color.g = 160;break;
-    case 5: color.r = 44; color.b = 252; color.g = 184; break;
-    case 6: color.r = 196; color.b = 0; color.g = 28; break;
-    case 7: color.r = color.g = color.b = 0; break;
-    }
-    
-    return color;
-}
-
-SDL_Color Player::get_color_for_neutral()
-{
-    SDL_Color color;
-    color.r = color.g = color.b = 204; color.unused = 0;
-    return color;
-}
-
 
 // signal
 sigc::signal<void, Player::Type> sendingTurn;
@@ -94,7 +71,7 @@ sigc::signal<void, Player::Type> sendingTurn;
 Player::Player(string name, Uint32 armyset, SDL_Color color, int width,
 	       int height, Type type, int player_no)
     :d_color(color), d_name(name), d_armyset(armyset), d_gold(1000),
-    d_dead(false), d_immortal(false), d_type(type), d_upkeep(0)
+    d_dead(false), d_immortal(false), d_type(type), d_upkeep(0), d_income(0)
 {
     if (player_no != -1)
 	d_id = player_no;
@@ -129,7 +106,8 @@ Player::Player(const Player& player)
     :d_color(player.d_color), d_name(player.d_name), d_armyset(player.d_armyset),
     d_gold(player.d_gold), d_dead(player.d_dead), d_immortal(player.d_immortal),
     d_type(player.d_type), d_id(player.d_id), 
-    d_fight_order(player.d_fight_order), d_upkeep(player.d_upkeep)
+    d_fight_order(player.d_fight_order), d_upkeep(player.d_upkeep), 
+    d_income(player.d_income)
 {
     // as the other player is propably dumped somehow, we need to deep copy
     // everything. This costs a lot, but the only useful situation for this
@@ -178,6 +156,7 @@ Player::Player(XML_Helper* helper)
     helper->getData(d_immortal, "immortal");
     helper->getData(d_type, "type");
     helper->getData(d_upkeep, "upkeep");
+    helper->getData(d_income, "income");
 
     string s;
     helper->getData(s, "color");
@@ -239,7 +218,6 @@ Player::Player(XML_Helper* helper)
 	    d_diplomatic_score[i] = val;
     }
 
-    //last but not least, register the load function for actionlist
     helper->registerTag("action", sigc::mem_fun(this, &Player::load));
     helper->registerTag("history", sigc::mem_fun(this, &Player::load));
     helper->registerTag("stacklist", sigc::mem_fun(this, &Player::load));
@@ -305,7 +283,7 @@ void Player::initTurn()
 {
   clearActionlist();
   History_StartTurn* item = new History_StartTurn();
-  d_history.push_back(item);
+  addHistory(item);
 }
 
 void Player::setColor(SDL_Color c)
@@ -413,9 +391,7 @@ void Player::clearActionlist()
     for (list<Action*>::iterator it = d_actions.begin();
         it != d_actions.end(); it++)
     {
-#if 0  // FIXME: temp. leak to avoid double-delete
       delete (*it);
-#endif
     }
     d_actions.clear();
 }
@@ -452,7 +428,7 @@ void Player::kill()
                         
     History_PlayerVanquished* item;
     item = new History_PlayerVanquished();
-    d_history.push_back(item);
+    addHistory(item);
 
     d_dead = true;
     d_stacklist->flClear();
@@ -490,6 +466,7 @@ bool Player::save(XML_Helper* helper) const
     retval &= helper->saveData("type", d_type);
     debug("type of " << d_name << " is " << d_type)
     retval &= helper->saveData("upkeep", d_upkeep);
+    retval &= helper->saveData("income", d_income);
 
     // save the fight order, one ranking per army type
     std::stringstream fight_order;
@@ -528,12 +505,10 @@ bool Player::save(XML_Helper* helper) const
       }
     retval &= helper->saveData("diplomatic_scores", diplomatic_scores.str());
 
-#if 0
     //save the actionlist
     for (list<Action*>::const_iterator it = d_actions.begin();
             it != d_actions.end(); it++)
         retval &= (*it)->save(helper);
-#endif
     
     //save the pasteventlist
     for (list<History*>::const_iterator it = d_history.begin();
@@ -602,14 +577,12 @@ Player* Player::loadPlayer(XML_Helper* helper)
 
 bool Player::load(string tag, XML_Helper* helper)
 {
-#if 0
     if (tag == "action")
     {
         Action* action;
         action = Action::handle_load(helper);
         d_actions.push_back(action);
     }
-#endif
     if (tag == "history")
     {
         History* history;
@@ -662,15 +635,18 @@ bool Player::load(string tag, XML_Helper* helper)
 
 void Player::addAction(Action *action)
 {
-  action->setPlayer(getId());
-  
-  // FIXME
-  if (!action_done.empty())
-    action_done.emit(action);
-#if 0
-  else
-    delete action;
-#endif
+  d_actions.push_back(action);
+  NetworkAction *copy = new NetworkAction(action, this);
+  acting.emit(copy);
+  //free'd in game-server
+}
+
+void Player::addHistory(History *history)
+{
+  d_history.push_back(history);
+  NetworkHistory *copy = new NetworkHistory(history, this);
+  history_written.emit(copy);
+  //free'd in game-server
 }
 
 
@@ -695,6 +671,17 @@ void Player::calculateUpkeep()
       d_upkeep += (*i)->getUpkeep();
 }
 
+void Player::calculateIncome()
+{
+    d_income = 0;
+    Citylist *cl = Citylist::getInstance();
+    for (Citylist::iterator i = cl->begin(), iend = cl->end(); i != iend; ++i)
+      {
+	if ((*i).getOwner() == this)
+	  d_income += (*i).getGold();
+      }
+}
+
 void Player::doSetFightOrder(std::list<Uint32> order)
 {
   d_fight_order = order;
@@ -790,8 +777,12 @@ bool Player::stackJoin(Stack* receiver, Stack* joining, bool grouped)
     if ((receiver == 0) || (joining == 0))
         return false;
 
-    if ((receiver->size() + joining->size()) > MAX_STACK_SIZE)
+    if (joining->canJoin(receiver) == false)
+      {
+	Stack *already_there = Stacklist::getAmbiguity(joining);
+	stackJoin(joining, already_there,  false);
         return false;
+      }
     
     Action_Join* item = new Action_Join();
     item->fillData(receiver, joining);
@@ -802,6 +793,76 @@ bool Player::stackJoin(Stack* receiver, Stack* joining, bool grouped)
     return true;
 }
 
+bool Player::stackSplitAndMove(Stack* s)
+{
+  if (s->getPath()->size() == 0)
+    return false;
+  Stack *join = getStacklist()->getObjectAt(*s->getPath()->back());
+  if (join)
+    return stackSplitAndMoveToJoin(s, join);
+  else
+    return stackSplitAndMoveToAttack(s);
+}
+
+bool Player::stackSplitAndMoveToJoin(Stack* s, Stack *join)
+{
+  //the stack can't get there, but maybe part of the stack can.
+  if (s->getPath()->empty())
+    return false;
+
+  if (s->canJoin(join) == false)
+    return false;
+
+  Path::iterator it = s->getPath()->end();
+  it--;
+  std::vector<Uint32> ids;
+  ids = s->determineReachableArmies(**(it));
+  if (ids.size() == 0)
+    return false;
+  //if they're all reachable and we can join, just move them
+  if (ids.size() == s->size())
+    return stackMove(s);
+
+  for (Stack::iterator it = s->begin(); it != s->end(); it++)
+    {
+      (*it)->setGrouped(false);
+      if (find(ids.begin(), ids.end(), (*it)->getId()) != ids.end())
+	{
+	  if (s->countGroupedArmies() + join->size() < MAX_STACK_SIZE)
+	    (*it)->setGrouped(true);
+	}
+    }
+  //this splits the ungrouped armies into their own stack
+  stackSplit(s);
+  return stackMove(s);
+}
+
+bool Player::stackSplitAndMoveToAttack(Stack* s)
+{
+  //the stack can't get there, but maybe part of the stack can.
+  if (s->getPath()->empty())
+    return false;
+
+  Path::iterator it = s->getPath()->end();
+  it--;
+  std::vector<Uint32> ids;
+  ids = s->determineReachableArmies(**(it));
+  if (ids.size() == 0)
+    return false;
+  if (ids.size() == s->size())
+    return stackMove(s);
+
+  for (Stack::iterator it = s->begin(); it != s->end(); it++)
+    {
+      (*it)->setGrouped(false);
+      if (find(ids.begin(), ids.end(), (*it)->getId()) != ids.end())
+	(*it)->setGrouped(true);
+    }
+  //this splits the ungrouped armies into their own stack
+  stackSplit(s);
+  return stackMove(s);
+}
+
 bool Player::stackMove(Stack* s)
 {
     debug("Player::stackMove(Stack*)")
@@ -814,7 +875,7 @@ bool Player::stackMove(Stack* s)
     Path::iterator it = s->getPath()->end();
     it--;
     MoveResult *result = stackMove(s, **(it), true);
-    bool ret = result->moveSucceeded();
+    bool ret = result->didSomething();//result->moveSucceeded();
     delete result;
     result = 0;
     return ret;
@@ -840,12 +901,11 @@ MoveResult *Player::stackMove(Stack* s, Vector<int> dest, bool follow)
     }
 
     int stepCount = 0;
-    while (s->getPath()->size() > 1 && s->enoughMoves())
-    {
-        if (stackMoveOneStep(s))
-            stepCount++;
+    while (s->getPath()->size() > 1 && stackMoveOneStep(s))
+      {
+	stepCount++;
         supdatingStack.emit(0);
-    }
+      }
 
     if (s->getPath()->size() == 1 && s->enoughMoves())
     //now look for fight targets, joins etc.
@@ -870,25 +930,25 @@ MoveResult *Player::stackMove(Stack* s, Vector<int> dest, bool follow)
             Fight::Result result;
             MoveResult *moveResult = new MoveResult(true);
 	    if (stackMoveOneStep(s))
-	      stepCount++;
+	      {
+		stepCount++;
+		moveResult = new MoveResult(true);
+	      }
+	    else
+	      {
+		moveResult = new MoveResult(false);
+		moveResult->setStepCount(stepCount);
+		return moveResult;
+	      }
+
             vector<Stack*> def_in_city = Stacklist::defendersInCity(city);
             if (!def_in_city.empty())
             {
                 // This is a hack to circumvent the limitations of stackFight.
-                // Create a dummy stack at the target position if neccessary
-                // and start a fight with this dummy stack.
-#if 0
-                if (!target)
-                    target = new Stack(city->getOwner(), pos);
-#endif
                 if (!target)
                   target = def_in_city[0];
  
                 result = stackFight(&s, &target);
-#if 0
-                if (target && target->empty())
-                    delete target;
-#endif
             }
             else
                 result = Fight::ATTACKER_WON;
@@ -912,19 +972,29 @@ MoveResult *Player::stackMove(Stack* s, Vector<int> dest, bool follow)
         
         //another friendly stack => join it
         else if (target && target->getOwner() == this)
-        {
+          {
+	    bool moved = false;
             if (stackMoveOneStep(s))
+	      {
+		moved = true;
                 stepCount++;
-            stackJoin(Stacklist::getAmbiguity(s), s, false);
+	      }
+	    Stack *other_stack = Stacklist::getAmbiguity(s);
+            stackJoin(other_stack, s, false);
 
-            supdatingStack.emit(0);
-            SDL_Delay(Configuration::s_displaySpeedDelay);
+	    if (other_stack)
+	      d_stacklist->getActivestack()->sortForViewing(false);
+	      
+	    supdatingStack.emit(0);
+	    SDL_Delay(Configuration::s_displaySpeedDelay);
     
-            MoveResult *moveResult = new MoveResult(true);
+            MoveResult *moveResult = new MoveResult(moved);
             moveResult->setStepCount(stepCount);
-            moveResult->setJoin(true);
+            moveResult->setJoin(moved);
+	    //if (moved == false)
+	      //d_stacklist->getActivestack()->getPath()->flClear();
             return moveResult;
-        }
+         }
         
         //enemy stack => fight
         else if (target)
@@ -936,6 +1006,7 @@ MoveResult *Player::stackMove(Stack* s, Vector<int> dest, bool follow)
 		{
 		  s->getPath()->flClear();
 		  MoveResult *moveResult = new MoveResult(false);
+		  moveResult->setStepCount(stepCount);
 		  return moveResult;
 		}
 	    }
@@ -988,7 +1059,9 @@ MoveResult *Player::stackMove(Stack* s, Vector<int> dest, bool follow)
         return moveResult;
     }
 
-    return new MoveResult(true);
+    MoveResult *moveResult = new MoveResult(true);
+    moveResult->setStepCount(stepCount);
+    return moveResult;
 }
 
 bool Player::stackMoveOneStep(Stack* s)
@@ -1001,6 +1074,22 @@ bool Player::stackMoveOneStep(Stack* s)
 
   Vector<int> dest = *s->getPath()->front();
   
+  Stack *another_stack = d_stacklist->getObjectAt(dest);
+  if (another_stack)
+    {
+      if (another_stack->getOwner() == s->getOwner())
+	{
+	  if (s->canJoin(another_stack) == false)
+	    return false;
+	}
+      else
+	{
+	  //if we're attacking, then jump onto the square with the enemy.
+	  if (s->getPath()->size() != 1)
+	    return false;
+	}
+
+    }
   Action_Move* item = new Action_Move();
   item->fillData(s, dest);
   addAction(item);
@@ -1052,7 +1141,7 @@ Fight::Result Player::stackFight(Stack** attacker, Stack** defender)
     bool attacker_active = *attacker == d_stacklist->getActivestack();
 
     Fight fight(*attacker, *defender);
-    fight.battle(GameScenario::s_intense_combat);
+    fight.battle(GameScenarioOptions::s_intense_combat);
     
     fight_started.emit(fight);
     // cleanup
@@ -1076,15 +1165,6 @@ Fight::Result Player::stackFight(Stack** attacker, Stack** defender)
     bool exists =
 	std::find(d_stacklist->begin(), d_stacklist->end(), *attacker)
 	!= d_stacklist->end();
-#if 0
-    bool exists = false;
-    for (Stacklist::iterator it = d_stacklist->begin(); it != d_stacklist->end(); it++)
-        if ((*it) == (*attacker))
-	{
-            exists = true;
-	    break;
-	}
-#endif
     
     if (!exists)
     {
@@ -1096,12 +1176,9 @@ Fight::Result Player::stackFight(Stack** attacker, Stack** defender)
     // ...then the defender.
     exists = false;
     if (pd)
-        for (Stacklist::iterator it = pd->getStacklist()->begin();
-             it != pd->getStacklist()->end(); it++)
-        {
-            if ((*it) == (*defender))
-                exists = true;
-        }
+      exists = 
+	std::find(pd->getStacklist()->begin(), pd->getStacklist()->end(), 
+		  *defender) != pd->getStacklist()->end();
     else
         exists = true;
     if (!exists)
@@ -1126,7 +1203,7 @@ Fight::Result Player::stackFight(Stack** attacker, Stack** defender)
  * OddsOfFailure = BaseOdds * MonsterFactor * StackFactor * HeroFactor,
  *
  * with
- *        BaseOdds = 0.25
+ *        BaseOdds = 0.10
  * and
  *        MonsterFactor = 2, 1 or 0.5 depending on hard vs. easy
  * and
@@ -1141,7 +1218,7 @@ Fight::Result ruinfight (Stack **attacker, Stack **defender)
   Uint32 hero_strength, monster_strength;
   hero_strength = (*attacker)->getFirstHero()->getStat(Army::STRENGTH, true);
   monster_strength = (*defender)->getStrongestArmy()->getStat(Army::STRENGTH, true);
-  float base_factor = 0.25;
+  float base_factor = 0.33;
   float stack_factor = ((float)(MAX_STACK_SIZE + 1) - (*attacker)->size()) / (float)MAX_STACK_SIZE;
   float hero_factor = (10.0 - hero_strength) / 5.0;
   float monster_factor;
@@ -1253,7 +1330,7 @@ Reward* Player::stackSearchRuin(Stack* s, Ruin* r)
   {
     History_FoundSage* history = new History_FoundSage();
     history->fillData(dynamic_cast<Hero *>(s->getFirstHero()));
-    d_history.push_back(history);
+    addHistory(history);
   }
   else
   {
@@ -1334,7 +1411,7 @@ Quest* Player::stackGetQuest(Stack* s, Temple* t, bool except_raze)
   // and record it for posterity
   History_HeroQuestStarted * history = new History_HeroQuestStarted();
   history->fillData(dynamic_cast<Hero *>(s->getFirstHero()));
-  d_history.push_back(history);
+  addHistory(history);
   return q;
 }
 
@@ -1347,7 +1424,12 @@ float Player::stackFightAdvise(Stack* s, Vector<int> tile,
   Stack* target = Stacklist::getObjectAt(tile);
                 
   if (!target && city)
-    target = new Stack(city->getOwner(), tile);
+    {
+      vector<Stack*> def_in_city = Stacklist::defendersInCity(city);
+      if (def_in_city.empty())
+	return 100.0;
+      target = def_in_city[0];
+    }
 
   //what chance is there that stack will defeat defenders?
     
@@ -1408,13 +1490,13 @@ void Player::doConquerCity(City *city, Stack *stack)
   
   History_CityWon *item = new History_CityWon();
   item->fillData(city);
-  d_history.push_back(item);
+  addHistory(item);
   if (stack->hasHero())
   {
     History_HeroCityWon *another = new History_HeroCityWon();
     Hero *hero = dynamic_cast<Hero *>(stack->getFirstHero());
     another->fillData(hero, city);
-    d_history.push_back(another);
+    addHistory(another);
   }
 }
 
@@ -1458,10 +1540,11 @@ void Player::cityOccupy(City* c)
   addAction(item);
 }
 
-void Player::doCityPillage(City *c, int& gold, int& pillaged_army_type)
+void Player::doCityPillage(City *c, int& gold, int* pillaged_army_type)
 {
   gold = 0;
-  pillaged_army_type = -1;
+  if (pillaged_army_type)
+    *pillaged_army_type = -1;
   
   // get rid of the most expensive army type and trade it in for 
   // half it's cost
@@ -1492,25 +1575,27 @@ void Player::doCityPillage(City *c, int& gold, int& pillaged_army_type)
       if (slot > -1)
 	{
 	  const Army *a = c->getProductionBase(slot);
-	  pillaged_army_type = a->getType();
+	  if (pillaged_army_type)
+	    *pillaged_army_type = a->getType();
 	  if (a->getProductionCost() == 0)
 	    gold += 1500;
 	  else
 	    gold += a->getProductionCost() / 2;
 	  c->removeProductionBase(slot);
 	}
+  //*pillaged_army_type = 10;
+  //gold = 300;
+      addGold(gold);
+      Stack *s = getActivestack();
+      //printf ("%s emitting %p, %p, %d, %d\n", getName().c_str(), c, s, gold, *pillaged_army_type);
+      spillagingCity.emit(c, s, gold, *pillaged_army_type);
+      QuestsManager::getInstance()->cityPillaged(c, s, gold);
     }
 
-  addGold(gold);
-  std::list<Uint32> sacked_types;
-  sacked_types.push_back (pillaged_army_type);
-  Stack *s = getActivestack();
-  spillagingCity.emit(c, s, gold, sacked_types);
-  QuestsManager::getInstance()->cityPillaged(c, s, gold);
   takeCityInPossession(c);
 }
 
-void Player::cityPillage(City* c, int& gold, int& pillaged_army_type)
+void Player::cityPillage(City* c, int& gold, int* pillaged_army_type)
 {
   debug("Player::cityPillage");
   
@@ -1578,7 +1663,7 @@ void Player::doCityRaze(City *c)
 {
   History_CityRazed* history = new History_CityRazed();
   history->fillData(c);
-  d_history.push_back(history);
+  addHistory(history);
 
   c->conquer(this);
   c->setBurnt(true);
@@ -1618,7 +1703,7 @@ bool Player::cityBuyProduction(City* c, int slot, int type)
   Uint32 as = c->getOwner()->getArmyset();
 
   // sort out unusual values (-1 is allowed and means "scrap production")
-  if ((type < -1) || (type >= (int)al->getSize(as)))
+  if ((type <= -1) || (type >= (int)al->getSize(as)))
     return false;
 
   // return if we don't have enough money
@@ -1684,6 +1769,7 @@ void Player::doGiveReward(Stack *s, Reward *reward)
           Ruin *r = dynamic_cast<Reward_Ruin*>(reward)->getRuin();
           r->setHidden(true);
           r->setOwner(this);
+	  r->deFog(this);
         }
       break;
     case Reward::MAP:
@@ -1776,12 +1862,21 @@ bool Player::heroPickupItem(Hero *h, Item *i, Vector<int> pos)
   return true;
 }
 
+bool Player::heroPickupAllItems(Hero *h, Vector<int> pos)
+{
+  std::list<Item*> bag = GameMap::getInstance()->getTile(pos)->getItems();
+  for (std::list<Item*>::iterator i = bag.begin(), end = bag.end();
+       i != end; ++i)
+    heroPickupItem(h, *i, pos);
+  return true;
+}
+
 bool Player::heroCompletesQuest(Hero *h)
 {
   // record it for posterity
   History_HeroQuestCompleted* item = new History_HeroQuestCompleted();
   item->fillData(h);
-  d_history.push_back(item);
+  addHistory(item);
   return true;
 }
 
@@ -1799,7 +1894,7 @@ void Player::doResign()
 	  (*it).setBurnt(true);
 	  History_CityRazed* history = new History_CityRazed();
 	  history->fillData(&(*it));
-	  d_history.push_back(history);
+	  addHistory(history);
 	}
     }
   withdrawGold(getGold()); //empty the coffers!
@@ -1853,6 +1948,20 @@ bool Player::cityRename(City *c, std::string name)
   return true;
 }
 
+void Player::doRename(std::string name)
+{
+  setName(name);
+}
+
+void Player::rename(std::string name)
+{
+  doRename(name);
+  Action_RenamePlayer * item = new Action_RenamePlayer();
+  item->fillData(name);
+  addAction(item);
+  return;
+}
+
 void Player::doVectorFromCity(City * c, Vector<int> dest)
 {
   c->setVectoring(dest);
@@ -1981,7 +2090,7 @@ double Player::removeDeadArmies(std::list<Stack*>& stacks,
                         History_HeroKilledSearching* item;
                         item = new History_HeroKilledSearching();
                         item->fillData(h);
-                        h->getOwner()->getHistorylist()->push_back(item);
+			h->getOwner()->addHistory(item);
                         heroDropAllItems (h, (*it)->getPos());
                     }
                     else if (tile->getBuilding() == Maptile::CITY)
@@ -1991,7 +2100,7 @@ double Player::removeDeadArmies(std::list<Stack*>& stacks,
                         History_HeroKilledInCity* item;
                         item = new History_HeroKilledInCity();
                         item->fillData(h, c);
-                        h->getOwner()->getHistorylist()->push_back(item);
+			h->getOwner()->addHistory(item);
                         heroDropAllItems (h, (*it)->getPos());
                     }
                     else //somewhere else
@@ -1999,7 +2108,7 @@ double Player::removeDeadArmies(std::list<Stack*>& stacks,
                         History_HeroKilledInBattle* item;
                         item = new History_HeroKilledInBattle();
                         item->fillData(h);
-                        h->getOwner()->getHistorylist()->push_back(item);
+			h->getOwner()->addHistory(item);
                         heroDropAllItems (h, (*it)->getPos());
                     }
                 }
@@ -2185,7 +2294,7 @@ void Player::doRecruitHero(Hero* herotemplate, City *city, int cost, int alliesC
 {
   History_HeroEmerges *item = new History_HeroEmerges();
   item->fillData(herotemplate, city);
-  d_history.push_back(item);
+  addHistory(item);
 
   Hero *newhero = new Hero(*herotemplate);
   newhero->setOwner(this);
@@ -2242,6 +2351,8 @@ void Player::declareDiplomacy (DiplomaticState state, Player *player)
 
 void Player::doProposeDiplomacy (DiplomaticProposal proposal, Player *player)
 {
+  if (GameScenarioOptions::s_diplomacy == false)
+    return;
   Playerlist *pl = Playerlist::getInstance();
   if (pl->getNeutral() == player)
     return;
@@ -2459,4 +2570,498 @@ void Player::improveAlliesRelationship(Player *player, Uint32 amount,
     }
 }
 
+void Player::AI_maybeBuyScout()
+{
+  bool hero_exists = false;
+  for (Stacklist::iterator it = d_stacklist->begin(); 
+       it != d_stacklist->end(); it++)
+    
+    if ((*it)->hasHero())
+      hero_exists = true; 
+    
+  if (Citylist::getInstance()->countCities(this) == 1 && 
+	hero_exists == false)
+    {
+      bool one_turn_army_exists = false;
+      City *c = Citylist::getInstance()->getFirstCity(this);
+      //do we already have something that can be produced in one turn?
+      for (int i = 0; i < c->getMaxNoOfProductionBases(); i++)
+	{
+	  if (c->getArmytype(i) == -1)    // no production in this slot
+	    continue;
+
+	  const Army *proto = c->getProductionBase(i);
+	  if (proto->getProduction() == 1)
+	    {
+	      one_turn_army_exists = true;
+	      break;
+	    }
+	}
+      if (one_turn_army_exists == false)
+	{
+	  const Armysetlist* al = Armysetlist::getInstance();
+	  int free_slot = c->getFreeBasicSlot();
+	  if (free_slot == -1)
+	    free_slot = 0;
+	  Army *scout = al->getScout(getArmyset());
+	  cityBuyProduction(c, free_slot, scout->getType());
+	}
+    }
+}
+bool Player::AI_maybePickUpItems(Stack *s, int max_dist, int max_mp, 
+				 bool &picked_up, bool &stack_died)
+{
+  int min_dist = -1;
+  bool stack_moved = false;
+  Vector<int> item_tile(-1, -1);
+
+  // do we not have a hero?
+  if (s->hasHero() == false)
+    return false;
+
+  //ok, which bag of stuff is closest?
+  std::vector<Vector<int> > tiles = GameMap::getInstance()->getItems();
+  std::vector<Vector<int> >::iterator it = tiles.begin();
+  for(; it != tiles.end(); it++)
+    {
+      Vector<int> tile = *it;
+      //don't consider bags of stuff that are inside enemy cities
+      City *c = Citylist::getInstance()->getObjectAt(tile);
+      if (c)
+	{
+	  if (c->getOwner() != s->getOwner())
+	    continue;
+	}
+
+      int distance = dist (tile, s->getPos());
+      if (distance < min_dist || min_dist == -1)
+	{
+	  min_dist = distance;
+	  item_tile = tile;
+	}
+    }
+
+  //if no bags of stuff, or the bag is too far away
+  if (min_dist == -1 || min_dist > max_dist)
+    return false;
+  
+  //are we not standing on it?
+  if (s->getPos() != item_tile)
+    {
+      //can we really reach it?
+      Vector<int> old_dest(-1,-1);
+      if (s->getPath()->size())
+	old_dest = *s->getPath()->back();
+      Uint32 mp = s->getPath()->calculate(s, item_tile);
+      if ((int)mp > max_mp)
+	{
+	  //nope.  unreachable.  set in our old path.
+	  if (old_dest != Vector<int>(-1,-1))
+	    s->getPath()->calculate(s, old_dest);
+	  return false;
+	}
+      stack_moved = stackMove(s);
+      //maybe we died -- an enemy stack was guarding the bag.
+      if (!d_stacklist->getActivestack())
+	{
+	  stack_died = true;
+	  return true;
+	}
+      s = d_stacklist->getActivestack();
+    }
+
+  //are we standing on it now?
+  if (s->getPos() == item_tile)
+    {
+      Hero *hero = static_cast<Hero*>(s->getFirstHero());
+      if (hero)
+	picked_up = heroPickupAllItems(hero, s->getPos());
+    }
+
+  return stack_moved;
+}
+
+bool Player::AI_maybeVisitTempleForBlessing(Stack *s, int dist, int max_mp, 
+					    double percent_can_be_blessed, 
+					    bool &blessed, bool &stack_died)
+{
+  bool stack_moved = false;
+  Templelist *tl = Templelist::getInstance();
+
+  Temple *temple = tl->getNearestVisibleAndUsefulTemple(s, percent_can_be_blessed, dist);
+  if (!temple)
+    return false;
+
+  //if we're not there yet
+  if (s->getPos() != temple->getPos())
+    {
+      //can we really reach it?
+      Vector<int> old_dest(-1,-1);
+      if (s->getPath()->size())
+	old_dest = *s->getPath()->back();
+      Uint32 mp = s->getPath()->calculate(s, temple->getPos());
+      if ((int)mp > max_mp)
+	{
+	  //nope.  unreachable.  set in our old path.
+	  if (old_dest != Vector<int>(-1,-1))
+	    s->getPath()->calculate(s, old_dest);
+	  return false;
+	}
+      stack_moved = stackMove(s);
+        
+      //maybe we died -- an enemy stack was guarding the temple
+      if (!d_stacklist->getActivestack())
+	{
+	  stack_died = true;
+	  return true;
+	}
+      s = d_stacklist->getActivestack();
+    }
+
+  int num_blessed = 0;
+  //are we there yet?
+  if (s->getPos() == temple->getPos())
+    {
+      num_blessed = stackVisitTemple(s, temple);
+    }
+
+  blessed = num_blessed > 0;
+  return stack_moved;
+}
+
+bool Player::safeFromAttack(City *c, Uint32 safe_mp, Uint32 min_defenders)
+{
+  //if there isn't an enemy city nearby to the source
+  // calculate mp to nearest enemy city
+  //   needs to be less than 18 mp with a scout
+  //does the source city contain at least 3 defenders?
+
+  City *enemy_city = Citylist::getInstance()->getNearestEnemyCity(c->getPos());
+  if (enemy_city)
+    {
+      Uint32 mp = Stack::scout (c->getOwner(), c->getPos(), 
+				enemy_city->getPos());
+      if ((int)mp <= 0 || mp >= safe_mp)
+	{
+	  if (c->countDefenders() >= min_defenders)
+	    return true;
+	}
+    }
+
+  return false;
+}
+
+bool Player::AI_maybeDisband(Stack *s, City *city, Uint32 min_defenders, 
+			     int safe_mp, bool &stack_killed)
+{
+  //to prevent armies from piling up in far away places, 
+  //we disband some periodically.
+  if (s->size() != MAX_STACK_SIZE)
+    return false;
+
+  //is the city in danger from a city?
+  if (safeFromAttack(city, safe_mp, 0) == false)
+    return false;
+
+  if (city->countDefenders() - s->size() >= min_defenders)
+    {
+    return stackDisband(s);
+    }
+
+  //okay, we need to disband part of our stack
+  //find a square to travel to
+  std::list<Vector<int> > diffs;
+  diffs.push_back(Vector<int>(0, 1));
+  diffs.push_back(Vector<int>(0, -1));
+  diffs.push_back(Vector<int>(-1, -1));
+  diffs.push_back(Vector<int>(-1, 1));
+  diffs.push_back(Vector<int>(1, -1));
+  diffs.push_back(Vector<int>(1, 1));
+  diffs.push_back(Vector<int>(1, 0));
+  diffs.push_back(Vector<int>(-1, 0));
+
+  Vector<int> found = Vector<int>(-1, -1);
+  for (std::list<Vector<int> >::iterator it = diffs.begin();
+       it != diffs.end(); it++)
+    {
+      Vector<int> dest = s->getPos() + (*it);
+      if (d_stacklist->getObjectAt(dest) == NULL)
+	{
+	  Uint32 mp = s->getPath()->calculate(s, dest);
+	  if ((int)mp <= 0)
+	    continue;
+	  found = dest;
+	  break;
+	}
+    }
+
+  //no place to move to (strange)
+  if (found == Vector<int>(-1, -1))
+    return false;
+
+  //before we move, ungroup the lucky ones not being disbanded
+  unsigned int count = 0;
+  s->group();
+  for (Stack::reverse_iterator i = s->rbegin(); i != s->rend(); i++)
+    {
+      if (count == min_defenders)
+	break;
+      if ((*i)->isHero() == false)
+	{
+	  count++;
+	  (*i)->setGrouped(false);
+	}
+    }
+
+  stackSplit(s);
+  stackMove(s);
+  s = d_stacklist->getActivestack();
+
+  if (d_stacklist->getActivestack() == 0) 
+    {
+      //maybe we got lucky and inadvertently attacked an enemy stack and lost.
+      stack_killed = true;
+      return false;
+    }
+
+  return stackDisband(s);
+}
+
+bool Player::AI_maybeVector(City *c, Uint32 safe_mp, Uint32 min_defenders,
+			    City *target, City **vector_city)
+{
+  if (vector_city)
+    *vector_city = NULL;
+  Citylist *cl = Citylist::getInstance();
+
+  //is this city producing anything that we can vector?
+  if (c->getActiveProductionSlot() == -1)
+    return false;
+
+  //is it safe to vector from this city?
+  bool safe = safeFromAttack(c, 18, 3);
+
+  if (!safe)
+    return false;
+
+  //get the nearest city to the enemy city that can accept vectored units
+  City *near_city = cl->getNearestFriendlyVectorableCity(target->getPos());
+  if (!near_city)
+    return false;
+
+  //if it's us then it's easier to just walk.
+  if (near_city == c)
+    return false;
+
+  //is that city already vectoring?
+  if (near_city->getVectoring() != Vector<int>(-1, -1))
+    return false;
+
+  //can i just walk there faster?
+
+  //find mp from source to target city
+  const Army *proto = c->getProductionBase(c->getActiveProductionSlot());
+  Uint32 mp_from_source_city = Stack::scout(c->getOwner(), c->getPos(),
+					    target->getPos(), proto);
+
+  //find mp from nearer vectorable city to target city
+  Uint32 mp_from_near_city = Stack::scout(c->getOwner(), near_city->getPos(),
+					  target->getPos(), proto);
+
+  Uint32 max_moves_per_turn = proto->getStat(Army::MOVES);
+
+  double turns_to_move_from_source_city = 
+    (double)mp_from_source_city / (double)max_moves_per_turn;
+  double turns_to_move_from_near_city = 
+    (double)mp_from_near_city / (double)max_moves_per_turn;
+  turns_to_move_from_near_city += 1.0; //add extra turn to vector
+
+  //yes i can walk there faster, so don't vector
+  if (turns_to_move_from_source_city <= turns_to_move_from_near_city)
+    return false;
+
+  //great.  now do the vectoring.
+  c->changeVectorDestination(near_city->getPos());
+
+  if (vector_city)
+    *vector_city = near_city;
+  return true;
+}
+
+void Player::AI_setupVectoring(Uint32 safe_mp, Uint32 min_defenders,
+			       Uint32 mp_to_front)
+{
+  Citylist *cl = Citylist::getInstance();
+  //turn off vectoring where it isn't safe anymore
+  //turn off vectoring for destinations that are far away from the
+  //nearest enemy city
+
+	  
+  debug("setting up vectoring\n");
+  for (Citylist::iterator cit = cl->begin(); cit != cl->end(); ++cit)
+    {
+      City *c = &*cit;
+      if (c->getOwner() != this || c->isBurnt())
+	continue;
+      Vector<int> dest = c->getVectoring();
+      if (dest == Vector<int>(-1, -1))
+	continue;
+      if (safeFromAttack(c, safe_mp, min_defenders) == false)
+	{
+	  City *target_city = Citylist::getInstance()->getObjectAt(dest);
+	  debug("stopping vectoring from " << c->getName() <<" to " << target_city->getName() << " because it's not safe to anymore!\n")
+	    c->setVectoring(Vector<int>(-1,-1));
+	  continue;
+	}
+
+      City *enemy_city = cl->getNearestEnemyCity(dest);
+      if (!enemy_city)
+	{
+	  City *target_city = Citylist::getInstance()->getObjectAt(dest);
+	  debug("stopping vectoring from " << c->getName() <<" to " << target_city->getName() << " because there aren't any more enemy cities!\n")
+	    c->setVectoring(Vector<int>(-1,-1));
+	  continue;
+	}
+
+      Uint32 mp = Stack::scout(this, dest, enemy_city->getPos(), NULL);
+      if ((int)mp <= 0 || mp > mp_to_front)
+	{
+
+	  City *target_city = Citylist::getInstance()->getObjectAt(dest);
+	  debug("stopping vectoring from " << c->getName() <<" to " << target_city->getName() << " because it's too far away from an enemy city!\n")
+	    c->setVectoring(Vector<int>(-1,-1));
+	  continue;
+	}
+    }
+
+  for (Citylist::iterator cit = cl->begin(); cit != cl->end(); ++cit)
+    {
+      City *c = &*cit;
+      if (c->getOwner() != this || c->isBurnt())
+	continue;
+      City *enemy_city = cl->getNearestEnemyCity(c->getPos());
+      if (!enemy_city)
+	continue;
+      City *vector_city = NULL;
+      //if the city isn't already vectoring
+      if (c->getVectoring() == Vector<int>(-1,-1))
+	{
+	  bool vectored = AI_maybeVector(c, safe_mp, min_defenders, enemy_city, 
+					 &vector_city);
+	  if (vectored)
+	    debug("begin vectoring from " << c->getName() <<" to " << vector_city->getName() << "!\n");
+	}
+    }
+}
+
+void Player::doCityProducesArmy(City *city)
+{
+  city->armyArrives();
+}
+
+bool Player::cityProducesArmy(City *city)
+{
+  Action_Produce *item = new Action_Produce();
+  doCityProducesArmy(city);
+  const Army *army = city->getProductionBase(city->getActiveProductionSlot());
+  if (city->getVectoring() == Vector<int>(-1, -1))
+    item->fillData(army, city, false);
+  else
+    item->fillData(army, city, true);
+  addAction(item);
+  return true;
+}
+	
+void Player::doVectoredUnitArrives(VectoredUnit *unit)
+{
+  unit->armyArrives();
+}
+
+bool Player::vectoredUnitArrives(VectoredUnit *unit)
+{
+  Action_ProduceVectored *item = new Action_ProduceVectored();
+  item->fillData(unit->getArmy()->getType(), unit->getDestination());
+  addAction(item);
+  doVectoredUnitArrives(unit);
+  return true;
+}
+
+std::list<Action *> Player::getReportableActions()
+{
+  std::list<Action *> actions;
+  std::list<Action *>::iterator it = d_actions.begin();
+  for (; it != d_actions.end(); it++)
+    {
+      if ((*it)->getType() == Action::PRODUCE_UNIT ||
+	  (*it)->getType() == Action::PRODUCE_VECTORED_UNIT ||
+	  (*it)->getType() == Action::CITY_DESTITUTE)
+	actions.push_back(*it);
+    }
+  return actions;
+}
+
+	
+void Player::cityTooPoorToProduce(City *city, int slot)
+{
+  cityChangeProduction(city, -1);
+  const Army *a = city->getProductionBase(slot);
+  Action_CityTooPoorToProduce *action = new Action_CityTooPoorToProduce();
+  action->fillData(city, a);
+  addAction(action);
+}
+
+void Player::pruneActionlist()
+{
+  pruneActionlist(d_actions);
+}
+
+void Player::pruneActionlist(std::list<Action*> actions)
+{
+  //remove duplicate city production actions
+
+  //enumerate the ones we want
+  std::list<Action_Production*> keepers;
+  std::list<Action*>::reverse_iterator ait;
+  for (ait = actions.rbegin(); ait != actions.rend(); ait++)
+    {
+      if ((*ait)->getType() != Action::CITY_PROD)
+	continue;
+      //if this city isn't already in the keepers list, then add it.
+  
+      Action_Production *action = static_cast<Action_Production*>(*ait);
+      bool found = false;
+      std::list<Action_Production*>::const_iterator it;
+      for (it = keepers.begin(); it != keepers.end(); it++)
+	{
+	  if (action->getCityId() == (*it)->getCityId())
+	    {
+	      found = true;
+	      break;
+	    }
+	}
+      if (found == false)
+	keepers.push_back(action);
+
+    }
+
+  //now delete all city production events that aren't in keepers
+  int total = 0;
+  std::list<Action*>::iterator bit;
+  for (bit = actions.begin(); bit != actions.end(); bit++)
+    {
+      if ((*bit)->getType() != Action::CITY_PROD)
+	continue;
+      if (find (keepers.begin(), keepers.end(), (*bit)) == keepers.end())
+	{
+	  total++;
+	  actions.erase (bit);
+	  bit = actions.begin();
+	  continue;
+	}
+    }
+  //if (total)
+    //printf ("pruned %d city production actions.\n", total);
+
+}
+
 // End of file
