@@ -41,7 +41,9 @@ class Stacklist;
 class XML_Helper;
 class Hero;
 class Action;
+class NetworkAction;
 class History;
+class NetworkHistory;
 class City;
 class Quest;
 class Army;
@@ -52,6 +54,7 @@ class FogMap;
 class Fight;
 class Reward;
 class Signpost;
+class VectoredUnit;
 
 //! The abstract player class.
 /** 
@@ -214,24 +217,6 @@ class Player: public sigc::trackable
 	//! Create a new player from another player.
         static Player* create(Player* orig, Type type);
 
-	/**
-	 * Get the default colour for the Player with the given Id.
-	 *
-	 * @note This colour is used to graphically shade Army, Shield, Flags,
-	 * and selector pictures.
-	 *
-	 * @note This is not used to obtain the Neutral player's colour.
-	 *
-	 * @param player_no  The player's Id for which we want the colour.
-	 *
-	 * @return The default colour associated with the player.
-	 */
-	//! Get standard colour for a player.
-	static SDL_Color get_color_for_no(int player_no);
-
-	//! Get standard colour for the neutral player.
-	static SDL_Color get_color_for_neutral();
-
         //! Change the player's name.
         void setName(std::string name){d_name = name;}
         
@@ -271,8 +256,8 @@ class Player: public sigc::trackable
         //! Returns the unique ID of the player.
         Uint32 getId() const {return d_id;}
 
-        //! Returns the list of player's actions. 
-        std::list<Action*>* getActionlist() {return &d_actions;}
+	//! Returns a list of the player's actions to show in a report.
+	std::list<Action *> getReportableActions();
 
         //! Returns the list of player's events. 
         std::list<History*>* getHistorylist() {return &d_history;}
@@ -296,6 +281,9 @@ class Player: public sigc::trackable
 	//! Return the upkeep.
         Uint32 getUpkeep() {return d_upkeep;}
 
+	//! Return the income from all of the player's cities.
+        Uint32 getIncome () {return d_income;}
+
 	/**
 	 * Perform a summation of the upkeep value for every Army in the 
 	 * player's Stacklist.  This method sets d_upkeep.
@@ -304,6 +292,14 @@ class Player: public sigc::trackable
 	//! Calculates the upkeep.
 	void calculateUpkeep();
 
+	/**
+	 * Perform a summation of the income value for every City in the 
+	 * player's Citylist.  This method sets d_income.
+	 * The income value is in gold pieces.
+	 */
+	//! Calculates the upkeep.
+	void calculateIncome();
+
 	//! Declare a new diplomatic state with respect to an opponent.
 	void declareDiplomacy(DiplomaticState state, Player *player);
 
@@ -536,6 +532,7 @@ class Player: public sigc::trackable
          */
         void recruitHero(Hero* herotemplate, City *city, int cost, int alliesCount, const Army *ally);
 
+	void rename (std::string name);
         /** 
 	 * Called whenever a hero advances a level.
 	 * For human players this method presents a dialog that allows the
@@ -544,7 +541,7 @@ class Player: public sigc::trackable
 	 * used to decide which stat should be improved.
          * 
 	 * This callback must result in an Action_Level element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 *
          * @param army     The army to raise (is always a Hero.)
          */
@@ -558,7 +555,7 @@ class Player: public sigc::trackable
 	 * The Army units that are grouped are the units in the new stack.
 	 *
 	 * This callback must result in an Action_Split element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
          *
          * @param s        The stack to split.
 	 *
@@ -571,7 +568,7 @@ class Player: public sigc::trackable
 	 * Called to merge two stacks into one.
 	 *
 	 * This callback must result in an Action_Join element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
          *
          * @param receiver     The receiving stack.
          * @param joining      The joining stack, destroyed after the join.
@@ -589,7 +586,7 @@ class Player: public sigc::trackable
 	 * Stack.  This method can trigger many other actions.
 	 *
 	 * This callback must result in an Action_Move element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 *
 	 * @param s             The stack to be moved.
 	 *
@@ -598,6 +595,12 @@ class Player: public sigc::trackable
         //! Callback to move a stack on the map.
         bool stackMove(Stack* s);
 
+	//! Callback to take the armies from the stack that have at least
+	//! enough moves to reach the end of the stack's path.
+	bool stackSplitAndMove(Stack* s);
+	bool stackSplitAndMoveToAttack(Stack* s);
+	bool stackSplitAndMoveToJoin(Stack* s, Stack *join);
+
         /** 
 	 * Called to move a Stack to a specified position.
          *
@@ -607,7 +610,7 @@ class Player: public sigc::trackable
 	 * round and should continue the movement.
          *
 	 * This callback must result in an Action_Move element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 *
          * @param s                The stack to be moved.
          * @param dest             The destination of the move.
@@ -627,7 +630,7 @@ class Player: public sigc::trackable
 	 * events, the pointers are set to 0.
          *
 	 * This callback must result in an Action_Fight element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 *
          * @param attacker         The list of attacking stacks.
          * @param defender         The list of defending stacks.
@@ -681,7 +684,7 @@ class Player: public sigc::trackable
 	 * A stack searches a ruin.  The stack must contain a hero.
 	 *
 	 * This callback must result in an Action_Ruin element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 *
          * @param stack            The stack which searches the ruin.
          * @param ruin             The ruin to be searched.
@@ -697,7 +700,7 @@ class Player: public sigc::trackable
          * strength of all armies rises by 1.
          *
 	 * This callback must result in an Action_Temple element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 *
          * @param stack            The stack visiting the temple.
          * @param temple           The visited temple.
@@ -713,7 +716,7 @@ class Player: public sigc::trackable
 	 * stack, the quest is assigned to the first hero without a quest.
          *
 	 * This callback must result in an Action_Quest element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 * This callback must result in a History_QuestStarted element being
 	 * added to the player's History list (Player::d_history).
 	 *
@@ -752,7 +755,7 @@ class Player: public sigc::trackable
 	 * becomes owned by the ocuppying player.
          *
 	 * This callback must result in an Action_Occupy element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 *
          * @param city             The occupied city.
 	 *
@@ -771,7 +774,7 @@ class Player: public sigc::trackable
 	 * amount of gold pieces.
          *
 	 * This callback must result in an Action_Pillage element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 *
          * @param city             The city to be pillaged.
          * @param gold             Returns the amount of gold pillaged.
@@ -780,7 +783,7 @@ class Player: public sigc::trackable
          * @return False on error, true otherwise.
          */
 	//! Callback to pillage a city.
-        void cityPillage(City* city, int& gold, int& pillaged_army_type);
+        void cityPillage(City* city, int& gold, int *pillaged_army_type);
 
         /**
 	 * Sack a city (trade in all army types except one and get some gold.)
@@ -795,7 +798,7 @@ class Player: public sigc::trackable
 	 * as defined in RealPlayer to sack cities.
          *
 	 * This callback must result in an Action_Sack element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
          *
          * @param city             The city to be sacked .
          * @param gold             Returns the amount of gold sacked.
@@ -820,7 +823,7 @@ class Player: public sigc::trackable
 	 * as defined in RealPlayer to raze cities.
          *
 	 * This callback must result in an Action_Raze element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
          *
          * @param city             The city to be razed.
 	 *
@@ -840,7 +843,7 @@ class Player: public sigc::trackable
 	 * removed permanently.
          *
 	 * This callback must result in an Action_Buy element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
          *
          * @param city             The lucky city.
          * @param slot             The production slot of the city.  The 
@@ -865,7 +868,7 @@ class Player: public sigc::trackable
 	 * will arrive in the city that produced it.
          *
 	 * This callback must result in an Action_Production element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
          *
          * @param city             The affected city.
          * @param slot             The index of the selected production slot.
@@ -881,6 +884,16 @@ class Player: public sigc::trackable
 	//! Callback to change the Army unit being produced within a City.
         bool cityChangeProduction(City* city, int slot);
 
+	//! A player's city produces an army unit.
+	/**
+	 * @param city  The city that has produced an army unit.
+         * @return False on error, true otherwise.
+	 */
+	bool cityProducesArmy(City *city);
+
+	//! A player has a vectored army unit arrive somewhere.
+	bool vectoredUnitArrives(VectoredUnit *unit);
+
         /** 
 	 * This method gives the player the specified Reward.  There are 
 	 * various possibilities when they player is being given a reward.
@@ -891,7 +904,7 @@ class Player: public sigc::trackable
 	 * contains a Hero, and the Reward is an Item for the Hero to carry.
 	 *
 	 * This callback must result in an Action_Reward element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
          *
          * @param stack            The stack which has caused the reward.
          * @param reward           A pointer for storing the Reward being 
@@ -907,7 +920,7 @@ class Player: public sigc::trackable
 	 * stacks saves upkeep for unwanted Army units.
 	 *
 	 * This callback must result in an Action_Disband element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 *
 	 * @param stack            The stack to disband.
 	 *
@@ -926,7 +939,7 @@ class Player: public sigc::trackable
 	 * drop items here.
 	 *
 	 * This callback must result in an Action_Equip element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 *
 	 * @param hero             The Hero that holds the item.
 	 * @param item             The Item to drop onto the ground.
@@ -948,7 +961,7 @@ class Player: public sigc::trackable
 	 * drop items here.
 	 *
 	 * This callback must result in one or more Action_Equip elements 
-	 * being added to the player's Action list (Player::d_actions).
+	 * being given to the addAction method.
 	 *
 	 * @param hero             The Hero that holds the items.
 	 * @param pos              The position of the tile on the game map to 
@@ -969,7 +982,7 @@ class Player: public sigc::trackable
 	 * pickup items from the tile they are on.
 	 *
 	 * This callback must result in an Action_Equip element being 
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 *
 	 * @param hero             The Hero that holds the item.
 	 * @param item             The Item to pickup off of the ground.
@@ -981,6 +994,8 @@ class Player: public sigc::trackable
         //! Callback to have a Hero pick up an Item.
         bool heroPickupItem(Hero *hero, Item *item, Vector<int> pos);
 
+	bool heroPickupAllItems(Hero *h, Vector<int> pos);
+
 	/**
 	 * Completing a Quest entails that the Hero is going to receive a
 	 * reward, but that happens in Player::giveReward.
@@ -1011,7 +1026,7 @@ class Player: public sigc::trackable
 	 * mechanism to collectively surrender to a final human player.
 	 *
 	 * This callback must result in a Action_Resign element being
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 *
 	 */
         //! Callback to disband all the player's stacks and raze all cities.
@@ -1026,7 +1041,7 @@ class Player: public sigc::trackable
 	 * Signposts for which we have a Stack co-located.
 	 *
 	 * This callback must result in a Action_ModifySignpost element being
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 *
 	 * @param signpost         The signpost to modify.
 	 * @param message          The new text to inscribe onto the sign.
@@ -1043,7 +1058,7 @@ class Player: public sigc::trackable
 	 * do not consider doing so.
 	 *
 	 * This callback must result in a Action_RenameCity element being
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 *
 	 * @param city             The city to change the name of.
 	 * @param name             The new name of the city.
@@ -1061,7 +1076,7 @@ class Player: public sigc::trackable
 	 * only human players use this method.
 	 *
 	 * This callback must result in a Action_Vector element being
-	 * added to the player's Action list (Player::d_actions).
+	 * given to the addAction method.
 	 *
          * @param  city   The city to vector from.
          * @param  dest   The place on the map to vector the produced Army
@@ -1083,7 +1098,7 @@ class Player: public sigc::trackable
 	 * only human players use this method.
 	 *
 	 * This callback must result in one or more Action_Vector elements 
-	 * being added to the player's Action list (Player::d_actions).
+	 * being given to the addAction method.
 	 *
 	 * @param  city   The city being vectored to.
          * @param  dest   The place on the map to vector to.  The destination 
@@ -1117,6 +1132,7 @@ class Player: public sigc::trackable
         //! Callback to plant a player's standard.
         bool heroPlantStandard(Stack *stack);
 
+	void cityTooPoorToProduce(City *city, int slot);
 	/**
 	 * @param city   The city being invaded.
 	 * @param loot   The gold looted.
@@ -1186,7 +1202,7 @@ class Player: public sigc::trackable
 	 * @param army_types  The list of Army types traded-in for gold pieces.
 	 */
         //! Emitted whenever the player pillages a city.
-        sigc::signal<void, City*, Stack*, int, std::list<Uint32> > spillagingCity;
+        sigc::signal<void, City*, Stack*, int, Uint32> spillagingCity;
 
 	/**
 	 * @param city        The city that has been sacked.
@@ -1270,8 +1286,12 @@ class Player: public sigc::trackable
 
         sigc::signal<void, int> hero_arrives_with_allies;
 
-        sigc::signal<void, Action *> action_done;
+        sigc::signal<void, NetworkAction *> acting;
+        sigc::signal<void, NetworkHistory *> history_written;
         
+	//! is it safe to vector from the given city?
+	static bool safeFromAttack(City *c, Uint32 safe_mp, Uint32 min_defenders);
+	void addHistory(History *history);
     protected:
         // do some fight cleaning up, setting
         void cleanupAfterFight(std::list<Stack*> &attackers,
@@ -1335,6 +1355,9 @@ class Player: public sigc::trackable
 	//! How many gold pieces the Player paid out in the last turn.
 	Uint32 d_upkeep;
 
+	//! How many gold pieces the Player made from taxes in the last turn.
+	Uint32 d_income;
+
 	//! The diplomatic view that this Player has of each other Player.
 	DiplomaticState d_diplomatic_state[MAX_PLAYERS];
 
@@ -1360,7 +1383,7 @@ class Player: public sigc::trackable
         void doStackJoin(Stack* receiver, Stack* joining, bool grouped);
         int doStackVisitTemple(Stack *s, Temple *t);
         void doCityOccupy(City *c);
-        void doCityPillage(City *c, int& gold, int& pillaged_army_type);
+        void doCityPillage(City *c, int& gold, int* pillaged_army_type);
         void doCitySack(City *c, int& gold, std::list<Uint32> *sacked_types);
         void doCityRaze(City *c);
         void doCityBuyProduction(City *c, int slot, int type);
@@ -1380,7 +1403,61 @@ class Player: public sigc::trackable
         void doProposeDiplomacy (DiplomaticProposal proposal, Player *player);
         void doConquerCity(City *city, Stack *stack);
         void doRecruitHero(Hero* herotemplate, City *city, int cost, int alliesCount, const Army *ally);
+        void doRename(std::string name);
+	void doCityProducesArmy(City *city);
+	void doVectoredUnitArrives(VectoredUnit *unit);
 
+	void AI_maybeBuyScout();
+
+	//! Go to a temple if we're near enough.
+	/**
+	 * Helper method to take a stack on a mission to get blessed.
+	 * If the method returns false initially, it means that the nearest 
+	 * temple is unsuitable.
+	 * @note The idea is that this method is called over subsequent turns, 
+	 * until the blessed parameter gets filled with a value of true.
+	 *
+	 * @param s            The stack to visit a temple.
+	 * @param dist         The maximum number of tiles that a temple
+	 *                     can be away from the stack, and be considered
+	 *                     for visiting.
+	 * @param mp           The maximum number of movement points that a
+	 *                     stack needs to have to reach the temple.
+	 * @param percent_can_be_blessed  If the stack has this many army 
+	 *                                units that have not been blessed
+	 *                                at the temple (expressed as a
+	 *                                percent), then the temple will be
+	 *                                considered for visiting.
+	 * @param blessed      Gets filled with false if the stack didn't get 
+	 *                     blessed.  Gets filled with true if the stack 
+	 *                     got blessed at the temple.
+	 * @param stack_died   Gets filled with true if the stack got killed
+	 *                     by an enemy stack on the same square as the
+	 *                     temple.
+	 *
+	 * Returns true if the stack moved, false if it stayed still.
+	 */
+	bool AI_maybeVisitTempleForBlessing(Stack *s, int dist, int mp, 
+					    double percent_can_be_blessed, 
+					    bool &blessed, bool &stack_died);
+	bool AI_maybePickUpItems (Stack *s, int dist, int mp, bool &picked_up,
+				  bool &stack_died);
+
+
+
+	bool AI_maybeVector(City *c, Uint32 safe_mp, Uint32 min_defenders,
+			    City *target, City **vector_city = NULL);
+
+
+	void AI_setupVectoring(Uint32 safe_mp, Uint32 min_defenders,
+			       Uint32 mp_to_front);
+
+	bool AI_maybeDisband(Stack *s, City *city, Uint32 min_defenders, 
+			     int safe_mp, bool &stack_died);
+
+	void pruneActionlist();
+	static void pruneActionlist(std::list<Action*> actions);
+	    
     private:
         //! Loads the subdata of a player (actions and stacklist)
         bool load(std::string tag, XML_Helper* helper);
