@@ -1,3 +1,5 @@
+// Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,31 +12,39 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #ifndef PORT_H
 #define PORT_H
 
 #include "Location.h"
 
-/** A port is just a thing on the map to differentiate space
-  */
-
+//! A port on the game map.
+/** 
+ * A port is place on the map that Stack objects can use to gain access to
+ * the water.
+ */
 class Port: public Location
 {
     public:
-        /** Default constructor
-          * 
-          * @param pos          the location of the port
+	//! Default constructor.
+        /**
+          * @param pos          The location of the port on the game map.
           */
-        Port(Vector<int> pos, std::string name = "Port");
-
-        //! Loading constructor. See XML_Helper
-        Port(XML_Helper* helper);
+        Port(Vector<int> pos);
+	//! Copy constructor.
         Port(const Port&);
+        //! Loading constructor.
+	/**
+	 * Load the port object from the opened saved-game file.
+	 * @param helper  The opened saved-game file to load the port from.
+	 */
+        Port(XML_Helper* helper);
+	//! Destructor.
         ~Port();
 
-        //! Save the port data.
+        //! Save the port data to the opened saved-game file.
         bool save(XML_Helper* helper) const;
 
 };
