@@ -1,3 +1,5 @@
+//  Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +12,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #include <stdlib.h>
 #include <sstream>
@@ -22,8 +25,11 @@
 #include "armysetlist.h"
 #include "playerlist.h"
 #include "ruinlist.h"
+#include "rewardlist.h"
+#include "Itemlist.h"
 #include "GameMap.h"
 #include "ruin.h"
+#include "ucompose.hpp"
 using namespace std;
 
 Reward::Reward(Type type, std::string name)
@@ -38,6 +44,11 @@ Reward::Reward(XML_Helper *helper)
   d_type = static_cast<Reward::Type>(t);
   helper->getData(d_name, "name");
 }
+        
+Reward::Reward (const Reward& orig)
+	:d_type(orig.d_type), d_name(orig.d_name)
+{
+}
 
 bool Reward::save(XML_Helper* helper) const
 {
@@ -84,6 +95,11 @@ Reward_Gold::Reward_Gold(XML_Helper* helper)
   helper->getData(d_gold, "gold");
 }
 
+Reward_Gold::Reward_Gold (const Reward_Gold & orig)
+	:Reward(orig), d_gold(orig.d_gold)
+{
+}
+
 bool Reward_Gold::save(XML_Helper* helper) const
 {
   bool retval = true;
@@ -98,6 +114,10 @@ Reward_Gold::~Reward_Gold()
 {
 }
 
+Uint32 Reward_Gold::getRandomGoldPieces()
+{
+  return 310 + (rand() % 1000);
+}
 
 Reward_Allies::Reward_Allies(Uint32 army_type, Uint32 army_set, Uint32 count)
     :Reward(Reward::ALLIES), d_count(count)
@@ -126,6 +146,12 @@ Reward_Allies::Reward_Allies(XML_Helper* helper)
   d_army = al->getArmy (d_army_set, d_army_type);
 }
 
+Reward_Allies::Reward_Allies (const Reward_Allies& orig)
+	:Reward(orig), d_army(orig.d_army), d_army_type(orig.d_army_type), 
+	d_army_set(orig.d_army_set), d_count(orig.d_count)
+{
+}
+
 bool Reward_Allies::save(XML_Helper* helper) const
 {
   bool retval = true;
@@ -137,6 +163,12 @@ bool Reward_Allies::save(XML_Helper* helper) const
   retval &= helper->closeTag();
   return retval;
 }
+	
+const Uint32 Reward_Allies::getRandomAmountOfAllies()
+{
+  return (rand() % MAX_STACK_SIZE) + 1;
+}
+
 const Army* Reward_Allies::randomArmyAlly()
 {
   Uint32 allytype;
@@ -152,11 +184,10 @@ const Army* Reward_Allies::randomArmyAlly()
       if (a->getAwardable())
         allytypes.push_back(a);
     }
-  if (!allytypes.empty())
-    allytype = rand() % allytypes.size();
-  else 
+  if (allytypes.empty())
     return NULL;
 
+  allytype = rand() % allytypes.size();
   return allytypes[allytype];
 }
 
@@ -165,6 +196,7 @@ bool Reward_Allies::addAllies(Player *p, Vector<int> pos, const Army *army, Uint
   for (unsigned int i = 0; i < alliesCount; i++)
     {
       Army* ally = new Army(*army, p);
+      ally->setUpkeep(0);
       if (GameMap::getInstance()->addArmy(pos, ally) == NULL)
         return false;
     }
@@ -176,6 +208,7 @@ bool Reward_Allies::addAllies(Player *p, Location *l, const Army *army, Uint32 a
   for (unsigned int i = 0; i < alliesCount; i++)
     {
       Army* ally = new Army(*army, p);
+      ally->setUpkeep(0);
       if (GameMap::getInstance()->addArmy(l, ally) == NULL)
         return false;
     }
@@ -209,6 +242,11 @@ Reward_Item::Reward_Item(XML_Helper* helper)
   helper->registerTag("item", sigc::mem_fun(this, &Reward_Item::loadItem));
 }
 
+Reward_Item::Reward_Item (const Reward_Item& orig)
+	:Reward(orig), d_item(orig.d_item)
+{
+}
+
 bool Reward_Item::save(XML_Helper* helper) const
 {
   bool retval = true;
@@ -219,6 +257,14 @@ bool Reward_Item::save(XML_Helper* helper) const
   return retval;
 }
 
+Item *Reward_Item::getRandomItem()
+{
+  Itemlist *il = Itemlist::getInstance();
+  Itemlist::iterator it = il->begin();
+  std::advance(it, rand() % il->size());
+  Item *i = it->second;
+  return new Item(*i);
+}
 
 Reward_Item::~Reward_Item()
 {
@@ -227,7 +273,7 @@ Reward_Item::~Reward_Item()
 }
 
 Reward_Ruin::Reward_Ruin(Ruin *ruin)
-    :Reward(Reward::RUIN), d_ruin(ruin)
+    :Reward(Reward::RUIN), d_ruin_pos(ruin->getPos())
 {
 }
 
@@ -238,69 +284,157 @@ Reward_Ruin::Reward_Ruin(XML_Helper* helper)
   Uint32 y;
   helper->getData(x, "x");
   helper->getData(y, "y");
-  d_ruin = Ruinlist::getInstance()->getObjectAt(x, y);
+  d_ruin_pos = Vector<int>(x,y);
 }
 
+Reward_Ruin::Reward_Ruin (const Reward_Ruin& orig)
+	:Reward(orig), d_ruin_pos(orig.d_ruin_pos)
+{
+}
 bool Reward_Ruin::save(XML_Helper* helper) const
 {
   bool retval = true;
   retval &= helper->openTag("reward");
   retval &= Reward::save(helper);
-  retval &= helper->saveData("x", d_ruin->getPos().x);
-  retval &= helper->saveData("y", d_ruin->getPos().y);
+  retval &= helper->saveData("x", getRuin()->getPos().x);
+  retval &= helper->saveData("y", getRuin()->getPos().y);
   retval &= helper->closeTag();
   return retval;
 }
 
+Ruin *Reward_Ruin::getRandomHiddenRuin()
+{
+  std::vector<Ruin *>hidden_ruins;
+  Ruinlist *rl = Ruinlist::getInstance();
+  Rewardlist *rw = Rewardlist::getInstance();
+  for (Ruinlist::iterator it = rl->begin(); it != rl->end(); it++)
+    {
+      if ((*it).isHidden())
+	if ((*it).getOwner() == NULL || 
+	    (*it).getOwner() == Playerlist::getInstance()->getNeutral())
+	  {
+	    //is it already being pointed to by a reward in the rewardlist?
+	    bool found = false;
+	    for (Rewardlist::iterator i = rw->begin(); i != rw->end(); i++)
+	      {
+		if ((*i)->getType() == Reward::RUIN)
+		  {
+		    Ruin *r = static_cast<Reward_Ruin*>(*i)->getRuin();
+		    if (r)
+		      {
+			if (r->getPos() == (*it).getPos())
+			  {
+			    found = true;
+			    break;
+			  }
+		      }
+		  }
+	      }
+	    if (found == false)
+	      hidden_ruins.push_back(&*it);
+	  }
+    }
+ if (hidden_ruins.empty())
+   return NULL;
+ return hidden_ruins[rand() % hidden_ruins.size()];
+}
+
 Reward_Ruin::~Reward_Ruin()
 {
 }
 
-Reward_Map::Reward_Map(Location *loc, Uint32 height, Uint32 width)
-    :Reward(Reward::MAP), d_loc(loc), d_height(height), d_width(width)
+Reward_Map::Reward_Map(Vector<int> pos, std::string name, 
+		       Uint32 height, Uint32 width)
+    :Reward(Reward::MAP, name), Location(pos), d_height(height), d_width(width)
 {
 }
 
-bool Reward_Map::loadLocation(std::string tag, XML_Helper* helper)
-{
-  if (tag == "location")
-    {
-      d_loc = new Location(helper);
-      return true;
-    }
-    
-  return false;
-}
-
 Reward_Map::Reward_Map(XML_Helper* helper)
-    :Reward(helper)
+    :Reward(helper), Location(helper)
 {
-  helper->registerTag("location", sigc::mem_fun(this, 
-						&Reward_Map::loadLocation));
   helper->getData(d_height, "height");
   helper->getData(d_width, "width");
 }
 
+Reward_Map::Reward_Map (const Reward_Map& orig)
+	:Reward(orig), Location(orig),
+	d_height(orig.d_height), d_width(orig.d_width)
+{
+}
+
 bool Reward_Map::save(XML_Helper* helper) const
 {
   bool retval = true;
   retval &= helper->openTag("reward");
   retval &= Reward::save(helper);
+  retval &= helper->saveData("id", getId());
+  retval &= helper->saveData("x", getPos().x);
+  retval &= helper->saveData("y", getPos().y);
+  retval &= helper->saveData("name", getName());
   retval &= helper->saveData("height", d_height);
   retval &= helper->saveData("width", d_width);
-  retval &= helper->openTag("location");
-  retval &= helper->saveData("id", d_loc->getId());
-  retval &= helper->saveData("name", d_loc->getName());
-  Vector<int> pos = d_loc->getPos();
-  retval &= helper->saveData("x", pos.x);
-  retval &= helper->saveData("y", pos.y);
-  retval &= helper->closeTag();
   retval &= helper->closeTag();
   return retval;
 }
 
+void Reward_Map::getRandomMap(int *x, int *y, int *width, int *height)
+{
+  int map_width = GameMap::getInstance()->getWidth();
+  *x = rand() % (map_width - (map_width / 10));
+  int map_height = GameMap::getInstance()->getHeight();
+  *y = rand() % (map_height - (map_height / 10));
+  *width = ((rand() % (map_width - *x)) + (map_width / 10));
+  *height = ((rand() % (map_height - *y)) + (map_height / 10));
+}
 
 Reward_Map::~Reward_Map()
 {
 }
 
+std::string Reward::getDescription()
+{
+  Glib::ustring s = "";
+  switch (getType())
+    {
+    case Reward::GOLD:
+	{
+	  Reward_Gold *g = dynamic_cast<Reward_Gold*>(this);
+	  s += String::ucompose(ngettext("%1 Gold Piece", "%1 Gold Pieces", 
+					 g->getGold()), g->getGold());
+	  return s;
+	}
+    case Reward::ALLIES:
+	{
+	  Reward_Allies *a = dynamic_cast<Reward_Allies *>(this);
+	  if (a->getArmy())
+	    s += String::ucompose(_("Allies: %1 x %2"), a->getArmy()->getName(),
+				  a->getNoOfAllies());
+	  return s;
+	}
+    case Reward::ITEM:
+	{
+	  Reward_Item *i = dynamic_cast<Reward_Item *>(this);
+	  if (i->getItem())
+	    s += String::ucompose(_("Item: %1"), i->getItem()->getName());
+	  return s;
+	}
+    case Reward::RUIN:
+	{
+	  Reward_Ruin *r = dynamic_cast<Reward_Ruin *>(this);
+	  if (r->getRuin())
+	    s += String::ucompose(_("Site: %1"), r->getRuin()->getName());
+	  return s;
+	}
+    case Reward::MAP:
+	{
+	  Reward_Map *m = dynamic_cast<Reward_Map *>(this);
+	  s += String::ucompose(_("Map: %1,%2 %3x%4"), 
+				  m->getPos().x,
+				  m->getPos().y,
+				  m->getHeight(),
+				  m->getWidth());
+	  return s;
+	}
+    }
+  return s;
+}
