@@ -1,3 +1,5 @@
+//  Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +12,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #include <sigc++/functors/mem_fun.h>
 
@@ -52,39 +55,6 @@ Roadlist::Roadlist()
 {
 }
 
-Road* Roadlist::getNearestRoad(const Vector<int>& pos)
-{
-    int diff = -1;
-    iterator diffit;
-    
-    for (iterator it = begin(); it != end(); ++it)
-    {
-       Vector<int> p = (*it).getPos();
-       int delta = abs(p.x - pos.x);
-       if (delta < abs(p.y - pos.y))
-           delta = abs(p.y - pos.y);
-       if ((diff > delta) || (diff == -1))
-       {
-           diff = delta;
-           diffit = it;
-       }
-    }
-
-    if (diff == -1) return 0;
-    return &(*diffit);
-}
-Road* Roadlist::getNearestRoad(const Vector<int>& pos, int dist)
-{
-  Road *r = getNearestRoad(pos);
-  if (!r)
-    return r;
-  if (r->getPos().x <= pos.x + dist && r->getPos().x >= pos.x - dist &&
-      r->getPos().y <= pos.y + dist && r->getPos().y >= pos.y - dist)
-    return r;
-  return NULL;
-}
-
-
 Roadlist::Roadlist(XML_Helper* helper)
 {
     helper->registerTag("road", sigc::mem_fun(this, &Roadlist::load));
