@@ -1,3 +1,7 @@
+// Copyright (C) 2001, 2003 Michael Bartl
+// Copyright (C) 2002, 2003, 2004, 2005 Ulf Lorenz
+// Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +14,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #include "ruin.h"
 #include "playerlist.h"
@@ -19,24 +24,25 @@
 #include <stdlib.h>
 
 Ruin::Ruin(Vector<int> pos, std::string name, int type, Stack* occupant, bool searched, bool hidden, Player *owner, bool sage)
-    :Location(name, pos), d_searched(searched), d_type(type),
+    :NamedLocation(pos, name), d_searched(searched), d_type(type),
     d_occupant(occupant), d_hidden(hidden), d_owner(owner), d_sage(sage)
 {
     d_owner = NULL;
     d_reward = NULL;
     //mark the location as being occupied by a ruin on the map
-    GameMap::getInstance()->getTile(d_pos.x, d_pos.y)->setBuilding(Maptile::RUIN);
+    GameMap::getInstance()->getTile(getPos())->setBuilding(Maptile::RUIN);
 }
 
 Ruin::Ruin(const Ruin& ruin)
-    :Location(ruin), d_searched(ruin.d_searched), d_type(ruin.d_type),
-    d_occupant(ruin.d_occupant), d_hidden(ruin.d_hidden), 
+    :NamedLocation(ruin), d_searched(ruin.d_searched), 
+    d_type(ruin.d_type), d_occupant(ruin.d_occupant), d_hidden(ruin.d_hidden), 
     d_owner(ruin.d_owner), d_sage(ruin.d_sage), d_reward(ruin.d_reward)
 {
 }
 
 Ruin::Ruin(XML_Helper* helper)
-    :Location(helper), d_type(0), d_occupant(0), d_hidden(0), d_owner(0), d_sage(0), d_reward(0)
+    :NamedLocation(helper), d_type(0), d_occupant(0), d_hidden(0), 
+    d_owner(0), d_sage(0), d_reward(0)
 {
     Uint32 ui;
     helper->getData(d_type, "type");
@@ -55,7 +61,7 @@ Ruin::Ruin(XML_Helper* helper)
       d_owner = NULL;
 
     //mark the location as being occupied by a ruin on the map
-    GameMap::getInstance()->getTile(d_pos.x, d_pos.y)->setBuilding(Maptile::RUIN);
+    GameMap::getInstance()->getTile(getPos())->setBuilding(Maptile::RUIN);
 }
 
 Ruin::~Ruin()
@@ -72,10 +78,10 @@ bool Ruin::save(XML_Helper* helper) const
 
   retval &= helper->openTag("ruin");
   retval &= helper->saveData("id", d_id);
-  retval &= helper->saveData("name", d_name);
+  retval &= helper->saveData("x", getPos().x);
+  retval &= helper->saveData("y", getPos().y);
+  retval &= helper->saveData("name", getName());
   retval &= helper->saveData("type", d_type);
-  retval &= helper->saveData("x", d_pos.x);
-  retval &= helper->saveData("y", d_pos.y);
   retval &= helper->saveData("searched", d_searched);
   retval &= helper->saveData("sage", d_sage);
   retval &= helper->saveData("hidden", d_hidden);
@@ -142,11 +148,11 @@ void Ruin::populateWithRandomReward()
   else
     num = rand() % 3;
   if (num == 0)
-    setReward(new Reward_Gold(300 + (rand() % 1000)));
+    setReward(new Reward_Gold(Reward_Gold::getRandomGoldPieces()));
   else if (num == 1)
     {
       const Army *a = Reward_Allies::randomArmyAlly();
-      setReward(new Reward_Allies(a, (rand() % MAX_STACK_SIZE) + 1));
+      setReward(new Reward_Allies(a, Reward_Allies::getRandomAmountOfAllies()));
     }
   else if (num == 2)
     {
@@ -154,7 +160,7 @@ void Ruin::populateWithRandomReward()
       if (reward)
 	setReward(reward);
       else //no items left to give!
-	setReward(new Reward_Gold(300 + (rand() % 1000)));
+	setReward(new Reward_Gold(Reward_Gold::getRandomGoldPieces()));
     }
 }
 // End of file
