@@ -1,3 +1,5 @@
+//  Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,33 +12,45 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #ifndef SIGNPOST_H
 #define SIGNPOST_H
 
+#define DEFAULT_SIGNPOST "nowhere"
+
 #include <string>
 #include "Location.h"
+#include "Renamable.h"
 
-/** A signpost is the place where a human player can read a relevant message.
-  */
-
-class Signpost: public Location
+//!A signpost is a map feature where a human player can read a relevant message.
+/**
+ * Signposts are generally useful on a hidden map, when they can direct a 
+ * player to a nearby city that is obscured from view.
+ *
+ * Players can change the contents of the signpost.
+ */
+class Signpost: public Location, public Renamable
 {
     public:
-        /** Default constructor
-          * 
-          * @param pos          the location of the signpost
-          * @param name         the contents of the sign
-          */
+	//! Default constructor.
+        /**
+         * @param pos          The location of the signpost on the game map.
+         * @param name         The contents of the sign.
+         */
         Signpost(Vector<int> pos, std::string name = "nowhere");
-
-        //! Loading constructor. See XML_Helper
-        Signpost(XML_Helper* helper);
+	//! Copy constructor.
         Signpost(const Signpost&);
+        //! Loading constructor.
+	/**
+	 * @param helper  The opened saved-game file to load the signpost from.
+	 */
+        Signpost(XML_Helper* helper);
+	//! Destructor.
         ~Signpost();
 
-        //! Save the signpost data.
+        //! Save the signpost data to an opened saved-game file.
         bool save(XML_Helper* helper) const;
 
 };
