@@ -1,3 +1,10 @@
+// Copyright (C) 2001, 2002, 2003 Michael Bartl
+// Copyright (C) 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
+// Copyright (C) 2004, 2005, 2006 Andrea Paternesi
+// Copyright (C) 2004 Thomas Plonka
+// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2007 Ole Laursen
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +17,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #include <config.h>
 
@@ -23,6 +31,7 @@
 #include "sdl-draw.h"
 #include "timing.h"
 #include "GameMap.h"
+#include "Configuration.h"
 
 SmallMap::SmallMap()
 {
@@ -61,36 +70,45 @@ void SmallMap::draw_selection()
     draw_rect(surface, pos.x+1, pos.y+1, pos.x + w-1, pos.y + h-1, raw);
 }
 
-void SmallMap::center_view(Vector<int> p, bool slide, bool from_tile)
+void SmallMap::center_view_on_tile(Vector<int> pos, bool slide)
 {
-  if (from_tile == false)
-    {
-      p.x = int(round(p.x / pixels_per_tile));
-      p.y = int(round(p.y / pixels_per_tile));
-
-      p -= view.dim / 2;
-
-      p = clip(Vector<int>(0, 0), p, GameMap::get_dim() - view.dim);
-    }
-  else
-      
-    p = clip(Vector<int>(0,0), p - view.dim / 2, GameMap::get_dim() - view.dim);
+  pos = clip(Vector<int>(0,0), pos - view.dim / calculateResizeFactor(), 
+	     GameMap::get_dim() - view.dim);
 
   if (slide)
-    slide_view(Rectangle(p.x, p.y, view.w, view.h));
+    slide_view(Rectangle(pos.x, pos.y, view.w, view.h));
   else
-    set_view(Rectangle(p.x, p.y, view.w, view.h));
+    set_view(Rectangle(pos.x, pos.y, view.w, view.h));
+	  
+  view_changed.emit(view);
+}
+
+void SmallMap::center_view_on_pixel(Vector<int> pos, bool slide)
+{
+  pos.x = int(round(pos.x / pixels_per_tile));
+  pos.y = int(round(pos.y / pixels_per_tile));
+
+  pos -= view.dim / calculateResizeFactor();
+
+  pos = clip(Vector<int>(0, 0), pos, GameMap::get_dim() - view.dim);
+
+  if (slide)
+    slide_view(Rectangle(pos.x, pos.y, view.w, view.h));
+  else
+    set_view(Rectangle(pos.x, pos.y, view.w, view.h));
 	  
-  if (Playerlist::isFinished()) //window closed while computer player moves
-      return;
   view_changed.emit(view);
 }
 
 void SmallMap::after_draw()
 {
   OverviewMap::after_draw();
-  draw_cities(false);
-  draw_selection();
+  if (Playerlist::getActiveplayer()->getType() == Player::HUMAN ||
+      Configuration::s_hidden_map == false)
+    {
+      draw_cities(false);
+      draw_selection();
+    }
   map_changed.emit(get_surface());
 }
 
@@ -102,7 +120,7 @@ void SmallMap::mouse_button_event(MouseButtonEvent e)
   if ((e.button == MouseButtonEvent::LEFT_BUTTON ||
        e.button == MouseButtonEvent::RIGHT_BUTTON)
       && e.state == MouseButtonEvent::PRESSED)
-    center_view(e.pos, true, false);
+    center_view_on_pixel(e.pos, true);
 }
 
 void SmallMap::mouse_motion_event(MouseMotionEvent e)
@@ -112,8 +130,9 @@ void SmallMap::mouse_motion_event(MouseMotionEvent e)
 
   if (e.pressed[MouseMotionEvent::LEFT_BUTTON] ||
       e.pressed[MouseMotionEvent::RIGHT_BUTTON])
-    center_view(e.pos, false, false);
+    center_view_on_pixel(e.pos, false);
 }
+
 int slide (int x, int y)
 {
   int skip = 2;
@@ -155,3 +174,22 @@ void SmallMap::slide_view(Rectangle new_view)
 	}
     }
 }
+
+void SmallMap::blank()
+{
+  Uint32 fog_color = SDL_MapRGB(surface->format, 0, 0, 0);
+  int size = int(pixels_per_tile) > 1 ? int(pixels_per_tile) : 1;
+  //fog it up
+  for (int i = 0; i < GameMap::getWidth(); i++)
+    for (int j = 0; j < GameMap::getHeight(); j++)
+      {
+	Vector <int> pos;
+	pos.x = i;
+	pos.y = j;
+	pos = mapToSurface(pos);
+	draw_filled_rect(surface, pos.x, pos.y,
+			 pos.x + size, pos.y + size, fog_color);
+      }
+  map_changed.emit(get_surface());
+}
+
