@@ -163,7 +163,7 @@ void Stack::moveToDest(Vector<int> dest)
       else 
 	{
 	  //maybe the army has a natural movement ability
-	  if ((*it)->getStat(Army::MOVE_BONUS) == maptype && needed_moves > 1)
+	  if ((*it)->getStat(Army::MOVE_BONUS) & maptype && needed_moves > 1)
 	    (*it)->decrementMoves(2);
 	  else
 	    (*it)->decrementMoves(needed_moves);
@@ -303,6 +303,16 @@ Army *Stack::getArmyById(Uint32 id) const
   return 0;
 }
 
+Uint32 Stack::countGroupedArmies() const
+{
+  Uint32 count = 0;
+  if (empty())
+    return 0;
+  for (const_iterator it = begin(); it != end(); ++it)
+    if ((*it)->isGrouped() == true)
+      count++;
+  return count;
+}
 
 void Stack::group()
 {
@@ -369,13 +379,19 @@ Uint32 Stack::calculateTileMovementCost(Vector<int> pos) const
 {
   Maptile* tile = GameMap::getInstance()->getTile(pos);
   Uint32 moves = tile->getMoves();
-  if (isFlying() && moves > 1)
+  Uint32 bonus = calculateMoveBonus();
+  if (bonus & tile->getMaptileType() && moves > 1)
+    moves = 2;
+  else if (isFlying() && moves > 1)
     moves = 2;
   return moves;
 }
 
 bool Stack::enoughMoves() const
 {
+  if (d_path->size() == 0)
+    return true; //we have enough moves to move nowhere!
+
   Vector<int> p = **(d_path->begin());
   Uint32 needed = calculateTileMovementCost(p);
 
@@ -432,7 +448,7 @@ void Stack::nextTurn()
 	for (item = backpack.begin(); item != backpack.end(); item++)
 	  {
 	    if ((*item)->getBonus(Item::DOUBLEMOVESTACK))
-	      movement_multiplier++;
+	      movement_multiplier*=2;
 	  }
       }
 
@@ -712,4 +728,107 @@ Uint32 Stack::getUpkeep()
     upkeep += (*it)->getUpkeep();
   return upkeep;
 }
+
+bool Stack::canJoin(const Stack *stack) const
+{
+  Uint32 joinSize = countGroupedArmies();
+  if (joinSize == 0)
+    joinSize = size();
+
+  /* this is necessary because human players "group" armies in stacks,
+   * while the computer player does not.
+   */
+  if ((stack->size() + joinSize) > MAX_STACK_SIZE)
+    return false;
+
+  return true;
+
+}
+
+std::vector<Uint32> Stack::determineReachableArmies(Vector<int> dest)
+{
+  std::vector<Uint32> ids;
+  //try each army individually to see if it reaches
+  for (iterator it = begin(); it != end(); it++)
+    {
+      if ((*it)->getMoves() > 0)
+	{
+	  Stack *stack = new Stack(getOwner(), getPos());
+	  stack->push_back(*it);
+	  if (stack->getGroupMoves() >= 
+	      stack->getPath()->calculate(stack, dest))
+	    ids.push_back((*it)->getId());
+	  stack->clear();
+	  delete stack;
+	  //fixme: can't delete stacks like this because it deletes the army
+	}
+    }
+  if (ids.size() == 0)
+    return ids;
+
+  //now try to see if any army units can tag along
+  for (iterator it = begin(); it != end(); it++)
+    {
+      //skip over armies that are already known to be reachable
+      if (find(ids.begin(), ids.end(), (*it)->getId()) != ids.end())
+	continue;
+      if ((*it)->getMoves() > 0)
+	{
+	  Stack *stack = new Stack(getOwner(), getPos());
+	  stack->push_back(*it);
+	  //also push back the rest of the known reachables
+	  std::vector<Uint32>::iterator iit = ids.begin();
+	  for (; iit != ids.end(); iit++)
+	    {
+	      Army *army = getArmyById(*iit);
+	      if (army)
+		stack->push_back(army);
+	    }
+	  if (stack->getGroupMoves() >= 
+	      stack->getPath()->calculate(stack, dest))
+	    ids.push_back((*it)->getId());
+	  stack->clear();
+	  delete stack;
+	}
+    }
+
+  return ids;
+}
+
+Uint32 Stack::countArmiesBlessedAtTemple(Uint32 temple_id)
+{
+  Uint32 blessed = 0;
+  for (iterator it = begin(); it != end(); it++)
+    {
+      if ((*it)->blessedAtTemple(temple_id))
+	blessed++;
+    }
+    return blessed;
+}
+	
+Uint32 Stack::scout(Player *p, Vector<int> src, Vector<int> dest, 
+		    const Army *proto)
+{
+  Stack *stack = new Stack(p, src);
+
+  if (!proto)
+    proto = Armysetlist::getInstance()->getScout(p->getArmyset());
+  if (!proto)
+    return 0;
+
+  Army *army = new Army (*proto);
+  if (!army)
+    return 0;
+  stack->push_back(army);
+  Uint32 mp = stack->getPath()->calculate(stack, dest);
+  delete stack;
+  return mp;
+}
+Uint32 Stack::scout(Stack *stack, Vector<int> dest)
+{
+  Stack *scout_stack = new Stack(*stack);
+  Uint32 mp = scout_stack->getPath()->calculate(scout_stack, dest);
+  delete scout_stack;
+  return mp;
+}
 // End of file
