@@ -1,3 +1,7 @@
+// Copyright (C) 2003 Michael Bartl
+// Copyright (C) 2003, 2004, 2005, 2006 Ulf Lorenz
+// Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +14,8 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #include <SDL_image.h>
 #include <sigc++/functors/mem_fun.h>
@@ -26,6 +31,14 @@ using namespace std;
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 #define debug(x)
 
+#define DEFAULT_TILE_SIZE 40
+	
+Tileset::Tileset(std::string name)
+	: d_name(name), d_dir(""), d_tileSize(DEFAULT_TILE_SIZE)
+{
+  d_info = "";
+}
+
 Tileset::Tileset(XML_Helper *helper)
 {
     helper->getData(d_name, "name"); 
@@ -111,7 +124,6 @@ bool Tileset::loadTile(string tag, XML_Helper* helper)
 	// create a new tile style with the information we got
 	// put it on the latest tilestyleset
 	TileStyle* tilestyle = new TileStyle(helper);
-	tilestyle->setIndex(tilestyleset->size());
 	tilestyleset->push_back(tilestyle);
 	d_tilestyles[tilestyle->getId()] = tilestyle;
 
@@ -134,20 +146,55 @@ bool Tileset::loadTile(string tag, XML_Helper* helper)
 TileStyle *Tileset::getRandomTileStyle(Uint32 index, TileStyle::Type style)
 {
   Tile *tile = (*this)[index];
-  std::vector<TileStyle*> tilestyles;
-  for (Uint32 j = 0; j < tile->size(); j++)
+  if (tile)
+    return tile->getRandomTileStyle (style);
+  else
+    return NULL;
+}
+
+bool Tileset::save(XML_Helper *helper)
+{
+  bool retval = true;
+
+  retval &= helper->openTag("tileset");
+  retval &= helper->saveData("name", d_name);
+  retval &= helper->saveData("info", d_info);
+  retval &= helper->saveData("tilesize", d_tileSize);
+  for (Tileset::iterator i = begin(); i != end(); ++i)
+    retval &= (*i)->save(helper);
+  retval &= helper->closeTag();
+
+  return retval;
+}
+	
+Tile *Tileset::lookupTileByName(std::string name)
+{
+  for (Tileset::iterator i = begin(); i != end(); ++i)
+    if ((*i)->getName() == name)
+      return *i;
+  return NULL;
+}
+	
+int Tileset::getFreeTileStyleId()
+{
+  int ids[256];
+  memset (ids, 0, sizeof (ids));
+  for (Tileset::iterator i = begin(); i != end(); ++i)
     {
-      TileStyleSet *tilestyleset = (*tile)[j];
-      for (Uint32 k = 0; k < tilestyleset->size(); k++)
+      for (std::list<TileStyleSet*>::iterator j = (*i)->begin(); j != (*i)->end(); j++)
 	{
-	  TileStyle *tilestyle = (*tilestyleset)[k];
-	  if (tilestyle->getType() == style)
-	    tilestyles.push_back(tilestyle);
+	  for (std::vector<TileStyle*>::iterator k = (*j)->begin(); k != (*j)->end(); k++)
+	    {
+	      ids[(*k)->getId()] = 1;
+	    }
 	}
     }
-
-  if (tilestyles.empty() == true)
-    return NULL;
-  return tilestyles[rand() % tilestyles.size()];
+  //these ids range from 0 to 255.
+  for (unsigned int i = 0; i < 256; i++)
+    {
+      if (ids[i] == 0)
+	return i;
+    }
+  return -1;
 }
 // End of file
